Class: Google::Cloud::NetworkManagement::V1::AbortInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkmanagement/v1/trace.rb

Overview

Details of the final state "abort" and associated resource.

Defined Under Namespace

Modules: Cause

Instance Attribute Summary collapse

Instance Attribute Details

#cause::Google::Cloud::NetworkManagement::V1::AbortInfo::Cause

Returns Causes that the analysis is aborted.

Returns:



1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1386

class AbortInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Abort cause types:
  module Cause
    # Cause is unspecified.
    CAUSE_UNSPECIFIED = 0

    # Aborted due to unknown network. Deprecated, not used in the new tests.
    UNKNOWN_NETWORK = 1

    # Aborted because no project information can be derived from the test
    # input. Deprecated, not used in the new tests.
    UNKNOWN_PROJECT = 3

    # Aborted because traffic is sent from a public IP to an instance without
    # an external IP. Deprecated, not used in the new tests.
    NO_EXTERNAL_IP = 7

    # Aborted because none of the traces matches destination information
    # specified in the input test request. Deprecated, not used in the new
    # tests.
    UNINTENDED_DESTINATION = 8

    # Aborted because the source endpoint could not be found. Deprecated, not
    # used in the new tests.
    SOURCE_ENDPOINT_NOT_FOUND = 11

    # Aborted because the source network does not match the source endpoint.
    # Deprecated, not used in the new tests.
    MISMATCHED_SOURCE_NETWORK = 12

    # Aborted because the destination endpoint could not be found. Deprecated,
    # not used in the new tests.
    DESTINATION_ENDPOINT_NOT_FOUND = 13

    # Aborted because the destination network does not match the destination
    # endpoint. Deprecated, not used in the new tests.
    MISMATCHED_DESTINATION_NETWORK = 14

    # Aborted because no endpoint with the packet's destination IP address is
    # found.
    UNKNOWN_IP = 2

    # Aborted because no endpoint with the packet's destination IP is found in
    # the Google-managed project.
    GOOGLE_MANAGED_SERVICE_UNKNOWN_IP = 32

    # Aborted because the source IP address doesn't belong to any of the
    # subnets of the source VPC network.
    SOURCE_IP_ADDRESS_NOT_IN_SOURCE_NETWORK = 23

    # Aborted because user lacks permission to access all or part of the
    # network configurations required to run the test.
    PERMISSION_DENIED = 4

    # Aborted because user lacks permission to access Cloud NAT configs
    # required to run the test.
    PERMISSION_DENIED_NO_CLOUD_NAT_CONFIGS = 28

    # Aborted because user lacks permission to access Network endpoint group
    # endpoint configs required to run the test.
    PERMISSION_DENIED_NO_NEG_ENDPOINT_CONFIGS = 29

    # Aborted because user lacks permission to access Cloud Router configs
    # required to run the test.
    PERMISSION_DENIED_NO_CLOUD_ROUTER_CONFIGS = 36

    # Aborted because no valid source or destination endpoint can be derived
    # from the test request.
    NO_SOURCE_LOCATION = 5

    # Aborted because the source IP address is not contained within the subnet
    # ranges of the provided VPC network.
    NO_SOURCE_GCP_NETWORK_LOCATION = 42

    # Aborted because the source IP address is not contained within the
    # destination ranges of the routes towards non-GCP networks in the provided
    # VPC network.
    NO_SOURCE_NON_GCP_NETWORK_LOCATION = 43

    # Aborted because the source IP address can't be resolved as an Internet
    # IP address.
    NO_SOURCE_INTERNET_LOCATION = 44

    # Aborted because the source or destination endpoint specified in
    # the request is invalid. Some examples:
    # - The request might contain malformed resource URI, project ID, or IP
    # address.
    # - The request might contain inconsistent information (for example, the
    # request might include both the instance and the network, but the instance
    # might not have a NIC in that network).
    INVALID_ARGUMENT = 6

    # Aborted because the number of steps in the trace exceeds a certain
    # limit. It might be caused by a routing loop.
    TRACE_TOO_LONG = 9

    # Aborted due to internal server error.
    INTERNAL_ERROR = 10

    # Aborted because the test scenario is not supported.
    UNSUPPORTED = 15

    # Aborted because the source and destination resources have no common IP
    # version.
    MISMATCHED_IP_VERSION = 16

    # Aborted because the connection between the control plane and the node of
    # the source cluster is initiated by the node and managed by the
    # Konnectivity proxy.
    GKE_KONNECTIVITY_PROXY_UNSUPPORTED = 17

    # Aborted because expected resource configuration was missing.
    RESOURCE_CONFIG_NOT_FOUND = 18

    # Aborted because expected VM instance configuration was missing.
    VM_INSTANCE_CONFIG_NOT_FOUND = 24

    # Aborted because expected network configuration was missing.
    NETWORK_CONFIG_NOT_FOUND = 25

    # Aborted because expected firewall configuration was missing.
    FIREWALL_CONFIG_NOT_FOUND = 26

    # Aborted because expected route configuration was missing.
    ROUTE_CONFIG_NOT_FOUND = 27

    # Aborted because PSC endpoint selection for the Google-managed service
    # is ambiguous (several PSC endpoints satisfy test input).
    GOOGLE_MANAGED_SERVICE_AMBIGUOUS_PSC_ENDPOINT = 19

    # Aborted because endpoint selection for the Google-managed service is
    # ambiguous (several endpoints satisfy test input).
    GOOGLE_MANAGED_SERVICE_AMBIGUOUS_ENDPOINT = 39

    # Aborted because tests with a PSC-based Cloud SQL instance as a source are
    # not supported.
    SOURCE_PSC_CLOUD_SQL_UNSUPPORTED = 20

    # Aborted because tests with the external database as a source are not
    # supported. In such replication scenarios, the connection is initiated by
    # the Cloud SQL replica instance.
    SOURCE_EXTERNAL_CLOUD_SQL_UNSUPPORTED = 45

    # Aborted because tests with a Redis Cluster as a source are not supported.
    SOURCE_REDIS_CLUSTER_UNSUPPORTED = 34

    # Aborted because tests with a Redis Instance as a source are not
    # supported.
    SOURCE_REDIS_INSTANCE_UNSUPPORTED = 35

    # Aborted because tests with a forwarding rule as a source are not
    # supported.
    SOURCE_FORWARDING_RULE_UNSUPPORTED = 21

    # Aborted because one of the endpoints is a non-routable IP address
    # (loopback, link-local, etc).
    NON_ROUTABLE_IP_ADDRESS = 22

    # Aborted due to an unknown issue in the Google-managed project.
    UNKNOWN_ISSUE_IN_GOOGLE_MANAGED_PROJECT = 30

    # Aborted due to an unsupported configuration of the Google-managed
    # project.
    UNSUPPORTED_GOOGLE_MANAGED_PROJECT_CONFIG = 31

    # Aborted because the source endpoint is a Cloud Run revision with direct
    # VPC access enabled, but there are no reserved serverless IP ranges.
    NO_SERVERLESS_IP_RANGES = 37

    # Aborted because the used protocol is not supported for the used IP
    # version.
    IP_VERSION_PROTOCOL_MISMATCH = 40

    # Aborted because selected GKE Pod endpoint location is unknown. This is
    # often the case for "Pending" Pods, which don't have assigned IP addresses
    # yet.
    GKE_POD_UNKNOWN_ENDPOINT_LOCATION = 41
  end
end

#ip_address::String

Returns IP address that caused the abort.

Returns:

  • (::String)

    IP address that caused the abort.



1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1386

class AbortInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Abort cause types:
  module Cause
    # Cause is unspecified.
    CAUSE_UNSPECIFIED = 0

    # Aborted due to unknown network. Deprecated, not used in the new tests.
    UNKNOWN_NETWORK = 1

    # Aborted because no project information can be derived from the test
    # input. Deprecated, not used in the new tests.
    UNKNOWN_PROJECT = 3

    # Aborted because traffic is sent from a public IP to an instance without
    # an external IP. Deprecated, not used in the new tests.
    NO_EXTERNAL_IP = 7

    # Aborted because none of the traces matches destination information
    # specified in the input test request. Deprecated, not used in the new
    # tests.
    UNINTENDED_DESTINATION = 8

    # Aborted because the source endpoint could not be found. Deprecated, not
    # used in the new tests.
    SOURCE_ENDPOINT_NOT_FOUND = 11

    # Aborted because the source network does not match the source endpoint.
    # Deprecated, not used in the new tests.
    MISMATCHED_SOURCE_NETWORK = 12

    # Aborted because the destination endpoint could not be found. Deprecated,
    # not used in the new tests.
    DESTINATION_ENDPOINT_NOT_FOUND = 13

    # Aborted because the destination network does not match the destination
    # endpoint. Deprecated, not used in the new tests.
    MISMATCHED_DESTINATION_NETWORK = 14

    # Aborted because no endpoint with the packet's destination IP address is
    # found.
    UNKNOWN_IP = 2

    # Aborted because no endpoint with the packet's destination IP is found in
    # the Google-managed project.
    GOOGLE_MANAGED_SERVICE_UNKNOWN_IP = 32

    # Aborted because the source IP address doesn't belong to any of the
    # subnets of the source VPC network.
    SOURCE_IP_ADDRESS_NOT_IN_SOURCE_NETWORK = 23

    # Aborted because user lacks permission to access all or part of the
    # network configurations required to run the test.
    PERMISSION_DENIED = 4

    # Aborted because user lacks permission to access Cloud NAT configs
    # required to run the test.
    PERMISSION_DENIED_NO_CLOUD_NAT_CONFIGS = 28

    # Aborted because user lacks permission to access Network endpoint group
    # endpoint configs required to run the test.
    PERMISSION_DENIED_NO_NEG_ENDPOINT_CONFIGS = 29

    # Aborted because user lacks permission to access Cloud Router configs
    # required to run the test.
    PERMISSION_DENIED_NO_CLOUD_ROUTER_CONFIGS = 36

    # Aborted because no valid source or destination endpoint can be derived
    # from the test request.
    NO_SOURCE_LOCATION = 5

    # Aborted because the source IP address is not contained within the subnet
    # ranges of the provided VPC network.
    NO_SOURCE_GCP_NETWORK_LOCATION = 42

    # Aborted because the source IP address is not contained within the
    # destination ranges of the routes towards non-GCP networks in the provided
    # VPC network.
    NO_SOURCE_NON_GCP_NETWORK_LOCATION = 43

    # Aborted because the source IP address can't be resolved as an Internet
    # IP address.
    NO_SOURCE_INTERNET_LOCATION = 44

    # Aborted because the source or destination endpoint specified in
    # the request is invalid. Some examples:
    # - The request might contain malformed resource URI, project ID, or IP
    # address.
    # - The request might contain inconsistent information (for example, the
    # request might include both the instance and the network, but the instance
    # might not have a NIC in that network).
    INVALID_ARGUMENT = 6

    # Aborted because the number of steps in the trace exceeds a certain
    # limit. It might be caused by a routing loop.
    TRACE_TOO_LONG = 9

    # Aborted due to internal server error.
    INTERNAL_ERROR = 10

    # Aborted because the test scenario is not supported.
    UNSUPPORTED = 15

    # Aborted because the source and destination resources have no common IP
    # version.
    MISMATCHED_IP_VERSION = 16

    # Aborted because the connection between the control plane and the node of
    # the source cluster is initiated by the node and managed by the
    # Konnectivity proxy.
    GKE_KONNECTIVITY_PROXY_UNSUPPORTED = 17

    # Aborted because expected resource configuration was missing.
    RESOURCE_CONFIG_NOT_FOUND = 18

    # Aborted because expected VM instance configuration was missing.
    VM_INSTANCE_CONFIG_NOT_FOUND = 24

    # Aborted because expected network configuration was missing.
    NETWORK_CONFIG_NOT_FOUND = 25

    # Aborted because expected firewall configuration was missing.
    FIREWALL_CONFIG_NOT_FOUND = 26

    # Aborted because expected route configuration was missing.
    ROUTE_CONFIG_NOT_FOUND = 27

    # Aborted because PSC endpoint selection for the Google-managed service
    # is ambiguous (several PSC endpoints satisfy test input).
    GOOGLE_MANAGED_SERVICE_AMBIGUOUS_PSC_ENDPOINT = 19

    # Aborted because endpoint selection for the Google-managed service is
    # ambiguous (several endpoints satisfy test input).
    GOOGLE_MANAGED_SERVICE_AMBIGUOUS_ENDPOINT = 39

    # Aborted because tests with a PSC-based Cloud SQL instance as a source are
    # not supported.
    SOURCE_PSC_CLOUD_SQL_UNSUPPORTED = 20

    # Aborted because tests with the external database as a source are not
    # supported. In such replication scenarios, the connection is initiated by
    # the Cloud SQL replica instance.
    SOURCE_EXTERNAL_CLOUD_SQL_UNSUPPORTED = 45

    # Aborted because tests with a Redis Cluster as a source are not supported.
    SOURCE_REDIS_CLUSTER_UNSUPPORTED = 34

    # Aborted because tests with a Redis Instance as a source are not
    # supported.
    SOURCE_REDIS_INSTANCE_UNSUPPORTED = 35

    # Aborted because tests with a forwarding rule as a source are not
    # supported.
    SOURCE_FORWARDING_RULE_UNSUPPORTED = 21

    # Aborted because one of the endpoints is a non-routable IP address
    # (loopback, link-local, etc).
    NON_ROUTABLE_IP_ADDRESS = 22

    # Aborted due to an unknown issue in the Google-managed project.
    UNKNOWN_ISSUE_IN_GOOGLE_MANAGED_PROJECT = 30

    # Aborted due to an unsupported configuration of the Google-managed
    # project.
    UNSUPPORTED_GOOGLE_MANAGED_PROJECT_CONFIG = 31

    # Aborted because the source endpoint is a Cloud Run revision with direct
    # VPC access enabled, but there are no reserved serverless IP ranges.
    NO_SERVERLESS_IP_RANGES = 37

    # Aborted because the used protocol is not supported for the used IP
    # version.
    IP_VERSION_PROTOCOL_MISMATCH = 40

    # Aborted because selected GKE Pod endpoint location is unknown. This is
    # often the case for "Pending" Pods, which don't have assigned IP addresses
    # yet.
    GKE_POD_UNKNOWN_ENDPOINT_LOCATION = 41
  end
end

#projects_missing_permission::Array<::String>

Returns List of project IDs the user specified in the request but lacks access to. In this case, analysis is aborted with the PERMISSION_DENIED cause.

Returns:

  • (::Array<::String>)

    List of project IDs the user specified in the request but lacks access to. In this case, analysis is aborted with the PERMISSION_DENIED cause.



1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1386

class AbortInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Abort cause types:
  module Cause
    # Cause is unspecified.
    CAUSE_UNSPECIFIED = 0

    # Aborted due to unknown network. Deprecated, not used in the new tests.
    UNKNOWN_NETWORK = 1

    # Aborted because no project information can be derived from the test
    # input. Deprecated, not used in the new tests.
    UNKNOWN_PROJECT = 3

    # Aborted because traffic is sent from a public IP to an instance without
    # an external IP. Deprecated, not used in the new tests.
    NO_EXTERNAL_IP = 7

    # Aborted because none of the traces matches destination information
    # specified in the input test request. Deprecated, not used in the new
    # tests.
    UNINTENDED_DESTINATION = 8

    # Aborted because the source endpoint could not be found. Deprecated, not
    # used in the new tests.
    SOURCE_ENDPOINT_NOT_FOUND = 11

    # Aborted because the source network does not match the source endpoint.
    # Deprecated, not used in the new tests.
    MISMATCHED_SOURCE_NETWORK = 12

    # Aborted because the destination endpoint could not be found. Deprecated,
    # not used in the new tests.
    DESTINATION_ENDPOINT_NOT_FOUND = 13

    # Aborted because the destination network does not match the destination
    # endpoint. Deprecated, not used in the new tests.
    MISMATCHED_DESTINATION_NETWORK = 14

    # Aborted because no endpoint with the packet's destination IP address is
    # found.
    UNKNOWN_IP = 2

    # Aborted because no endpoint with the packet's destination IP is found in
    # the Google-managed project.
    GOOGLE_MANAGED_SERVICE_UNKNOWN_IP = 32

    # Aborted because the source IP address doesn't belong to any of the
    # subnets of the source VPC network.
    SOURCE_IP_ADDRESS_NOT_IN_SOURCE_NETWORK = 23

    # Aborted because user lacks permission to access all or part of the
    # network configurations required to run the test.
    PERMISSION_DENIED = 4

    # Aborted because user lacks permission to access Cloud NAT configs
    # required to run the test.
    PERMISSION_DENIED_NO_CLOUD_NAT_CONFIGS = 28

    # Aborted because user lacks permission to access Network endpoint group
    # endpoint configs required to run the test.
    PERMISSION_DENIED_NO_NEG_ENDPOINT_CONFIGS = 29

    # Aborted because user lacks permission to access Cloud Router configs
    # required to run the test.
    PERMISSION_DENIED_NO_CLOUD_ROUTER_CONFIGS = 36

    # Aborted because no valid source or destination endpoint can be derived
    # from the test request.
    NO_SOURCE_LOCATION = 5

    # Aborted because the source IP address is not contained within the subnet
    # ranges of the provided VPC network.
    NO_SOURCE_GCP_NETWORK_LOCATION = 42

    # Aborted because the source IP address is not contained within the
    # destination ranges of the routes towards non-GCP networks in the provided
    # VPC network.
    NO_SOURCE_NON_GCP_NETWORK_LOCATION = 43

    # Aborted because the source IP address can't be resolved as an Internet
    # IP address.
    NO_SOURCE_INTERNET_LOCATION = 44

    # Aborted because the source or destination endpoint specified in
    # the request is invalid. Some examples:
    # - The request might contain malformed resource URI, project ID, or IP
    # address.
    # - The request might contain inconsistent information (for example, the
    # request might include both the instance and the network, but the instance
    # might not have a NIC in that network).
    INVALID_ARGUMENT = 6

    # Aborted because the number of steps in the trace exceeds a certain
    # limit. It might be caused by a routing loop.
    TRACE_TOO_LONG = 9

    # Aborted due to internal server error.
    INTERNAL_ERROR = 10

    # Aborted because the test scenario is not supported.
    UNSUPPORTED = 15

    # Aborted because the source and destination resources have no common IP
    # version.
    MISMATCHED_IP_VERSION = 16

    # Aborted because the connection between the control plane and the node of
    # the source cluster is initiated by the node and managed by the
    # Konnectivity proxy.
    GKE_KONNECTIVITY_PROXY_UNSUPPORTED = 17

    # Aborted because expected resource configuration was missing.
    RESOURCE_CONFIG_NOT_FOUND = 18

    # Aborted because expected VM instance configuration was missing.
    VM_INSTANCE_CONFIG_NOT_FOUND = 24

    # Aborted because expected network configuration was missing.
    NETWORK_CONFIG_NOT_FOUND = 25

    # Aborted because expected firewall configuration was missing.
    FIREWALL_CONFIG_NOT_FOUND = 26

    # Aborted because expected route configuration was missing.
    ROUTE_CONFIG_NOT_FOUND = 27

    # Aborted because PSC endpoint selection for the Google-managed service
    # is ambiguous (several PSC endpoints satisfy test input).
    GOOGLE_MANAGED_SERVICE_AMBIGUOUS_PSC_ENDPOINT = 19

    # Aborted because endpoint selection for the Google-managed service is
    # ambiguous (several endpoints satisfy test input).
    GOOGLE_MANAGED_SERVICE_AMBIGUOUS_ENDPOINT = 39

    # Aborted because tests with a PSC-based Cloud SQL instance as a source are
    # not supported.
    SOURCE_PSC_CLOUD_SQL_UNSUPPORTED = 20

    # Aborted because tests with the external database as a source are not
    # supported. In such replication scenarios, the connection is initiated by
    # the Cloud SQL replica instance.
    SOURCE_EXTERNAL_CLOUD_SQL_UNSUPPORTED = 45

    # Aborted because tests with a Redis Cluster as a source are not supported.
    SOURCE_REDIS_CLUSTER_UNSUPPORTED = 34

    # Aborted because tests with a Redis Instance as a source are not
    # supported.
    SOURCE_REDIS_INSTANCE_UNSUPPORTED = 35

    # Aborted because tests with a forwarding rule as a source are not
    # supported.
    SOURCE_FORWARDING_RULE_UNSUPPORTED = 21

    # Aborted because one of the endpoints is a non-routable IP address
    # (loopback, link-local, etc).
    NON_ROUTABLE_IP_ADDRESS = 22

    # Aborted due to an unknown issue in the Google-managed project.
    UNKNOWN_ISSUE_IN_GOOGLE_MANAGED_PROJECT = 30

    # Aborted due to an unsupported configuration of the Google-managed
    # project.
    UNSUPPORTED_GOOGLE_MANAGED_PROJECT_CONFIG = 31

    # Aborted because the source endpoint is a Cloud Run revision with direct
    # VPC access enabled, but there are no reserved serverless IP ranges.
    NO_SERVERLESS_IP_RANGES = 37

    # Aborted because the used protocol is not supported for the used IP
    # version.
    IP_VERSION_PROTOCOL_MISMATCH = 40

    # Aborted because selected GKE Pod endpoint location is unknown. This is
    # often the case for "Pending" Pods, which don't have assigned IP addresses
    # yet.
    GKE_POD_UNKNOWN_ENDPOINT_LOCATION = 41
  end
end

#resource_uri::String

Returns URI of the resource that caused the abort.

Returns:

  • (::String)

    URI of the resource that caused the abort.



1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1386

class AbortInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Abort cause types:
  module Cause
    # Cause is unspecified.
    CAUSE_UNSPECIFIED = 0

    # Aborted due to unknown network. Deprecated, not used in the new tests.
    UNKNOWN_NETWORK = 1

    # Aborted because no project information can be derived from the test
    # input. Deprecated, not used in the new tests.
    UNKNOWN_PROJECT = 3

    # Aborted because traffic is sent from a public IP to an instance without
    # an external IP. Deprecated, not used in the new tests.
    NO_EXTERNAL_IP = 7

    # Aborted because none of the traces matches destination information
    # specified in the input test request. Deprecated, not used in the new
    # tests.
    UNINTENDED_DESTINATION = 8

    # Aborted because the source endpoint could not be found. Deprecated, not
    # used in the new tests.
    SOURCE_ENDPOINT_NOT_FOUND = 11

    # Aborted because the source network does not match the source endpoint.
    # Deprecated, not used in the new tests.
    MISMATCHED_SOURCE_NETWORK = 12

    # Aborted because the destination endpoint could not be found. Deprecated,
    # not used in the new tests.
    DESTINATION_ENDPOINT_NOT_FOUND = 13

    # Aborted because the destination network does not match the destination
    # endpoint. Deprecated, not used in the new tests.
    MISMATCHED_DESTINATION_NETWORK = 14

    # Aborted because no endpoint with the packet's destination IP address is
    # found.
    UNKNOWN_IP = 2

    # Aborted because no endpoint with the packet's destination IP is found in
    # the Google-managed project.
    GOOGLE_MANAGED_SERVICE_UNKNOWN_IP = 32

    # Aborted because the source IP address doesn't belong to any of the
    # subnets of the source VPC network.
    SOURCE_IP_ADDRESS_NOT_IN_SOURCE_NETWORK = 23

    # Aborted because user lacks permission to access all or part of the
    # network configurations required to run the test.
    PERMISSION_DENIED = 4

    # Aborted because user lacks permission to access Cloud NAT configs
    # required to run the test.
    PERMISSION_DENIED_NO_CLOUD_NAT_CONFIGS = 28

    # Aborted because user lacks permission to access Network endpoint group
    # endpoint configs required to run the test.
    PERMISSION_DENIED_NO_NEG_ENDPOINT_CONFIGS = 29

    # Aborted because user lacks permission to access Cloud Router configs
    # required to run the test.
    PERMISSION_DENIED_NO_CLOUD_ROUTER_CONFIGS = 36

    # Aborted because no valid source or destination endpoint can be derived
    # from the test request.
    NO_SOURCE_LOCATION = 5

    # Aborted because the source IP address is not contained within the subnet
    # ranges of the provided VPC network.
    NO_SOURCE_GCP_NETWORK_LOCATION = 42

    # Aborted because the source IP address is not contained within the
    # destination ranges of the routes towards non-GCP networks in the provided
    # VPC network.
    NO_SOURCE_NON_GCP_NETWORK_LOCATION = 43

    # Aborted because the source IP address can't be resolved as an Internet
    # IP address.
    NO_SOURCE_INTERNET_LOCATION = 44

    # Aborted because the source or destination endpoint specified in
    # the request is invalid. Some examples:
    # - The request might contain malformed resource URI, project ID, or IP
    # address.
    # - The request might contain inconsistent information (for example, the
    # request might include both the instance and the network, but the instance
    # might not have a NIC in that network).
    INVALID_ARGUMENT = 6

    # Aborted because the number of steps in the trace exceeds a certain
    # limit. It might be caused by a routing loop.
    TRACE_TOO_LONG = 9

    # Aborted due to internal server error.
    INTERNAL_ERROR = 10

    # Aborted because the test scenario is not supported.
    UNSUPPORTED = 15

    # Aborted because the source and destination resources have no common IP
    # version.
    MISMATCHED_IP_VERSION = 16

    # Aborted because the connection between the control plane and the node of
    # the source cluster is initiated by the node and managed by the
    # Konnectivity proxy.
    GKE_KONNECTIVITY_PROXY_UNSUPPORTED = 17

    # Aborted because expected resource configuration was missing.
    RESOURCE_CONFIG_NOT_FOUND = 18

    # Aborted because expected VM instance configuration was missing.
    VM_INSTANCE_CONFIG_NOT_FOUND = 24

    # Aborted because expected network configuration was missing.
    NETWORK_CONFIG_NOT_FOUND = 25

    # Aborted because expected firewall configuration was missing.
    FIREWALL_CONFIG_NOT_FOUND = 26

    # Aborted because expected route configuration was missing.
    ROUTE_CONFIG_NOT_FOUND = 27

    # Aborted because PSC endpoint selection for the Google-managed service
    # is ambiguous (several PSC endpoints satisfy test input).
    GOOGLE_MANAGED_SERVICE_AMBIGUOUS_PSC_ENDPOINT = 19

    # Aborted because endpoint selection for the Google-managed service is
    # ambiguous (several endpoints satisfy test input).
    GOOGLE_MANAGED_SERVICE_AMBIGUOUS_ENDPOINT = 39

    # Aborted because tests with a PSC-based Cloud SQL instance as a source are
    # not supported.
    SOURCE_PSC_CLOUD_SQL_UNSUPPORTED = 20

    # Aborted because tests with the external database as a source are not
    # supported. In such replication scenarios, the connection is initiated by
    # the Cloud SQL replica instance.
    SOURCE_EXTERNAL_CLOUD_SQL_UNSUPPORTED = 45

    # Aborted because tests with a Redis Cluster as a source are not supported.
    SOURCE_REDIS_CLUSTER_UNSUPPORTED = 34

    # Aborted because tests with a Redis Instance as a source are not
    # supported.
    SOURCE_REDIS_INSTANCE_UNSUPPORTED = 35

    # Aborted because tests with a forwarding rule as a source are not
    # supported.
    SOURCE_FORWARDING_RULE_UNSUPPORTED = 21

    # Aborted because one of the endpoints is a non-routable IP address
    # (loopback, link-local, etc).
    NON_ROUTABLE_IP_ADDRESS = 22

    # Aborted due to an unknown issue in the Google-managed project.
    UNKNOWN_ISSUE_IN_GOOGLE_MANAGED_PROJECT = 30

    # Aborted due to an unsupported configuration of the Google-managed
    # project.
    UNSUPPORTED_GOOGLE_MANAGED_PROJECT_CONFIG = 31

    # Aborted because the source endpoint is a Cloud Run revision with direct
    # VPC access enabled, but there are no reserved serverless IP ranges.
    NO_SERVERLESS_IP_RANGES = 37

    # Aborted because the used protocol is not supported for the used IP
    # version.
    IP_VERSION_PROTOCOL_MISMATCH = 40

    # Aborted because selected GKE Pod endpoint location is unknown. This is
    # often the case for "Pending" Pods, which don't have assigned IP addresses
    # yet.
    GKE_POD_UNKNOWN_ENDPOINT_LOCATION = 41
  end
end