Class: Google::Cloud::NetworkManagement::V1::CreateVpcFlowLogsConfigRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb

Overview

Request for the CreateVpcFlowLogsConfig method.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The parent resource of the VpcFlowLogsConfig to create, in one of the following formats:

  • For project-level resources: projects/{project_id}/locations/global

  • For organization-level resources: organizations/{organization_id}/locations/global.

Returns:

  • Required. The parent resource of the VpcFlowLogsConfig to create, in one of the following formats:

    • For project-level resources: projects/{project_id}/locations/global

    • For organization-level resources: organizations/{organization_id}/locations/global



101
102
103
104
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 101

class CreateVpcFlowLogsConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vpc_flow_logs_config::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig

Returns Required. A VpcFlowLogsConfig resource.

Returns:

  • Required. A VpcFlowLogsConfig resource



101
102
103
104
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 101

class CreateVpcFlowLogsConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vpc_flow_logs_config_id::String

Returns Required. ID of the VpcFlowLogsConfig.

Returns:

  • Required. ID of the VpcFlowLogsConfig.



101
102
103
104
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 101

class CreateVpcFlowLogsConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end