Class: Google::Cloud::NetworkManagement::V1::DeliverInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkmanagement/v1/trace.rb

Overview

Details of the final state "deliver" and associated resource.

Defined Under Namespace

Modules: GoogleServiceType, Target

Instance Attribute Summary collapse

Instance Attribute Details

#google_service_type::Google::Cloud::NetworkManagement::V1::DeliverInfo::GoogleServiceType

Returns Recognized type of a Google Service the packet is delivered to (if applicable).

Returns:



1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1222

class DeliverInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Deliver target types:
  module Target
    # Target not specified.
    TARGET_UNSPECIFIED = 0

    # Target is a Compute Engine instance.
    INSTANCE = 1

    # Target is the internet.
    INTERNET = 2

    # Target is a Google API.
    GOOGLE_API = 3

    # Target is a Google Kubernetes Engine cluster master.
    GKE_MASTER = 4

    # Target is a Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 5

    # Target is a published service that uses [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-services).
    PSC_PUBLISHED_SERVICE = 6

    # Target is Google APIs that use [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-apis).
    PSC_GOOGLE_API = 7

    # Target is a VPC-SC that uses [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-apis).
    PSC_VPC_SC = 8

    # Target is a serverless network endpoint group.
    SERVERLESS_NEG = 9

    # Target is a Cloud Storage bucket.
    STORAGE_BUCKET = 10

    # Target is a private network. Used only for return traces.
    PRIVATE_NETWORK = 11

    # Target is a Cloud Function. Used only for return traces.
    CLOUD_FUNCTION = 12

    # Target is a App Engine service version. Used only for return traces.
    APP_ENGINE_VERSION = 13

    # Target is a Cloud Run revision. Used only for return traces.
    CLOUD_RUN_REVISION = 14

    # Target is a Google-managed service. Used only for return traces.
    GOOGLE_MANAGED_SERVICE = 15

    # Target is a Redis Instance.
    REDIS_INSTANCE = 16

    # Target is a Redis Cluster.
    REDIS_CLUSTER = 17

    # Target is a GKE Pod.
    GKE_POD = 19
  end

  # Recognized type of a Google Service.
  module GoogleServiceType
    # Unspecified Google Service.
    GOOGLE_SERVICE_TYPE_UNSPECIFIED = 0

    # Identity aware proxy.
    # https://cloud.google.com/iap/docs/using-tcp-forwarding
    IAP = 1

    # One of two services sharing IP ranges:
    # * Load Balancer proxy
    # * Centralized Health Check prober
    # https://cloud.google.com/load-balancing/docs/firewall-rules
    GFE_PROXY_OR_HEALTH_CHECK_PROBER = 2

    # Connectivity from Cloud DNS to forwarding targets or alternate name
    # servers that use private routing.
    # https://cloud.google.com/dns/docs/zones/forwarding-zones#firewall-rules
    # https://cloud.google.com/dns/docs/policies#firewall-rules
    CLOUD_DNS = 3

    # private.googleapis.com and restricted.googleapis.com
    PRIVATE_GOOGLE_ACCESS = 4

    # Google API via Private Service Connect.
    # https://cloud.google.com/vpc/docs/configure-private-service-connect-apis
    # Google API via Serverless VPC Access.
    # https://cloud.google.com/vpc/docs/serverless-vpc-access
    SERVERLESS_VPC_ACCESS = 5
  end
end

#ip_address::String

Returns IP address of the target (if applicable).

Returns:

  • (::String)

    IP address of the target (if applicable).



1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1222

class DeliverInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Deliver target types:
  module Target
    # Target not specified.
    TARGET_UNSPECIFIED = 0

    # Target is a Compute Engine instance.
    INSTANCE = 1

    # Target is the internet.
    INTERNET = 2

    # Target is a Google API.
    GOOGLE_API = 3

    # Target is a Google Kubernetes Engine cluster master.
    GKE_MASTER = 4

    # Target is a Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 5

    # Target is a published service that uses [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-services).
    PSC_PUBLISHED_SERVICE = 6

    # Target is Google APIs that use [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-apis).
    PSC_GOOGLE_API = 7

    # Target is a VPC-SC that uses [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-apis).
    PSC_VPC_SC = 8

    # Target is a serverless network endpoint group.
    SERVERLESS_NEG = 9

    # Target is a Cloud Storage bucket.
    STORAGE_BUCKET = 10

    # Target is a private network. Used only for return traces.
    PRIVATE_NETWORK = 11

    # Target is a Cloud Function. Used only for return traces.
    CLOUD_FUNCTION = 12

    # Target is a App Engine service version. Used only for return traces.
    APP_ENGINE_VERSION = 13

    # Target is a Cloud Run revision. Used only for return traces.
    CLOUD_RUN_REVISION = 14

    # Target is a Google-managed service. Used only for return traces.
    GOOGLE_MANAGED_SERVICE = 15

    # Target is a Redis Instance.
    REDIS_INSTANCE = 16

    # Target is a Redis Cluster.
    REDIS_CLUSTER = 17

    # Target is a GKE Pod.
    GKE_POD = 19
  end

  # Recognized type of a Google Service.
  module GoogleServiceType
    # Unspecified Google Service.
    GOOGLE_SERVICE_TYPE_UNSPECIFIED = 0

    # Identity aware proxy.
    # https://cloud.google.com/iap/docs/using-tcp-forwarding
    IAP = 1

    # One of two services sharing IP ranges:
    # * Load Balancer proxy
    # * Centralized Health Check prober
    # https://cloud.google.com/load-balancing/docs/firewall-rules
    GFE_PROXY_OR_HEALTH_CHECK_PROBER = 2

    # Connectivity from Cloud DNS to forwarding targets or alternate name
    # servers that use private routing.
    # https://cloud.google.com/dns/docs/zones/forwarding-zones#firewall-rules
    # https://cloud.google.com/dns/docs/policies#firewall-rules
    CLOUD_DNS = 3

    # private.googleapis.com and restricted.googleapis.com
    PRIVATE_GOOGLE_ACCESS = 4

    # Google API via Private Service Connect.
    # https://cloud.google.com/vpc/docs/configure-private-service-connect-apis
    # Google API via Serverless VPC Access.
    # https://cloud.google.com/vpc/docs/serverless-vpc-access
    SERVERLESS_VPC_ACCESS = 5
  end
end

#psc_google_api_target::String

Returns PSC Google API target the packet is delivered to (if applicable).

Returns:

  • (::String)

    PSC Google API target the packet is delivered to (if applicable).



1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1222

class DeliverInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Deliver target types:
  module Target
    # Target not specified.
    TARGET_UNSPECIFIED = 0

    # Target is a Compute Engine instance.
    INSTANCE = 1

    # Target is the internet.
    INTERNET = 2

    # Target is a Google API.
    GOOGLE_API = 3

    # Target is a Google Kubernetes Engine cluster master.
    GKE_MASTER = 4

    # Target is a Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 5

    # Target is a published service that uses [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-services).
    PSC_PUBLISHED_SERVICE = 6

    # Target is Google APIs that use [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-apis).
    PSC_GOOGLE_API = 7

    # Target is a VPC-SC that uses [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-apis).
    PSC_VPC_SC = 8

    # Target is a serverless network endpoint group.
    SERVERLESS_NEG = 9

    # Target is a Cloud Storage bucket.
    STORAGE_BUCKET = 10

    # Target is a private network. Used only for return traces.
    PRIVATE_NETWORK = 11

    # Target is a Cloud Function. Used only for return traces.
    CLOUD_FUNCTION = 12

    # Target is a App Engine service version. Used only for return traces.
    APP_ENGINE_VERSION = 13

    # Target is a Cloud Run revision. Used only for return traces.
    CLOUD_RUN_REVISION = 14

    # Target is a Google-managed service. Used only for return traces.
    GOOGLE_MANAGED_SERVICE = 15

    # Target is a Redis Instance.
    REDIS_INSTANCE = 16

    # Target is a Redis Cluster.
    REDIS_CLUSTER = 17

    # Target is a GKE Pod.
    GKE_POD = 19
  end

  # Recognized type of a Google Service.
  module GoogleServiceType
    # Unspecified Google Service.
    GOOGLE_SERVICE_TYPE_UNSPECIFIED = 0

    # Identity aware proxy.
    # https://cloud.google.com/iap/docs/using-tcp-forwarding
    IAP = 1

    # One of two services sharing IP ranges:
    # * Load Balancer proxy
    # * Centralized Health Check prober
    # https://cloud.google.com/load-balancing/docs/firewall-rules
    GFE_PROXY_OR_HEALTH_CHECK_PROBER = 2

    # Connectivity from Cloud DNS to forwarding targets or alternate name
    # servers that use private routing.
    # https://cloud.google.com/dns/docs/zones/forwarding-zones#firewall-rules
    # https://cloud.google.com/dns/docs/policies#firewall-rules
    CLOUD_DNS = 3

    # private.googleapis.com and restricted.googleapis.com
    PRIVATE_GOOGLE_ACCESS = 4

    # Google API via Private Service Connect.
    # https://cloud.google.com/vpc/docs/configure-private-service-connect-apis
    # Google API via Serverless VPC Access.
    # https://cloud.google.com/vpc/docs/serverless-vpc-access
    SERVERLESS_VPC_ACCESS = 5
  end
end

#resource_uri::String

Returns URI of the resource that the packet is delivered to.

Returns:

  • (::String)

    URI of the resource that the packet is delivered to.



1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1222

class DeliverInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Deliver target types:
  module Target
    # Target not specified.
    TARGET_UNSPECIFIED = 0

    # Target is a Compute Engine instance.
    INSTANCE = 1

    # Target is the internet.
    INTERNET = 2

    # Target is a Google API.
    GOOGLE_API = 3

    # Target is a Google Kubernetes Engine cluster master.
    GKE_MASTER = 4

    # Target is a Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 5

    # Target is a published service that uses [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-services).
    PSC_PUBLISHED_SERVICE = 6

    # Target is Google APIs that use [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-apis).
    PSC_GOOGLE_API = 7

    # Target is a VPC-SC that uses [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-apis).
    PSC_VPC_SC = 8

    # Target is a serverless network endpoint group.
    SERVERLESS_NEG = 9

    # Target is a Cloud Storage bucket.
    STORAGE_BUCKET = 10

    # Target is a private network. Used only for return traces.
    PRIVATE_NETWORK = 11

    # Target is a Cloud Function. Used only for return traces.
    CLOUD_FUNCTION = 12

    # Target is a App Engine service version. Used only for return traces.
    APP_ENGINE_VERSION = 13

    # Target is a Cloud Run revision. Used only for return traces.
    CLOUD_RUN_REVISION = 14

    # Target is a Google-managed service. Used only for return traces.
    GOOGLE_MANAGED_SERVICE = 15

    # Target is a Redis Instance.
    REDIS_INSTANCE = 16

    # Target is a Redis Cluster.
    REDIS_CLUSTER = 17

    # Target is a GKE Pod.
    GKE_POD = 19
  end

  # Recognized type of a Google Service.
  module GoogleServiceType
    # Unspecified Google Service.
    GOOGLE_SERVICE_TYPE_UNSPECIFIED = 0

    # Identity aware proxy.
    # https://cloud.google.com/iap/docs/using-tcp-forwarding
    IAP = 1

    # One of two services sharing IP ranges:
    # * Load Balancer proxy
    # * Centralized Health Check prober
    # https://cloud.google.com/load-balancing/docs/firewall-rules
    GFE_PROXY_OR_HEALTH_CHECK_PROBER = 2

    # Connectivity from Cloud DNS to forwarding targets or alternate name
    # servers that use private routing.
    # https://cloud.google.com/dns/docs/zones/forwarding-zones#firewall-rules
    # https://cloud.google.com/dns/docs/policies#firewall-rules
    CLOUD_DNS = 3

    # private.googleapis.com and restricted.googleapis.com
    PRIVATE_GOOGLE_ACCESS = 4

    # Google API via Private Service Connect.
    # https://cloud.google.com/vpc/docs/configure-private-service-connect-apis
    # Google API via Serverless VPC Access.
    # https://cloud.google.com/vpc/docs/serverless-vpc-access
    SERVERLESS_VPC_ACCESS = 5
  end
end

#storage_bucket::String

Returns Name of the Cloud Storage Bucket the packet is delivered to (if applicable).

Returns:

  • (::String)

    Name of the Cloud Storage Bucket the packet is delivered to (if applicable).



1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1222

class DeliverInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Deliver target types:
  module Target
    # Target not specified.
    TARGET_UNSPECIFIED = 0

    # Target is a Compute Engine instance.
    INSTANCE = 1

    # Target is the internet.
    INTERNET = 2

    # Target is a Google API.
    GOOGLE_API = 3

    # Target is a Google Kubernetes Engine cluster master.
    GKE_MASTER = 4

    # Target is a Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 5

    # Target is a published service that uses [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-services).
    PSC_PUBLISHED_SERVICE = 6

    # Target is Google APIs that use [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-apis).
    PSC_GOOGLE_API = 7

    # Target is a VPC-SC that uses [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-apis).
    PSC_VPC_SC = 8

    # Target is a serverless network endpoint group.
    SERVERLESS_NEG = 9

    # Target is a Cloud Storage bucket.
    STORAGE_BUCKET = 10

    # Target is a private network. Used only for return traces.
    PRIVATE_NETWORK = 11

    # Target is a Cloud Function. Used only for return traces.
    CLOUD_FUNCTION = 12

    # Target is a App Engine service version. Used only for return traces.
    APP_ENGINE_VERSION = 13

    # Target is a Cloud Run revision. Used only for return traces.
    CLOUD_RUN_REVISION = 14

    # Target is a Google-managed service. Used only for return traces.
    GOOGLE_MANAGED_SERVICE = 15

    # Target is a Redis Instance.
    REDIS_INSTANCE = 16

    # Target is a Redis Cluster.
    REDIS_CLUSTER = 17

    # Target is a GKE Pod.
    GKE_POD = 19
  end

  # Recognized type of a Google Service.
  module GoogleServiceType
    # Unspecified Google Service.
    GOOGLE_SERVICE_TYPE_UNSPECIFIED = 0

    # Identity aware proxy.
    # https://cloud.google.com/iap/docs/using-tcp-forwarding
    IAP = 1

    # One of two services sharing IP ranges:
    # * Load Balancer proxy
    # * Centralized Health Check prober
    # https://cloud.google.com/load-balancing/docs/firewall-rules
    GFE_PROXY_OR_HEALTH_CHECK_PROBER = 2

    # Connectivity from Cloud DNS to forwarding targets or alternate name
    # servers that use private routing.
    # https://cloud.google.com/dns/docs/zones/forwarding-zones#firewall-rules
    # https://cloud.google.com/dns/docs/policies#firewall-rules
    CLOUD_DNS = 3

    # private.googleapis.com and restricted.googleapis.com
    PRIVATE_GOOGLE_ACCESS = 4

    # Google API via Private Service Connect.
    # https://cloud.google.com/vpc/docs/configure-private-service-connect-apis
    # Google API via Serverless VPC Access.
    # https://cloud.google.com/vpc/docs/serverless-vpc-access
    SERVERLESS_VPC_ACCESS = 5
  end
end

#target::Google::Cloud::NetworkManagement::V1::DeliverInfo::Target

Returns Target type where the packet is delivered to.

Returns:



1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1222

class DeliverInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Deliver target types:
  module Target
    # Target not specified.
    TARGET_UNSPECIFIED = 0

    # Target is a Compute Engine instance.
    INSTANCE = 1

    # Target is the internet.
    INTERNET = 2

    # Target is a Google API.
    GOOGLE_API = 3

    # Target is a Google Kubernetes Engine cluster master.
    GKE_MASTER = 4

    # Target is a Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 5

    # Target is a published service that uses [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-services).
    PSC_PUBLISHED_SERVICE = 6

    # Target is Google APIs that use [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-apis).
    PSC_GOOGLE_API = 7

    # Target is a VPC-SC that uses [Private Service
    # Connect](https://cloud.google.com/vpc/docs/configure-private-service-connect-apis).
    PSC_VPC_SC = 8

    # Target is a serverless network endpoint group.
    SERVERLESS_NEG = 9

    # Target is a Cloud Storage bucket.
    STORAGE_BUCKET = 10

    # Target is a private network. Used only for return traces.
    PRIVATE_NETWORK = 11

    # Target is a Cloud Function. Used only for return traces.
    CLOUD_FUNCTION = 12

    # Target is a App Engine service version. Used only for return traces.
    APP_ENGINE_VERSION = 13

    # Target is a Cloud Run revision. Used only for return traces.
    CLOUD_RUN_REVISION = 14

    # Target is a Google-managed service. Used only for return traces.
    GOOGLE_MANAGED_SERVICE = 15

    # Target is a Redis Instance.
    REDIS_INSTANCE = 16

    # Target is a Redis Cluster.
    REDIS_CLUSTER = 17

    # Target is a GKE Pod.
    GKE_POD = 19
  end

  # Recognized type of a Google Service.
  module GoogleServiceType
    # Unspecified Google Service.
    GOOGLE_SERVICE_TYPE_UNSPECIFIED = 0

    # Identity aware proxy.
    # https://cloud.google.com/iap/docs/using-tcp-forwarding
    IAP = 1

    # One of two services sharing IP ranges:
    # * Load Balancer proxy
    # * Centralized Health Check prober
    # https://cloud.google.com/load-balancing/docs/firewall-rules
    GFE_PROXY_OR_HEALTH_CHECK_PROBER = 2

    # Connectivity from Cloud DNS to forwarding targets or alternate name
    # servers that use private routing.
    # https://cloud.google.com/dns/docs/zones/forwarding-zones#firewall-rules
    # https://cloud.google.com/dns/docs/policies#firewall-rules
    CLOUD_DNS = 3

    # private.googleapis.com and restricted.googleapis.com
    PRIVATE_GOOGLE_ACCESS = 4

    # Google API via Private Service Connect.
    # https://cloud.google.com/vpc/docs/configure-private-service-connect-apis
    # Google API via Serverless VPC Access.
    # https://cloud.google.com/vpc/docs/serverless-vpc-access
    SERVERLESS_VPC_ACCESS = 5
  end
end