Class: Google::Cloud::NetworkManagement::V1::EndpointInfo
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::EndpointInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/trace.rb
Overview
For display only. The specification of the endpoints for the test. EndpointInfo is derived from source and destination Endpoint and validated by the backend data plane model.
Instance Attribute Summary collapse
-
#destination_ip ⇒ ::String
Destination IP address.
-
#destination_network_uri ⇒ ::String
URI of the network where this packet is sent to.
-
#destination_port ⇒ ::Integer
Destination port.
-
#protocol ⇒ ::String
IP protocol in string format, for example: "TCP", "UDP", "ICMP".
-
#source_agent_uri ⇒ ::String
URI of the source telemetry agent this packet originates from.
-
#source_ip ⇒ ::String
Source IP address.
-
#source_network_uri ⇒ ::String
URI of the network where this packet originates from.
-
#source_port ⇒ ::Integer
Source port.
Instance Attribute Details
#destination_ip ⇒ ::String
Returns Destination IP address.
1213 1214 1215 1216 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1213 class EndpointInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destination_network_uri ⇒ ::String
Returns URI of the network where this packet is sent to.
1213 1214 1215 1216 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1213 class EndpointInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destination_port ⇒ ::Integer
Returns Destination port. Only valid when protocol is TCP or UDP.
1213 1214 1215 1216 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1213 class EndpointInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#protocol ⇒ ::String
Returns IP protocol in string format, for example: "TCP", "UDP", "ICMP".
1213 1214 1215 1216 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1213 class EndpointInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_agent_uri ⇒ ::String
Returns URI of the source telemetry agent this packet originates from.
1213 1214 1215 1216 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1213 class EndpointInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_ip ⇒ ::String
Returns Source IP address.
1213 1214 1215 1216 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1213 class EndpointInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_network_uri ⇒ ::String
Returns URI of the network where this packet originates from.
1213 1214 1215 1216 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1213 class EndpointInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_port ⇒ ::Integer
Returns Source port. Only valid when protocol is TCP or UDP.
1213 1214 1215 1216 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1213 class EndpointInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |