Class: Google::Cloud::NetworkManagement::V1::GkeNetworkPolicyInfo
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::GkeNetworkPolicyInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/trace.rb
Overview
For display only. Metadata associated with a GKE Network Policy.
Instance Attribute Summary collapse
-
#action ⇒ ::String
Possible values: ALLOW, DENY.
-
#direction ⇒ ::String
Possible values: INGRESS, EGRESS.
-
#display_name ⇒ ::String
The name of the Network Policy.
-
#uri ⇒ ::String
The URI of the Network Policy.
Instance Attribute Details
#action ⇒ ::String
Returns Possible values: ALLOW, DENY.
2120 2121 2122 2123 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2120 class GkeNetworkPolicyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#direction ⇒ ::String
Returns Possible values: INGRESS, EGRESS.
2120 2121 2122 2123 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2120 class GkeNetworkPolicyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns The name of the Network Policy.
2120 2121 2122 2123 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2120 class GkeNetworkPolicyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#uri ⇒ ::String
Returns The URI of the Network Policy.
Format for a Network Policy in a zonal cluster:
projects/<project_id>/zones/<zone>/clusters/<cluster>/k8s/namespaces/<namespace>/networking.k8s.io/networkpolicies/<networkpolicy>
Format for a Network Policy in a regional cluster:
projects/<project_id>/locations/<location>/clusters/<cluster>/k8s/namespaces/<namespace>/networking.k8s.io/networkpolicies/<networkpolicy>.
2120 2121 2122 2123 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2120 class GkeNetworkPolicyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |