Module: Google::Cloud::NetworkManagement::V1::GkeNetworkPolicySkippedInfo::Reason

Defined in:
proto_docs/google/cloud/networkmanagement/v1/trace.rb

Constant Summary collapse

REASON_UNSPECIFIED =

Unused default value.

0
NETWORK_POLICY_DISABLED =

Network Policy is disabled on the cluster.

1
INGRESS_SOURCE_ON_SAME_NODE =

Ingress traffic to a Pod from a source on the same Node is always allowed.

2
EGRESS_FROM_NODE_NETWORK_NAMESPACE_POD =

Egress traffic from a Pod that uses the Node's network namespace is not subject to Network Policy.

3
NETWORK_POLICY_NOT_APPLIED_TO_RESPONSE_TRAFFIC =

Network Policy is not applied to response traffic. This is because GKE Network Policy evaluation is stateful in both GKE Dataplane V2 (eBPF) and legacy (iptables) implementations.

4
NETWORK_POLICY_ANALYSIS_UNSUPPORTED =

Network Policy evaluation is currently not supported for clusters with FQDN Network Policies enabled.

100