Class: Google::Cloud::NetworkManagement::V1::InstanceInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkmanagement/v1/trace.rb

Overview

For display only. Metadata associated with a Compute Engine instance.

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String

Returns Name of a Compute Engine instance.

Returns:

  • (::String)

    Name of a Compute Engine instance.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 476

class InstanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the instance. We treat all states other than "RUNNING" as
  # not running.
  module Status
    # Default unspecified value.
    STATUS_UNSPECIFIED = 0

    # The instance is running.
    RUNNING = 1

    # The instance has any status other than "RUNNING".
    NOT_RUNNING = 2
  end
end

#external_ip::String

Returns External IP address of the network interface.

Returns:

  • (::String)

    External IP address of the network interface.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 476

class InstanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the instance. We treat all states other than "RUNNING" as
  # not running.
  module Status
    # Default unspecified value.
    STATUS_UNSPECIFIED = 0

    # The instance is running.
    RUNNING = 1

    # The instance has any status other than "RUNNING".
    NOT_RUNNING = 2
  end
end

#interface::String

Returns Name of the network interface of a Compute Engine instance.

Returns:

  • (::String)

    Name of the network interface of a Compute Engine instance.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 476

class InstanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the instance. We treat all states other than "RUNNING" as
  # not running.
  module Status
    # Default unspecified value.
    STATUS_UNSPECIFIED = 0

    # The instance is running.
    RUNNING = 1

    # The instance has any status other than "RUNNING".
    NOT_RUNNING = 2
  end
end

#internal_ip::String

Returns Internal IP address of the network interface.

Returns:

  • (::String)

    Internal IP address of the network interface.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 476

class InstanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the instance. We treat all states other than "RUNNING" as
  # not running.
  module Status
    # Default unspecified value.
    STATUS_UNSPECIFIED = 0

    # The instance is running.
    RUNNING = 1

    # The instance has any status other than "RUNNING".
    NOT_RUNNING = 2
  end
end

#network_tags::Array<::String>

Returns Network tags configured on the instance.

Returns:

  • (::Array<::String>)

    Network tags configured on the instance.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 476

class InstanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the instance. We treat all states other than "RUNNING" as
  # not running.
  module Status
    # Default unspecified value.
    STATUS_UNSPECIFIED = 0

    # The instance is running.
    RUNNING = 1

    # The instance has any status other than "RUNNING".
    NOT_RUNNING = 2
  end
end

#network_uri::String

Returns URI of a Compute Engine network.

Returns:

  • (::String)

    URI of a Compute Engine network.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 476

class InstanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the instance. We treat all states other than "RUNNING" as
  # not running.
  module Status
    # Default unspecified value.
    STATUS_UNSPECIFIED = 0

    # The instance is running.
    RUNNING = 1

    # The instance has any status other than "RUNNING".
    NOT_RUNNING = 2
  end
end

#psc_network_attachment_uri::String

Returns URI of the PSC network attachment the NIC is attached to (if relevant).

Returns:

  • (::String)

    URI of the PSC network attachment the NIC is attached to (if relevant).



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 476

class InstanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the instance. We treat all states other than "RUNNING" as
  # not running.
  module Status
    # Default unspecified value.
    STATUS_UNSPECIFIED = 0

    # The instance is running.
    RUNNING = 1

    # The instance has any status other than "RUNNING".
    NOT_RUNNING = 2
  end
end

#running::Boolean

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Indicates whether the Compute Engine instance is running. Deprecated: use the status field instead.

Returns:

  • (::Boolean)

    Indicates whether the Compute Engine instance is running. Deprecated: use the status field instead.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 476

class InstanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the instance. We treat all states other than "RUNNING" as
  # not running.
  module Status
    # Default unspecified value.
    STATUS_UNSPECIFIED = 0

    # The instance is running.
    RUNNING = 1

    # The instance has any status other than "RUNNING".
    NOT_RUNNING = 2
  end
end

#service_account::String

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Service account authorized for the instance.

Returns:

  • (::String)

    Service account authorized for the instance.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 476

class InstanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the instance. We treat all states other than "RUNNING" as
  # not running.
  module Status
    # Default unspecified value.
    STATUS_UNSPECIFIED = 0

    # The instance is running.
    RUNNING = 1

    # The instance has any status other than "RUNNING".
    NOT_RUNNING = 2
  end
end

#status::Google::Cloud::NetworkManagement::V1::InstanceInfo::Status

Returns The status of the instance.

Returns:



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 476

class InstanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the instance. We treat all states other than "RUNNING" as
  # not running.
  module Status
    # Default unspecified value.
    STATUS_UNSPECIFIED = 0

    # The instance is running.
    RUNNING = 1

    # The instance has any status other than "RUNNING".
    NOT_RUNNING = 2
  end
end

#uri::String

Returns URI of a Compute Engine instance.

Returns:

  • (::String)

    URI of a Compute Engine instance.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 476

class InstanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the instance. We treat all states other than "RUNNING" as
  # not running.
  module Status
    # Default unspecified value.
    STATUS_UNSPECIFIED = 0

    # The instance is running.
    RUNNING = 1

    # The instance has any status other than "RUNNING".
    NOT_RUNNING = 2
  end
end