Class: Google::Cloud::NetworkManagement::V1::InterconnectAttachmentInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkmanagement/v1/trace.rb

Overview

For display only. Metadata associated with an Interconnect attachment.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_router_uri::String

Returns URI of the Cloud Router to be used for dynamic routing.

Returns:

  • (::String)

    URI of the Cloud Router to be used for dynamic routing.



1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1163

class InterconnectAttachmentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # What type of interconnect attachment this is.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # Attachment to a dedicated interconnect.
    DEDICATED = 1

    # Attachment to a partner interconnect, created by the customer.
    PARTNER = 2

    # Attachment to a partner interconnect, created by the partner.
    PARTNER_PROVIDER = 3

    # Attachment to a L2 interconnect, created by the customer.
    L2_DEDICATED = 4
  end
end

#display_name::String

Returns Name of an Interconnect attachment.

Returns:

  • (::String)

    Name of an Interconnect attachment.



1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1163

class InterconnectAttachmentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # What type of interconnect attachment this is.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # Attachment to a dedicated interconnect.
    DEDICATED = 1

    # Attachment to a partner interconnect, created by the customer.
    PARTNER = 2

    # Attachment to a partner interconnect, created by the partner.
    PARTNER_PROVIDER = 3

    # Attachment to a L2 interconnect, created by the customer.
    L2_DEDICATED = 4
  end
end

#interconnect_uri::String

Returns URI of the Interconnect where the Interconnect attachment is configured.

Returns:

  • (::String)

    URI of the Interconnect where the Interconnect attachment is configured.



1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1163

class InterconnectAttachmentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # What type of interconnect attachment this is.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # Attachment to a dedicated interconnect.
    DEDICATED = 1

    # Attachment to a partner interconnect, created by the customer.
    PARTNER = 2

    # Attachment to a partner interconnect, created by the partner.
    PARTNER_PROVIDER = 3

    # Attachment to a L2 interconnect, created by the customer.
    L2_DEDICATED = 4
  end
end

#l2_attachment_matched_ip_address::String

Returns Appliance IP address that was matched for L2_DEDICATED attachments.

Returns:

  • (::String)

    Appliance IP address that was matched for L2_DEDICATED attachments.



1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1163

class InterconnectAttachmentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # What type of interconnect attachment this is.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # Attachment to a dedicated interconnect.
    DEDICATED = 1

    # Attachment to a partner interconnect, created by the customer.
    PARTNER = 2

    # Attachment to a partner interconnect, created by the partner.
    PARTNER_PROVIDER = 3

    # Attachment to a L2 interconnect, created by the customer.
    L2_DEDICATED = 4
  end
end

#region::String

Returns Name of a Google Cloud region where the Interconnect attachment is configured.

Returns:

  • (::String)

    Name of a Google Cloud region where the Interconnect attachment is configured.



1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1163

class InterconnectAttachmentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # What type of interconnect attachment this is.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # Attachment to a dedicated interconnect.
    DEDICATED = 1

    # Attachment to a partner interconnect, created by the customer.
    PARTNER = 2

    # Attachment to a partner interconnect, created by the partner.
    PARTNER_PROVIDER = 3

    # Attachment to a L2 interconnect, created by the customer.
    L2_DEDICATED = 4
  end
end

#type::Google::Cloud::NetworkManagement::V1::InterconnectAttachmentInfo::Type

Returns The type of interconnect attachment this is.

Returns:



1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1163

class InterconnectAttachmentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # What type of interconnect attachment this is.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # Attachment to a dedicated interconnect.
    DEDICATED = 1

    # Attachment to a partner interconnect, created by the customer.
    PARTNER = 2

    # Attachment to a partner interconnect, created by the partner.
    PARTNER_PROVIDER = 3

    # Attachment to a L2 interconnect, created by the customer.
    L2_DEDICATED = 4
  end
end

#uri::String

Returns URI of an Interconnect attachment.

Returns:

  • (::String)

    URI of an Interconnect attachment.



1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1163

class InterconnectAttachmentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # What type of interconnect attachment this is.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # Attachment to a dedicated interconnect.
    DEDICATED = 1

    # Attachment to a partner interconnect, created by the customer.
    PARTNER = 2

    # Attachment to a partner interconnect, created by the partner.
    PARTNER_PROVIDER = 3

    # Attachment to a L2 interconnect, created by the customer.
    L2_DEDICATED = 4
  end
end