Class: Google::Cloud::NetworkManagement::V1::ListVpcFlowLogsConfigsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb

Overview

Request for the ListVpcFlowLogsConfigs method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Lists the VpcFlowLogsConfigs that match the filter expression. A filter expression must use the supported CEL logic operators.

Returns:

  • (::String)

    Optional. Lists the VpcFlowLogsConfigs that match the filter expression. A filter expression must use the supported CEL logic operators.



49
50
51
52
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 49

class ListVpcFlowLogsConfigsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Field to use to sort the list.

Returns:

  • (::String)

    Optional. Field to use to sort the list.



49
50
51
52
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 49

class ListVpcFlowLogsConfigsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Number of VpcFlowLogsConfigs to return.

Returns:

  • (::Integer)

    Optional. Number of VpcFlowLogsConfigs to return.



49
50
51
52
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 49

class ListVpcFlowLogsConfigsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. Page token from an earlier query, as returned in next_page_token.

Returns:

  • (::String)

    Optional. Page token from an earlier query, as returned in next_page_token.



49
50
51
52
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 49

class ListVpcFlowLogsConfigsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource of the VpcFlowLogsConfig, in one of the following formats:

  • For project-level resources: projects/{project_id}/locations/global

  • For organization-level resources: organizations/{organization_id}/locations/global.

Returns:

  • (::String)

    Required. The parent resource of the VpcFlowLogsConfig, in one of the following formats:

    • For project-level resources: projects/{project_id}/locations/global

    • For organization-level resources: organizations/{organization_id}/locations/global



49
50
51
52
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 49

class ListVpcFlowLogsConfigsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end