Class: Google::Cloud::NetworkManagement::V1::LoadBalancerBackend
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::LoadBalancerBackend
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/trace.rb
Overview
For display only. Metadata associated with a specific load balancer backend.
Defined Under Namespace
Modules: HealthCheckFirewallState
Instance Attribute Summary collapse
-
#display_name ⇒ ::String
Name of a Compute Engine instance or network endpoint.
-
#health_check_allowing_firewall_rules ⇒ ::Array<::String>
A list of firewall rule URIs allowing probes from health check IP ranges.
-
#health_check_blocking_firewall_rules ⇒ ::Array<::String>
A list of firewall rule URIs blocking probes from health check IP ranges.
-
#health_check_firewall_state ⇒ ::Google::Cloud::NetworkManagement::V1::LoadBalancerBackend::HealthCheckFirewallState
State of the health check firewall configuration.
-
#uri ⇒ ::String
URI of a Compute Engine instance or network endpoint.
Instance Attribute Details
#display_name ⇒ ::String
Returns Name of a Compute Engine instance or network endpoint.
1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1008 class LoadBalancerBackend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # State of a health check firewall configuration: module HealthCheckFirewallState # State is unspecified. Default state if not populated. HEALTH_CHECK_FIREWALL_STATE_UNSPECIFIED = 0 # There are configured firewall rules to allow health check probes to the # backend. CONFIGURED = 1 # There are firewall rules configured to allow partial health check ranges # or block all health check ranges. # If a health check probe is sent from denied IP ranges, # the health check to the backend will fail. Then, the backend will be # marked unhealthy and will not receive traffic sent to the load balancer. MISCONFIGURED = 2 end end |
#health_check_allowing_firewall_rules ⇒ ::Array<::String>
Returns A list of firewall rule URIs allowing probes from health check IP ranges.
1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1008 class LoadBalancerBackend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # State of a health check firewall configuration: module HealthCheckFirewallState # State is unspecified. Default state if not populated. HEALTH_CHECK_FIREWALL_STATE_UNSPECIFIED = 0 # There are configured firewall rules to allow health check probes to the # backend. CONFIGURED = 1 # There are firewall rules configured to allow partial health check ranges # or block all health check ranges. # If a health check probe is sent from denied IP ranges, # the health check to the backend will fail. Then, the backend will be # marked unhealthy and will not receive traffic sent to the load balancer. MISCONFIGURED = 2 end end |
#health_check_blocking_firewall_rules ⇒ ::Array<::String>
Returns A list of firewall rule URIs blocking probes from health check IP ranges.
1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1008 class LoadBalancerBackend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # State of a health check firewall configuration: module HealthCheckFirewallState # State is unspecified. Default state if not populated. HEALTH_CHECK_FIREWALL_STATE_UNSPECIFIED = 0 # There are configured firewall rules to allow health check probes to the # backend. CONFIGURED = 1 # There are firewall rules configured to allow partial health check ranges # or block all health check ranges. # If a health check probe is sent from denied IP ranges, # the health check to the backend will fail. Then, the backend will be # marked unhealthy and will not receive traffic sent to the load balancer. MISCONFIGURED = 2 end end |
#health_check_firewall_state ⇒ ::Google::Cloud::NetworkManagement::V1::LoadBalancerBackend::HealthCheckFirewallState
Returns State of the health check firewall configuration.
1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1008 class LoadBalancerBackend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # State of a health check firewall configuration: module HealthCheckFirewallState # State is unspecified. Default state if not populated. HEALTH_CHECK_FIREWALL_STATE_UNSPECIFIED = 0 # There are configured firewall rules to allow health check probes to the # backend. CONFIGURED = 1 # There are firewall rules configured to allow partial health check ranges # or block all health check ranges. # If a health check probe is sent from denied IP ranges, # the health check to the backend will fail. Then, the backend will be # marked unhealthy and will not receive traffic sent to the load balancer. MISCONFIGURED = 2 end end |
#uri ⇒ ::String
Returns URI of a Compute Engine instance or network endpoint.
1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1008 class LoadBalancerBackend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # State of a health check firewall configuration: module HealthCheckFirewallState # State is unspecified. Default state if not populated. HEALTH_CHECK_FIREWALL_STATE_UNSPECIFIED = 0 # There are configured firewall rules to allow health check probes to the # backend. CONFIGURED = 1 # There are firewall rules configured to allow partial health check ranges # or block all health check ranges. # If a health check probe is sent from denied IP ranges, # the health check to the backend will fail. Then, the backend will be # marked unhealthy and will not receive traffic sent to the load balancer. MISCONFIGURED = 2 end end |