Module: Google::Cloud::NetworkManagement::V1::OrganizationVpcFlowLogsService

Defined in:
lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service.rb,
lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/rest.rb,
lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/paths.rb,
lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb,
lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/operations.rb,
lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/credentials.rb,
lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/rest/client.rb,
lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/rest/operations.rb,
lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/rest/service_stub.rb

Overview

The VPC Flow Logs organization service in the Google Cloud Network Management API provides organization level configurations that generate Flow Logs. The service and the configuration resources created using this service are global.

To load this service and instantiate a REST client:

require "google/cloud/network_management/v1/organization_vpc_flow_logs_service/rest"
client = ::Google::Cloud::NetworkManagement::V1::OrganizationVpcFlowLogsService::Rest::Client.new

Defined Under Namespace

Modules: Paths, Rest Classes: Client, Credentials, Operations