Class: Google::Cloud::NetworkManagement::V1::OrganizationVpcFlowLogsService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb

Overview

Client for the OrganizationVpcFlowLogsService service.

The VPC Flow Logs organization service in the Google Cloud Network Management API provides organization level configurations that generate Flow Logs. The service and the configuration resources created using this service are global.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#location_path, #organization_location_path, #vpc_flow_logs_config_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new OrganizationVpcFlowLogsService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::NetworkManagement::V1::OrganizationVpcFlowLogsService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::NetworkManagement::V1::OrganizationVpcFlowLogsService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the OrganizationVpcFlowLogsService client.

Yield Parameters:



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb', line 129

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/networkmanagement/v1/vpc_flow_logs_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @operations_client = Operations.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config.endpoint
    config.universe_domain = @config.universe_domain
  end

  @organization_vpc_flow_logs_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::NetworkManagement::V1::OrganizationVpcFlowLogsService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @organization_vpc_flow_logs_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @organization_vpc_flow_logs_service_stub.endpoint
    config.universe_domain = @organization_vpc_flow_logs_service_stub.universe_domain
    config.logger = @organization_vpc_flow_logs_service_stub.logger if config.respond_to? :logger=
  end

  @iam_policy_client = Google::Iam::V1::IAMPolicy::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @organization_vpc_flow_logs_service_stub.endpoint
    config.universe_domain = @organization_vpc_flow_logs_service_stub.universe_domain
    config.logger = @organization_vpc_flow_logs_service_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#iam_policy_clientGoogle::Iam::V1::IAMPolicy::Client (readonly)

Get the associated client for mix-in of the IAMPolicy.

Returns:

  • (Google::Iam::V1::IAMPolicy::Client)


222
223
224
# File 'lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb', line 222

def iam_policy_client
  @iam_policy_client
end

#location_clientGoogle::Cloud::Location::Locations::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Client)


215
216
217
# File 'lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb', line 215

def location_client
  @location_client
end

#operations_client::Google::Cloud::NetworkManagement::V1::OrganizationVpcFlowLogsService::Operations (readonly)

Get the associated client for long-running operations.



208
209
210
# File 'lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb', line 208

def operations_client
  @operations_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the OrganizationVpcFlowLogsService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all OrganizationVpcFlowLogsService clients
::Google::Cloud::NetworkManagement::V1::OrganizationVpcFlowLogsService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb', line 67

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "NetworkManagement", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the OrganizationVpcFlowLogsService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



99
100
101
102
# File 'lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb', line 99

def configure
  yield @config if block_given?
  @config
end

#create_vpc_flow_logs_config(request, options = nil) ⇒ ::Gapic::Operation #create_vpc_flow_logs_config(parent: nil, vpc_flow_logs_config_id: nil, vpc_flow_logs_config: nil) ⇒ ::Gapic::Operation

Creates a new VpcFlowLogsConfig. If a configuration with the exact same settings already exists (even if the ID is different), the creation fails. Notes:

  1. Creating a configuration with state=DISABLED will fail
  2. The following fields are not considered as settings for the purpose of the check mentioned above, therefore - creating another configuration with the same fields but different values for the following fields will fail as well:
    • name
    • create_time
    • update_time
    • labels
    • description

Examples:

Basic example

require "google/cloud/network_management/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::NetworkManagement::V1::OrganizationVpcFlowLogsService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::NetworkManagement::V1::CreateVpcFlowLogsConfigRequest.new

# Call the create_vpc_flow_logs_config method.
result = client.create_vpc_flow_logs_config request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #create_vpc_flow_logs_config(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to create_vpc_flow_logs_config via a request object, either of type CreateVpcFlowLogsConfigRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::NetworkManagement::V1::CreateVpcFlowLogsConfigRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_vpc_flow_logs_config(parent: nil, vpc_flow_logs_config_id: nil, vpc_flow_logs_config: nil) ⇒ ::Gapic::Operation

    Pass arguments to create_vpc_flow_logs_config via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource of the VpcFlowLogsConfig to create, in one of the following formats:

      • For project-level resources: projects/{project_id}/locations/global

      • For organization-level resources: organizations/{organization_id}/locations/global

    • vpc_flow_logs_config_id (::String) (defaults to: nil)

      Required. ID of the VpcFlowLogsConfig.

    • vpc_flow_logs_config (::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig, ::Hash) (defaults to: nil)

      Required. A VpcFlowLogsConfig resource

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

  • response (::Gapic::Operation)
  • operation (::GRPC::ActiveCall::Operation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
# File 'lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb', line 510

def create_vpc_flow_logs_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::CreateVpcFlowLogsConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_vpc_flow_logs_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_vpc_flow_logs_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_vpc_flow_logs_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @organization_vpc_flow_logs_service_stub.call_rpc :create_vpc_flow_logs_config, request, options: options do |response, operation|
    response = ::Gapic::Operation.new response, @operations_client, options: options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_vpc_flow_logs_config(request, options = nil) ⇒ ::Gapic::Operation #delete_vpc_flow_logs_config(name: nil) ⇒ ::Gapic::Operation

Deletes a specific VpcFlowLogsConfig.

Examples:

Basic example

require "google/cloud/network_management/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::NetworkManagement::V1::OrganizationVpcFlowLogsService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::NetworkManagement::V1::DeleteVpcFlowLogsConfigRequest.new

# Call the delete_vpc_flow_logs_config method.
result = client.delete_vpc_flow_logs_config request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #delete_vpc_flow_logs_config(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to delete_vpc_flow_logs_config via a request object, either of type DeleteVpcFlowLogsConfigRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::NetworkManagement::V1::DeleteVpcFlowLogsConfigRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_vpc_flow_logs_config(name: nil) ⇒ ::Gapic::Operation

    Pass arguments to delete_vpc_flow_logs_config via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The resource name of the VpcFlowLogsConfig, in one of the following formats:

      • For a project-level resource: projects/{project_id}/locations/global/vpcFlowLogsConfigs/{vpc_flow_logs_config_id}

      • For an organization-level resource: organizations/{organization_id}/locations/global/vpcFlowLogsConfigs/{vpc_flow_logs_config_id}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

  • response (::Gapic::Operation)
  • operation (::GRPC::ActiveCall::Operation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
# File 'lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb', line 728

def delete_vpc_flow_logs_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::DeleteVpcFlowLogsConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_vpc_flow_logs_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_vpc_flow_logs_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_vpc_flow_logs_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @organization_vpc_flow_logs_service_stub.call_rpc :delete_vpc_flow_logs_config, request, options: options do |response, operation|
    response = ::Gapic::Operation.new response, @operations_client, options: options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_vpc_flow_logs_config(request, options = nil) ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig #get_vpc_flow_logs_config(name: nil) ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig

Gets the details of a specific VpcFlowLogsConfig.

Examples:

Basic example

require "google/cloud/network_management/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::NetworkManagement::V1::OrganizationVpcFlowLogsService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::NetworkManagement::V1::GetVpcFlowLogsConfigRequest.new

# Call the get_vpc_flow_logs_config method.
result = client.get_vpc_flow_logs_config request

# The returned object is of type Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig.
p result

Overloads:

  • #get_vpc_flow_logs_config(request, options = nil) ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig

    Pass arguments to get_vpc_flow_logs_config via a request object, either of type GetVpcFlowLogsConfigRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::NetworkManagement::V1::GetVpcFlowLogsConfigRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_vpc_flow_logs_config(name: nil) ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig

    Pass arguments to get_vpc_flow_logs_config via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The resource name of the VpcFlowLogsConfig, in one of the following formats:

      • For project-level resources: projects/{project_id}/locations/global/vpcFlowLogsConfigs/{vpc_flow_logs_config_id}

      • For organization-level resources: organizations/{organization_id}/locations/global/vpcFlowLogsConfigs/{vpc_flow_logs_config_id}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb', line 394

def get_vpc_flow_logs_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::GetVpcFlowLogsConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_vpc_flow_logs_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_vpc_flow_logs_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_vpc_flow_logs_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @organization_vpc_flow_logs_service_stub.call_rpc :get_vpc_flow_logs_config, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_vpc_flow_logs_configs(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig> #list_vpc_flow_logs_configs(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig>

Lists all VpcFlowLogsConfigs in a given organization.

Examples:

Basic example

require "google/cloud/network_management/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::NetworkManagement::V1::OrganizationVpcFlowLogsService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::NetworkManagement::V1::ListVpcFlowLogsConfigsRequest.new

# Call the list_vpc_flow_logs_configs method.
result = client.list_vpc_flow_logs_configs request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig.
  p item
end

Overloads:

  • #list_vpc_flow_logs_configs(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig>

    Pass arguments to list_vpc_flow_logs_configs via a request object, either of type ListVpcFlowLogsConfigsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::NetworkManagement::V1::ListVpcFlowLogsConfigsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_vpc_flow_logs_configs(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig>

    Pass arguments to list_vpc_flow_logs_configs via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource of the VpcFlowLogsConfig, in one of the following formats:

      • For project-level resources: projects/{project_id}/locations/global

      • For organization-level resources: organizations/{organization_id}/locations/global

    • page_size (::Integer) (defaults to: nil)

      Optional. Number of VpcFlowLogsConfigs to return.

    • page_token (::String) (defaults to: nil)

      Optional. Page token from an earlier query, as returned in next_page_token.

    • filter (::String) (defaults to: nil)

      Optional. Lists the VpcFlowLogsConfigs that match the filter expression. A filter expression must use the supported CEL logic operators.

    • order_by (::String) (defaults to: nil)

      Optional. Field to use to sort the list.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb', line 300

def list_vpc_flow_logs_configs request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::ListVpcFlowLogsConfigsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_vpc_flow_logs_configs..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_vpc_flow_logs_configs.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_vpc_flow_logs_configs.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @organization_vpc_flow_logs_service_stub.call_rpc :list_vpc_flow_logs_configs, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @organization_vpc_flow_logs_service_stub, :list_vpc_flow_logs_configs, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


229
230
231
# File 'lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb', line 229

def logger
  @organization_vpc_flow_logs_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


109
110
111
# File 'lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb', line 109

def universe_domain
  @organization_vpc_flow_logs_service_stub.universe_domain
end

#update_vpc_flow_logs_config(request, options = nil) ⇒ ::Gapic::Operation #update_vpc_flow_logs_config(update_mask: nil, vpc_flow_logs_config: nil) ⇒ ::Gapic::Operation

Updates an existing VpcFlowLogsConfig. If a configuration with the exact same settings already exists (even if the ID is different), the creation fails. Notes:

  1. Updating a configuration with state=DISABLED will fail
  2. The following fields are not considered as settings for the purpose of the check mentioned above, therefore - updating another configuration with the same fields but different values for the following fields will fail as well:
    • name
    • create_time
    • update_time
    • labels
    • description

Examples:

Basic example

require "google/cloud/network_management/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::NetworkManagement::V1::OrganizationVpcFlowLogsService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::NetworkManagement::V1::UpdateVpcFlowLogsConfigRequest.new

# Call the update_vpc_flow_logs_config method.
result = client.update_vpc_flow_logs_config request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #update_vpc_flow_logs_config(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to update_vpc_flow_logs_config via a request object, either of type UpdateVpcFlowLogsConfigRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::NetworkManagement::V1::UpdateVpcFlowLogsConfigRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_vpc_flow_logs_config(update_mask: nil, vpc_flow_logs_config: nil) ⇒ ::Gapic::Operation

    Pass arguments to update_vpc_flow_logs_config via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Required. Mask of fields to update. At least one path must be supplied in this field. For example, to change the state of the configuration to ENABLED, specify update_mask = "state", and the vpc_flow_logs_config would be: vpc_flow_logs_config = { name = "projects/my-project/locations/global/vpcFlowLogsConfigs/my-config" state = "ENABLED" }

    • vpc_flow_logs_config (::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig, ::Hash) (defaults to: nil)

      Required. Only fields specified in update_mask are updated.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

  • response (::Gapic::Operation)
  • operation (::GRPC::ActiveCall::Operation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
# File 'lib/google/cloud/network_management/v1/organization_vpc_flow_logs_service/client.rb', line 627

def update_vpc_flow_logs_config request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::UpdateVpcFlowLogsConfigRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_vpc_flow_logs_config..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.vpc_flow_logs_config&.name
    header_params["vpc_flow_logs_config.name"] = request.vpc_flow_logs_config.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_vpc_flow_logs_config.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_vpc_flow_logs_config.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @organization_vpc_flow_logs_service_stub.call_rpc :update_vpc_flow_logs_config, request, options: options do |response, operation|
    response = ::Gapic::Operation.new response, @operations_client, options: options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end