Class: Google::Cloud::NetworkManagement::V1::ProbingDetails::SingleEdgeResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb

Overview

Probing results for a single edge device.

Instance Attribute Summary collapse

Instance Attribute Details

#destination_egress_location::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation

Returns The EdgeLocation from which a packet, destined to the internet, will egress the Google network. This will only be populated for a connectivity test which has an internet destination address. The absence of this field must not be used as an indication that the destination is part of the Google network.

Returns:

  • (::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation)

    The EdgeLocation from which a packet, destined to the internet, will egress the Google network. This will only be populated for a connectivity test which has an internet destination address. The absence of this field must not be used as an indication that the destination is part of the Google network.



460
461
462
463
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 460

class SingleEdgeResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#destination_router::String

Returns Router name in the format '{router}.{metroshard}'. For example: pf01.aaa01, pr02.aaa01.

Returns:

  • (::String)

    Router name in the format '{router}.{metroshard}'. For example: pf01.aaa01, pr02.aaa01.



460
461
462
463
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 460

class SingleEdgeResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#probing_latency::Google::Cloud::NetworkManagement::V1::LatencyDistribution

Returns Latency as measured by active probing in one direction: from the source to the destination endpoint.

Returns:



460
461
462
463
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 460

class SingleEdgeResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#result::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult

Returns The overall result of active probing for this egress device.

Returns:



460
461
462
463
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 460

class SingleEdgeResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sent_probe_count::Integer

Returns Number of probes sent.

Returns:

  • (::Integer)

    Number of probes sent.



460
461
462
463
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 460

class SingleEdgeResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#successful_probe_count::Integer

Returns Number of probes that reached the destination.

Returns:

  • (::Integer)

    Number of probes that reached the destination.



460
461
462
463
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 460

class SingleEdgeResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end