Class: Google::Cloud::NetworkManagement::V1::QueryOrgVpcFlowLogsConfigsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb

Overview

Request for the QueryOrgVpcFlowLogsConfigs method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Lists the VpcFlowLogsConfigs that match the filter expression. A filter expression must use the supported CEL logic operators.

Returns:

  • Optional. Lists the VpcFlowLogsConfigs that match the filter expression. A filter expression must use the supported CEL logic operators.



158
159
160
161
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 158

class QueryOrgVpcFlowLogsConfigsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Number of VpcFlowLogsConfigs to return.

Returns:

  • Optional. Number of VpcFlowLogsConfigs to return.



158
159
160
161
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 158

class QueryOrgVpcFlowLogsConfigsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. Page token from an earlier query, as returned in next_page_token.

Returns:

  • Optional. Page token from an earlier query, as returned in next_page_token.



158
159
160
161
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 158

class QueryOrgVpcFlowLogsConfigsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource of the VpcFlowLogsConfig, specified in the following format: projects/{project_id}/locations/global.

Returns:

  • Required. The parent resource of the VpcFlowLogsConfig, specified in the following format: projects/{project_id}/locations/global



158
159
160
161
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 158

class QueryOrgVpcFlowLogsConfigsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end