Class: Google::Cloud::NetworkManagement::V1::ShowEffectiveFlowLogsConfigsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb

Overview

Response for the ShowEffectiveFlowLogsConfigs method.

Instance Attribute Summary collapse

Instance Attribute Details

#effective_flow_logs_configs::Array<::Google::Cloud::NetworkManagement::V1::EffectiveVpcFlowLogsConfig>

Returns List of Effective Vpc Flow Logs configurations.

Returns:



217
218
219
220
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 217

class ShowEffectiveFlowLogsConfigsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns Page token to fetch the next set of configurations.

Returns:

  • (::String)

    Page token to fetch the next set of configurations.



217
218
219
220
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 217

class ShowEffectiveFlowLogsConfigsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Locations that could not be reached (when querying all locations with -).

Returns:

  • (::Array<::String>)

    Locations that could not be reached (when querying all locations with -).



217
218
219
220
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 217

class ShowEffectiveFlowLogsConfigsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end