Module: Google::Cloud::NetworkManagement::V1::Step::State

Defined in:
proto_docs/google/cloud/networkmanagement/v1/trace.rb

Overview

Type of states that are defined in the network state machine. Each step in the packet trace is in a specific state.

Constant Summary collapse

STATE_UNSPECIFIED =

Unspecified state.

0
START_FROM_INSTANCE =

Initial state: packet originating from a Compute Engine instance. An InstanceInfo is populated with starting instance information.

1
START_FROM_INTERNET =

Initial state: packet originating from the internet. The endpoint information is populated.

2
START_FROM_GOOGLE_SERVICE =

Initial state: packet originating from a Google service. The google_service information is populated.

27
START_FROM_PRIVATE_NETWORK =

Initial state: packet originating from a VPC or on-premises network with internal source IP. If the source is a VPC network visible to the user, a NetworkInfo is populated with details of the network.

3
START_FROM_GKE_MASTER =

Initial state: packet originating from a Google Kubernetes Engine cluster master. A GKEMasterInfo is populated with starting instance information.

21
START_FROM_CLOUD_SQL_INSTANCE =

Initial state: packet originating from a Cloud SQL instance. A CloudSQLInstanceInfo is populated with starting instance information.

22
START_FROM_GKE_POD =

Initial state: packet originating from a Google Kubernetes Engine Pod. A GkePodInfo is populated with starting Pod information.

39
START_FROM_REDIS_INSTANCE =

Initial state: packet originating from a Redis instance. A RedisInstanceInfo is populated with starting instance information.

32
START_FROM_REDIS_CLUSTER =

Initial state: packet originating from a Redis Cluster. A RedisClusterInfo is populated with starting Cluster information.

33
START_FROM_CLOUD_FUNCTION =

Initial state: packet originating from a Cloud Function. A CloudFunctionInfo is populated with starting function information.

23
START_FROM_APP_ENGINE_VERSION =

Initial state: packet originating from an App Engine service version. An AppEngineVersionInfo is populated with starting version information.

25
START_FROM_CLOUD_RUN_REVISION =

Initial state: packet originating from a Cloud Run revision. A CloudRunRevisionInfo is populated with starting revision information.

26
START_FROM_STORAGE_BUCKET =

Initial state: packet originating from a Storage Bucket. Used only for return traces. The storage_bucket information is populated.

29
START_FROM_PSC_PUBLISHED_SERVICE =

Initial state: packet originating from a published service that uses Private Service Connect. Used only for return traces.

30
START_FROM_SERVERLESS_NEG =

Initial state: packet originating from a serverless network endpoint group backend. Used only for return traces. The serverless_neg information is populated.

31
APPLY_INGRESS_FIREWALL_RULE =

Config checking state: verify ingress firewall rule.

4
APPLY_EGRESS_FIREWALL_RULE =

Config checking state: verify egress firewall rule.

5
APPLY_ROUTE =

Config checking state: verify route.

6
APPLY_FORWARDING_RULE =

Config checking state: match forwarding rule.

7
ANALYZE_LOAD_BALANCER_BACKEND =

Config checking state: verify load balancer backend configuration.

28
SPOOFING_APPROVED =

Config checking state: packet sent or received under foreign IP address and allowed.

8
ARRIVE_AT_INSTANCE =

Forwarding state: arriving at a Compute Engine instance.

9
ARRIVE_AT_INTERNAL_LOAD_BALANCER =

Forwarding state: arriving at a Compute Engine internal load balancer.

10
ARRIVE_AT_EXTERNAL_LOAD_BALANCER =

Forwarding state: arriving at a Compute Engine external load balancer.

11
ARRIVE_AT_HYBRID_SUBNET =

Forwarding state: arriving at a hybrid subnet. Appropriate routing configuration will be determined here.

38
ARRIVE_AT_VPN_GATEWAY =

Forwarding state: arriving at a Cloud VPN gateway.

12
ARRIVE_AT_VPN_TUNNEL =

Forwarding state: arriving at a Cloud VPN tunnel.

13
ARRIVE_AT_INTERCONNECT_ATTACHMENT =

Forwarding state: arriving at an interconnect attachment.

37
ARRIVE_AT_VPC_CONNECTOR =

Forwarding state: arriving at a VPC connector.

24
ARRIVE_AT_GKE_POD =

Forwarding state: arriving at a GKE Pod.

44
DIRECT_VPC_EGRESS_CONNECTION =

Forwarding state: for packets originating from a serverless endpoint forwarded through Direct VPC egress.

35
SERVERLESS_EXTERNAL_CONNECTION =

Forwarding state: for packets originating from a serverless endpoint forwarded through public (external) connectivity.

36
NGFW_PACKET_INSPECTION =

Forwarding state: Layer 7 packet inspection by the firewall endpoint based on the configured security profile group.

47
NAT =

Transition state: packet header translated. The nat field is populated with the translation information.

14
SKIP_GKE_POD_IP_MASQUERADING =

Transition state: GKE Pod IP masquerading is skipped. The ip_masquerading_skipped field is populated with the reason.

40
SKIP_GKE_INGRESS_NETWORK_POLICY =

Transition state: GKE Ingress Network Policy is skipped. The gke_network_policy_skipped field is populated with the reason.

41
SKIP_GKE_EGRESS_NETWORK_POLICY =

Transition state: GKE Egress Network Policy is skipped. The gke_network_policy_skipped field is populated with the reason.

42
APPLY_INGRESS_GKE_NETWORK_POLICY =

Config checking state: verify ingress GKE network policy.

45
APPLY_EGRESS_GKE_NETWORK_POLICY =

Config checking state: verify egress GKE network policy.

46
PROXY_CONNECTION =

Transition state: original connection is terminated and a new proxied connection is initiated.

15
DELIVER =

Final state: packet could be delivered.

16
DROP =

Final state: packet could be dropped.

17
FORWARD =

Final state: packet could be forwarded to a network with an unknown configuration.

18
ABORT =

Final state: analysis is aborted.

19
VIEWER_PERMISSION_MISSING =

Special state: viewer of the test result does not have permission to see the configuration in this step.

20