Class: Google::Cloud::NetworkManagement::V1::UpdateVpcFlowLogsConfigRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb

Overview

Request for the UpdateVpcFlowLogsConfig method.

Instance Attribute Summary collapse

Instance Attribute Details

#update_mask::Google::Protobuf::FieldMask

Returns Required. Mask of fields to update. At least one path must be supplied in this field. For example, to change the state of the configuration to ENABLED, specify update_mask = "state", and the vpc_flow_logs_config would be: vpc_flow_logs_config = { name = "projects/my-project/locations/global/vpcFlowLogsConfigs/my-config" state = "ENABLED" }.

Returns:

  • (::Google::Protobuf::FieldMask)

    Required. Mask of fields to update. At least one path must be supplied in this field. For example, to change the state of the configuration to ENABLED, specify update_mask = "state", and the vpc_flow_logs_config would be: vpc_flow_logs_config = { name = "projects/my-project/locations/global/vpcFlowLogsConfigs/my-config" state = "ENABLED" }



120
121
122
123
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 120

class UpdateVpcFlowLogsConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vpc_flow_logs_config::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig

Returns Required. Only fields specified in update_mask are updated.

Returns:



120
121
122
123
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 120

class UpdateVpcFlowLogsConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end