Module: Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::CrossProjectMetadata

Defined in:
proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb

Overview

Determines whether to include cross project annotations in the logs. Project configurations will always have CROSS_PROJECT_METADATA_DISABLED.

Constant Summary collapse

CROSS_PROJECT_METADATA_UNSPECIFIED =

If not specified, the default is CROSS_PROJECT_METADATA_ENABLED.

0
CROSS_PROJECT_METADATA_ENABLED =

When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be included in the logs.

1
CROSS_PROJECT_METADATA_DISABLED =

When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will not be included in the logs.

2