Class: Google::Cloud::NetworkManagement::V1::VpcFlowLogsService::Client
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::VpcFlowLogsService::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb
Overview
Client for the VpcFlowLogsService service.
The VPC Flow Logs service in the Google Cloud Network Management API provides configurations that generate Flow Logs. The service and the configuration resources created using this service are global.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Client
readonly
Get the associated client for mix-in of the IAMPolicy.
-
#location_client ⇒ Google::Cloud::Location::Locations::Client
readonly
Get the associated client for mix-in of the Locations.
-
#operations_client ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsService::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the VpcFlowLogsService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the VpcFlowLogsService Client instance.
-
#create_vpc_flow_logs_config(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Creates a new
VpcFlowLogsConfig. -
#delete_vpc_flow_logs_config(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Deletes a specific
VpcFlowLogsConfig. -
#get_vpc_flow_logs_config(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig
Gets the details of a specific
VpcFlowLogsConfig. -
#initialize {|config| ... } ⇒ Client
constructor
Create a new VpcFlowLogsService client object.
-
#list_vpc_flow_logs_configs(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig>
Lists all
VpcFlowLogsConfigsin a given project. -
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#query_org_vpc_flow_logs_configs(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig>
QueryOrgVpcFlowLogsConfigs returns a list of all organization-level VPC Flow Logs configurations applicable to the specified project.
-
#show_effective_flow_logs_configs(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::EffectiveVpcFlowLogsConfig>
ShowEffectiveFlowLogsConfigs returns a list of all VPC Flow Logs configurations applicable to a specified resource.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_vpc_flow_logs_config(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Updates an existing
VpcFlowLogsConfig.
Methods included from Paths
#location_path, #organization_location_path, #vpc_flow_logs_config_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new VpcFlowLogsService client object.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 128 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/networkmanagement/v1/vpc_flow_logs_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @vpc_flow_logs_service_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @vpc_flow_logs_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @vpc_flow_logs_service_stub.endpoint config.universe_domain = @vpc_flow_logs_service_stub.universe_domain config.logger = @vpc_flow_logs_service_stub.logger if config.respond_to? :logger= end @iam_policy_client = Google::Iam::V1::IAMPolicy::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @vpc_flow_logs_service_stub.endpoint config.universe_domain = @vpc_flow_logs_service_stub.universe_domain config.logger = @vpc_flow_logs_service_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Client (readonly)
Get the associated client for mix-in of the IAMPolicy.
221 222 223 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 221 def iam_policy_client @iam_policy_client end |
#location_client ⇒ Google::Cloud::Location::Locations::Client (readonly)
Get the associated client for mix-in of the Locations.
214 215 216 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 214 def location_client @location_client end |
#operations_client ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsService::Operations (readonly)
Get the associated client for long-running operations.
207 208 209 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 207 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the VpcFlowLogsService Client class.
See Configuration for a description of the configuration fields.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 66 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "NetworkManagement", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the VpcFlowLogsService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
98 99 100 101 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 98 def configure yield @config if block_given? @config end |
#create_vpc_flow_logs_config(request, options = nil) ⇒ ::Gapic::Operation #create_vpc_flow_logs_config(parent: nil, vpc_flow_logs_config_id: nil, vpc_flow_logs_config: nil) ⇒ ::Gapic::Operation
Creates a new VpcFlowLogsConfig.
If a configuration with the exact same settings already exists (even if the
ID is different), the creation fails.
Notes:
- Creating a configuration with
state=DISABLEDwill fail - The following fields are not considered as settings for the purpose
of the check mentioned above, therefore - creating another configuration
with the same fields but different values for the following fields will
fail as well:
- name
- create_time
- update_time
- labels
- description
509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 509 def create_vpc_flow_logs_config request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::CreateVpcFlowLogsConfigRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_vpc_flow_logs_config..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_vpc_flow_logs_config.timeout, metadata: , retry_policy: @config.rpcs.create_vpc_flow_logs_config.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @vpc_flow_logs_service_stub.call_rpc :create_vpc_flow_logs_config, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_vpc_flow_logs_config(request, options = nil) ⇒ ::Gapic::Operation #delete_vpc_flow_logs_config(name: nil) ⇒ ::Gapic::Operation
Deletes a specific VpcFlowLogsConfig.
727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 727 def delete_vpc_flow_logs_config request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::DeleteVpcFlowLogsConfigRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_vpc_flow_logs_config..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_vpc_flow_logs_config.timeout, metadata: , retry_policy: @config.rpcs.delete_vpc_flow_logs_config.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @vpc_flow_logs_service_stub.call_rpc :delete_vpc_flow_logs_config, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_vpc_flow_logs_config(request, options = nil) ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig #get_vpc_flow_logs_config(name: nil) ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig
Gets the details of a specific VpcFlowLogsConfig.
393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 393 def get_vpc_flow_logs_config request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::GetVpcFlowLogsConfigRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_vpc_flow_logs_config..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_vpc_flow_logs_config.timeout, metadata: , retry_policy: @config.rpcs.get_vpc_flow_logs_config.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @vpc_flow_logs_service_stub.call_rpc :get_vpc_flow_logs_config, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_vpc_flow_logs_configs(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig> #list_vpc_flow_logs_configs(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig>
Lists all VpcFlowLogsConfigs in a given project.
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 299 def list_vpc_flow_logs_configs request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::ListVpcFlowLogsConfigsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_vpc_flow_logs_configs..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_vpc_flow_logs_configs.timeout, metadata: , retry_policy: @config.rpcs.list_vpc_flow_logs_configs.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @vpc_flow_logs_service_stub.call_rpc :list_vpc_flow_logs_configs, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @vpc_flow_logs_service_stub, :list_vpc_flow_logs_configs, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
228 229 230 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 228 def logger @vpc_flow_logs_service_stub.logger end |
#query_org_vpc_flow_logs_configs(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig> #query_org_vpc_flow_logs_configs(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig>
QueryOrgVpcFlowLogsConfigs returns a list of all organization-level VPC Flow Logs configurations applicable to the specified project.
829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 829 def query_org_vpc_flow_logs_configs request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::QueryOrgVpcFlowLogsConfigsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.query_org_vpc_flow_logs_configs..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.query_org_vpc_flow_logs_configs.timeout, metadata: , retry_policy: @config.rpcs.query_org_vpc_flow_logs_configs.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @vpc_flow_logs_service_stub.call_rpc :query_org_vpc_flow_logs_configs, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @vpc_flow_logs_service_stub, :query_org_vpc_flow_logs_configs, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#show_effective_flow_logs_configs(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::EffectiveVpcFlowLogsConfig> #show_effective_flow_logs_configs(parent: nil, resource: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::EffectiveVpcFlowLogsConfig>
ShowEffectiveFlowLogsConfigs returns a list of all VPC Flow Logs configurations applicable to a specified resource.
937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 937 def show_effective_flow_logs_configs request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::ShowEffectiveFlowLogsConfigsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.show_effective_flow_logs_configs..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.show_effective_flow_logs_configs.timeout, metadata: , retry_policy: @config.rpcs.show_effective_flow_logs_configs.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @vpc_flow_logs_service_stub.call_rpc :show_effective_flow_logs_configs, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @vpc_flow_logs_service_stub, :show_effective_flow_logs_configs, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
108 109 110 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 108 def universe_domain @vpc_flow_logs_service_stub.universe_domain end |
#update_vpc_flow_logs_config(request, options = nil) ⇒ ::Gapic::Operation #update_vpc_flow_logs_config(update_mask: nil, vpc_flow_logs_config: nil) ⇒ ::Gapic::Operation
Updates an existing VpcFlowLogsConfig.
If a configuration with the exact same settings already exists (even if the
ID is different), the creation fails.
Notes:
- Updating a configuration with
state=DISABLEDwill fail. - The following fields are not considered as settings for the purpose
of the check mentioned above, therefore - updating another configuration
with the same fields but different values for the following fields will
fail as well:
- name
- create_time
- update_time
- labels
- description
626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/client.rb', line 626 def update_vpc_flow_logs_config request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::UpdateVpcFlowLogsConfigRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_vpc_flow_logs_config..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.vpc_flow_logs_config&.name header_params["vpc_flow_logs_config.name"] = request.vpc_flow_logs_config.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_vpc_flow_logs_config.timeout, metadata: , retry_policy: @config.rpcs.update_vpc_flow_logs_config.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @vpc_flow_logs_service_stub.call_rpc :update_vpc_flow_logs_config, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |