Class: Google::Cloud::NetworkManagement::V1::VpcFlowLogsService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::VpcFlowLogsService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb
Overview
REST client for the VpcFlowLogsService service.
The VPC Flow Logs service in the Google Cloud Network Management API provides configurations that generate Flow Logs. The service and the configuration resources created using this service are global.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Rest::Client
readonly
Get the associated client for mix-in of the IAMPolicy.
-
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client
readonly
Get the associated client for mix-in of the Locations.
-
#operations_client ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsService::Rest::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the VpcFlowLogsService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the VpcFlowLogsService Client instance.
-
#create_vpc_flow_logs_config(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
Creates a new
VpcFlowLogsConfig. -
#delete_vpc_flow_logs_config(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
Deletes a specific
VpcFlowLogsConfig. -
#get_vpc_flow_logs_config(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig
Gets the details of a specific
VpcFlowLogsConfig. -
#initialize {|config| ... } ⇒ Client
constructor
Create a new VpcFlowLogsService REST client object.
-
#list_vpc_flow_logs_configs(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig>
Lists all
VpcFlowLogsConfigsin a given project. -
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#query_org_vpc_flow_logs_configs(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig>
QueryOrgVpcFlowLogsConfigs returns a list of all organization-level VPC Flow Logs configurations applicable to the specified project.
-
#show_effective_flow_logs_configs(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::EffectiveVpcFlowLogsConfig>
ShowEffectiveFlowLogsConfigs returns a list of all VPC Flow Logs configurations applicable to a specified resource.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_vpc_flow_logs_config(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
Updates an existing
VpcFlowLogsConfig.
Methods included from Paths
#location_path, #organization_location_path, #vpc_flow_logs_config_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new VpcFlowLogsService REST client object.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 130 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsService::Rest::Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @vpc_flow_logs_service_stub = ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @vpc_flow_logs_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @vpc_flow_logs_service_stub.endpoint config.universe_domain = @vpc_flow_logs_service_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @vpc_flow_logs_service_stub.logger if config.respond_to? :logger= end @iam_policy_client = Google::Iam::V1::IAMPolicy::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @vpc_flow_logs_service_stub.endpoint config.universe_domain = @vpc_flow_logs_service_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @vpc_flow_logs_service_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Rest::Client (readonly)
Get the associated client for mix-in of the IAMPolicy.
216 217 218 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 216 def iam_policy_client @iam_policy_client end |
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client (readonly)
Get the associated client for mix-in of the Locations.
209 210 211 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 209 def location_client @location_client end |
#operations_client ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsService::Rest::Operations (readonly)
Get the associated client for long-running operations.
202 203 204 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 202 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the VpcFlowLogsService Client class.
See Configuration for a description of the configuration fields.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 68 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "NetworkManagement", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the VpcFlowLogsService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
100 101 102 103 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 100 def configure yield @config if block_given? @config end |
#create_vpc_flow_logs_config(request, options = nil) ⇒ ::Gapic::Operation #create_vpc_flow_logs_config(parent: nil, vpc_flow_logs_config_id: nil, vpc_flow_logs_config: nil) ⇒ ::Gapic::Operation
Creates a new VpcFlowLogsConfig.
If a configuration with the exact same settings already exists (even if the
ID is different), the creation fails.
Notes:
- Creating a configuration with
state=DISABLEDwill fail - The following fields are not considered as settings for the purpose
of the check mentioned above, therefore - creating another configuration
with the same fields but different values for the following fields will
fail as well:
- name
- create_time
- update_time
- labels
- description
489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 489 def create_vpc_flow_logs_config request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::CreateVpcFlowLogsConfigRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_vpc_flow_logs_config..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_vpc_flow_logs_config.timeout, metadata: , retry_policy: @config.rpcs.create_vpc_flow_logs_config.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @vpc_flow_logs_service_stub.create_vpc_flow_logs_config request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_vpc_flow_logs_config(request, options = nil) ⇒ ::Gapic::Operation #delete_vpc_flow_logs_config(name: nil) ⇒ ::Gapic::Operation
Deletes a specific VpcFlowLogsConfig.
693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 693 def delete_vpc_flow_logs_config request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::DeleteVpcFlowLogsConfigRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_vpc_flow_logs_config..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_vpc_flow_logs_config.timeout, metadata: , retry_policy: @config.rpcs.delete_vpc_flow_logs_config.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @vpc_flow_logs_service_stub.delete_vpc_flow_logs_config request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_vpc_flow_logs_config(request, options = nil) ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig #get_vpc_flow_logs_config(name: nil) ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig
Gets the details of a specific VpcFlowLogsConfig.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 380 def get_vpc_flow_logs_config request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::GetVpcFlowLogsConfigRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_vpc_flow_logs_config..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_vpc_flow_logs_config.timeout, metadata: , retry_policy: @config.rpcs.get_vpc_flow_logs_config.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @vpc_flow_logs_service_stub.get_vpc_flow_logs_config request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_vpc_flow_logs_configs(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig> #list_vpc_flow_logs_configs(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig>
Lists all VpcFlowLogsConfigs in a given project.
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 293 def list_vpc_flow_logs_configs request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::ListVpcFlowLogsConfigsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_vpc_flow_logs_configs..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_vpc_flow_logs_configs.timeout, metadata: , retry_policy: @config.rpcs.list_vpc_flow_logs_configs.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @vpc_flow_logs_service_stub.list_vpc_flow_logs_configs request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @vpc_flow_logs_service_stub, :list_vpc_flow_logs_configs, "vpc_flow_logs_configs", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
223 224 225 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 223 def logger @vpc_flow_logs_service_stub.logger end |
#query_org_vpc_flow_logs_configs(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig> #query_org_vpc_flow_logs_configs(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig>
QueryOrgVpcFlowLogsConfigs returns a list of all organization-level VPC Flow Logs configurations applicable to the specified project.
788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 788 def query_org_vpc_flow_logs_configs request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::QueryOrgVpcFlowLogsConfigsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.query_org_vpc_flow_logs_configs..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.query_org_vpc_flow_logs_configs.timeout, metadata: , retry_policy: @config.rpcs.query_org_vpc_flow_logs_configs.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @vpc_flow_logs_service_stub.query_org_vpc_flow_logs_configs request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @vpc_flow_logs_service_stub, :query_org_vpc_flow_logs_configs, "vpc_flow_logs_configs", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#show_effective_flow_logs_configs(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::EffectiveVpcFlowLogsConfig> #show_effective_flow_logs_configs(parent: nil, resource: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::NetworkManagement::V1::EffectiveVpcFlowLogsConfig>
ShowEffectiveFlowLogsConfigs returns a list of all VPC Flow Logs configurations applicable to a specified resource.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 889 def show_effective_flow_logs_configs request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::ShowEffectiveFlowLogsConfigsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.show_effective_flow_logs_configs..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.show_effective_flow_logs_configs.timeout, metadata: , retry_policy: @config.rpcs.show_effective_flow_logs_configs.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @vpc_flow_logs_service_stub.show_effective_flow_logs_configs request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @vpc_flow_logs_service_stub, :show_effective_flow_logs_configs, "effective_flow_logs_configs", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
110 111 112 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 110 def universe_domain @vpc_flow_logs_service_stub.universe_domain end |
#update_vpc_flow_logs_config(request, options = nil) ⇒ ::Gapic::Operation #update_vpc_flow_logs_config(update_mask: nil, vpc_flow_logs_config: nil) ⇒ ::Gapic::Operation
Updates an existing VpcFlowLogsConfig.
If a configuration with the exact same settings already exists (even if the
ID is different), the creation fails.
Notes:
- Updating a configuration with
state=DISABLEDwill fail. - The following fields are not considered as settings for the purpose
of the check mentioned above, therefore - updating another configuration
with the same fields but different values for the following fields will
fail as well:
- name
- create_time
- update_time
- labels
- description
599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 |
# File 'lib/google/cloud/network_management/v1/vpc_flow_logs_service/rest/client.rb', line 599 def update_vpc_flow_logs_config request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::NetworkManagement::V1::UpdateVpcFlowLogsConfigRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_vpc_flow_logs_config..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::NetworkManagement::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_vpc_flow_logs_config.timeout, metadata: , retry_policy: @config.rpcs.update_vpc_flow_logs_config.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @vpc_flow_logs_service_stub.update_vpc_flow_logs_config request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |