Class: Google::Cloud::NetworkManagement::V1::EffectiveVpcFlowLogsConfig
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::EffectiveVpcFlowLogsConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb
Overview
A configuration to generate a response for GetEffectiveVpcFlowLogsConfig request.
Defined Under Namespace
Modules: Scope
Instance Attribute Summary collapse
-
#aggregation_interval ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::AggregationInterval
The aggregation interval for the logs.
-
#cross_project_metadata ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::CrossProjectMetadata
Determines whether to include cross project annotations in the logs.
-
#filter_expr ⇒ ::String
Export filter used to define which VPC Flow Logs should be logged.
-
#flow_sampling ⇒ ::Float
The value of the field must be in (0, 1].
-
#interconnect_attachment ⇒ ::String
Traffic will be logged from the Interconnect Attachment.
-
#metadata ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::Metadata
Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs.
-
#metadata_fields ⇒ ::Array<::String>
Custom metadata fields to include in the reported VPC flow logs.
-
#name ⇒ ::String
Unique name of the configuration.
-
#network ⇒ ::String
Traffic will be logged from VMs, VPN tunnels and Interconnect Attachments within the network.
-
#scope ⇒ ::Google::Cloud::NetworkManagement::V1::EffectiveVpcFlowLogsConfig::Scope
Specifies the scope of the config (e.g., SUBNET, NETWORK, ORGANIZATION..).
-
#state ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::State
The state of the VPC Flow Log configuration.
-
#subnet ⇒ ::String
Traffic will be logged from VMs within the subnetwork.
-
#vpn_tunnel ⇒ ::String
Traffic will be logged from the VPN Tunnel.
Instance Attribute Details
#aggregation_interval ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::AggregationInterval
Returns The aggregation interval for the logs. Default value is INTERVAL_5_SEC.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 280 class EffectiveVpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scope for this flow log configuration. module Scope # Scope is unspecified. SCOPE_UNSPECIFIED = 0 # Target resource is a subnet (Network Management API). SUBNET = 1 # Target resource is a subnet, and the config originates from the Compute # API. COMPUTE_API_SUBNET = 2 # Target resource is a network. NETWORK = 3 # Target resource is a VPN tunnel. VPN_TUNNEL = 4 # Target resource is an interconnect attachment. INTERCONNECT_ATTACHMENT = 5 # Configuration applies to an entire organization. ORGANIZATION = 6 end end |
#cross_project_metadata ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::CrossProjectMetadata
Returns Determines whether to include cross project annotations in the logs. This field is available only for organization configurations. If not specified in org configs will be set to CROSS_PROJECT_METADATA_ENABLED.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 280 class EffectiveVpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scope for this flow log configuration. module Scope # Scope is unspecified. SCOPE_UNSPECIFIED = 0 # Target resource is a subnet (Network Management API). SUBNET = 1 # Target resource is a subnet, and the config originates from the Compute # API. COMPUTE_API_SUBNET = 2 # Target resource is a network. NETWORK = 3 # Target resource is a VPN tunnel. VPN_TUNNEL = 4 # Target resource is an interconnect attachment. INTERCONNECT_ATTACHMENT = 5 # Configuration applies to an entire organization. ORGANIZATION = 6 end end |
#filter_expr ⇒ ::String
Returns Export filter used to define which VPC Flow Logs should be logged.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 280 class EffectiveVpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scope for this flow log configuration. module Scope # Scope is unspecified. SCOPE_UNSPECIFIED = 0 # Target resource is a subnet (Network Management API). SUBNET = 1 # Target resource is a subnet, and the config originates from the Compute # API. COMPUTE_API_SUBNET = 2 # Target resource is a network. NETWORK = 3 # Target resource is a VPN tunnel. VPN_TUNNEL = 4 # Target resource is an interconnect attachment. INTERCONNECT_ATTACHMENT = 5 # Configuration applies to an entire organization. ORGANIZATION = 6 end end |
#flow_sampling ⇒ ::Float
Returns The value of the field must be in (0, 1]. The sampling rate of VPC Flow Logs where 1.0 means all collected logs are reported. Setting the sampling rate to 0.0 is not allowed. If you want to disable VPC Flow Logs, use the state field instead. Default value is 1.0.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 280 class EffectiveVpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scope for this flow log configuration. module Scope # Scope is unspecified. SCOPE_UNSPECIFIED = 0 # Target resource is a subnet (Network Management API). SUBNET = 1 # Target resource is a subnet, and the config originates from the Compute # API. COMPUTE_API_SUBNET = 2 # Target resource is a network. NETWORK = 3 # Target resource is a VPN tunnel. VPN_TUNNEL = 4 # Target resource is an interconnect attachment. INTERCONNECT_ATTACHMENT = 5 # Configuration applies to an entire organization. ORGANIZATION = 6 end end |
#interconnect_attachment ⇒ ::String
Returns Traffic will be logged from the Interconnect Attachment. Format: projects/{project_id}/regions/{region}/interconnectAttachments/{name}
Note: The following fields are mutually exclusive: interconnect_attachment, network, subnet, vpn_tunnel. If a field in that set is populated, all other fields in the set will automatically be cleared.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 280 class EffectiveVpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scope for this flow log configuration. module Scope # Scope is unspecified. SCOPE_UNSPECIFIED = 0 # Target resource is a subnet (Network Management API). SUBNET = 1 # Target resource is a subnet, and the config originates from the Compute # API. COMPUTE_API_SUBNET = 2 # Target resource is a network. NETWORK = 3 # Target resource is a VPN tunnel. VPN_TUNNEL = 4 # Target resource is an interconnect attachment. INTERCONNECT_ATTACHMENT = 5 # Configuration applies to an entire organization. ORGANIZATION = 6 end end |
#metadata ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::Metadata
Returns Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default value is INCLUDE_ALL_METADATA.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 280 class EffectiveVpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scope for this flow log configuration. module Scope # Scope is unspecified. SCOPE_UNSPECIFIED = 0 # Target resource is a subnet (Network Management API). SUBNET = 1 # Target resource is a subnet, and the config originates from the Compute # API. COMPUTE_API_SUBNET = 2 # Target resource is a network. NETWORK = 3 # Target resource is a VPN tunnel. VPN_TUNNEL = 4 # Target resource is an interconnect attachment. INTERCONNECT_ATTACHMENT = 5 # Configuration applies to an entire organization. ORGANIZATION = 6 end end |
#metadata_fields ⇒ ::Array<::String>
Returns Custom metadata fields to include in the reported VPC flow logs. Can only be specified if "metadata" was set to CUSTOM_METADATA.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 280 class EffectiveVpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scope for this flow log configuration. module Scope # Scope is unspecified. SCOPE_UNSPECIFIED = 0 # Target resource is a subnet (Network Management API). SUBNET = 1 # Target resource is a subnet, and the config originates from the Compute # API. COMPUTE_API_SUBNET = 2 # Target resource is a network. NETWORK = 3 # Target resource is a VPN tunnel. VPN_TUNNEL = 4 # Target resource is an interconnect attachment. INTERCONNECT_ATTACHMENT = 5 # Configuration applies to an entire organization. ORGANIZATION = 6 end end |
#name ⇒ ::String
Returns Unique name of the configuration. The name can have one of the following forms:
For project-level configurations:
projects/{project_id}/locations/global/vpcFlowLogsConfigs/{vpc_flow_logs_config_id}For organization-level configurations:
organizations/{organization_id}/locations/global/vpcFlowLogsConfigs/{vpc_flow_logs_config_id}For a Compute config, the name will be the path of the subnet:
projects/{project_id}/regions/{region}/subnetworks/{subnet_id}.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 280 class EffectiveVpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scope for this flow log configuration. module Scope # Scope is unspecified. SCOPE_UNSPECIFIED = 0 # Target resource is a subnet (Network Management API). SUBNET = 1 # Target resource is a subnet, and the config originates from the Compute # API. COMPUTE_API_SUBNET = 2 # Target resource is a network. NETWORK = 3 # Target resource is a VPN tunnel. VPN_TUNNEL = 4 # Target resource is an interconnect attachment. INTERCONNECT_ATTACHMENT = 5 # Configuration applies to an entire organization. ORGANIZATION = 6 end end |
#network ⇒ ::String
Returns Traffic will be logged from VMs, VPN tunnels and Interconnect Attachments within the network. Format: projects/{project_id}/global/networks/{name}
Note: The following fields are mutually exclusive: network, subnet, interconnect_attachment, vpn_tunnel. If a field in that set is populated, all other fields in the set will automatically be cleared.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 280 class EffectiveVpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scope for this flow log configuration. module Scope # Scope is unspecified. SCOPE_UNSPECIFIED = 0 # Target resource is a subnet (Network Management API). SUBNET = 1 # Target resource is a subnet, and the config originates from the Compute # API. COMPUTE_API_SUBNET = 2 # Target resource is a network. NETWORK = 3 # Target resource is a VPN tunnel. VPN_TUNNEL = 4 # Target resource is an interconnect attachment. INTERCONNECT_ATTACHMENT = 5 # Configuration applies to an entire organization. ORGANIZATION = 6 end end |
#scope ⇒ ::Google::Cloud::NetworkManagement::V1::EffectiveVpcFlowLogsConfig::Scope
Returns Specifies the scope of the config (e.g., SUBNET, NETWORK, ORGANIZATION..).
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 280 class EffectiveVpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scope for this flow log configuration. module Scope # Scope is unspecified. SCOPE_UNSPECIFIED = 0 # Target resource is a subnet (Network Management API). SUBNET = 1 # Target resource is a subnet, and the config originates from the Compute # API. COMPUTE_API_SUBNET = 2 # Target resource is a network. NETWORK = 3 # Target resource is a VPN tunnel. VPN_TUNNEL = 4 # Target resource is an interconnect attachment. INTERCONNECT_ATTACHMENT = 5 # Configuration applies to an entire organization. ORGANIZATION = 6 end end |
#state ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::State
Returns The state of the VPC Flow Log configuration. Default value is ENABLED. When creating a new configuration, it must be enabled. Setting state=DISABLED will pause the log generation for this config.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 280 class EffectiveVpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scope for this flow log configuration. module Scope # Scope is unspecified. SCOPE_UNSPECIFIED = 0 # Target resource is a subnet (Network Management API). SUBNET = 1 # Target resource is a subnet, and the config originates from the Compute # API. COMPUTE_API_SUBNET = 2 # Target resource is a network. NETWORK = 3 # Target resource is a VPN tunnel. VPN_TUNNEL = 4 # Target resource is an interconnect attachment. INTERCONNECT_ATTACHMENT = 5 # Configuration applies to an entire organization. ORGANIZATION = 6 end end |
#subnet ⇒ ::String
Returns Traffic will be logged from VMs within the subnetwork. Format: projects/{project_id}/regions/{region}/subnetworks/{name}
Note: The following fields are mutually exclusive: subnet, network, interconnect_attachment, vpn_tunnel. If a field in that set is populated, all other fields in the set will automatically be cleared.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 280 class EffectiveVpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scope for this flow log configuration. module Scope # Scope is unspecified. SCOPE_UNSPECIFIED = 0 # Target resource is a subnet (Network Management API). SUBNET = 1 # Target resource is a subnet, and the config originates from the Compute # API. COMPUTE_API_SUBNET = 2 # Target resource is a network. NETWORK = 3 # Target resource is a VPN tunnel. VPN_TUNNEL = 4 # Target resource is an interconnect attachment. INTERCONNECT_ATTACHMENT = 5 # Configuration applies to an entire organization. ORGANIZATION = 6 end end |
#vpn_tunnel ⇒ ::String
Returns Traffic will be logged from the VPN Tunnel. Format: projects/{project_id}/regions/{region}/vpnTunnels/{name}
Note: The following fields are mutually exclusive: vpn_tunnel, network, subnet, interconnect_attachment. If a field in that set is populated, all other fields in the set will automatically be cleared.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 280 class EffectiveVpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The scope for this flow log configuration. module Scope # Scope is unspecified. SCOPE_UNSPECIFIED = 0 # Target resource is a subnet (Network Management API). SUBNET = 1 # Target resource is a subnet, and the config originates from the Compute # API. COMPUTE_API_SUBNET = 2 # Target resource is a network. NETWORK = 3 # Target resource is a VPN tunnel. VPN_TUNNEL = 4 # Target resource is an interconnect attachment. INTERCONNECT_ATTACHMENT = 5 # Configuration applies to an entire organization. ORGANIZATION = 6 end end |