Class: Google::Cloud::NetworkManagement::V1::FirewallInfo
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::FirewallInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/trace.rb
Overview
For display only. Metadata associated with a VPC firewall rule, an implied VPC firewall rule, or a firewall policy rule.
Defined Under Namespace
Modules: FirewallRuleType, TargetType
Instance Attribute Summary collapse
-
#action ⇒ ::String
Possible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP.
-
#direction ⇒ ::String
Possible values: INGRESS, EGRESS.
-
#display_name ⇒ ::String
The display name of the firewall rule.
-
#firewall_rule_type ⇒ ::Google::Cloud::NetworkManagement::V1::FirewallInfo::FirewallRuleType
The firewall rule's type.
-
#network_uri ⇒ ::String
The URI of the VPC network that the firewall rule is associated with.
-
#policy ⇒ ::String
The name of the firewall policy that this rule is associated with.
-
#policy_priority ⇒ ::Integer
The priority of the firewall policy that this rule is associated with.
-
#policy_uri ⇒ ::String
The URI of the firewall policy that this rule is associated with.
-
#priority ⇒ ::Integer
The priority of the firewall rule.
-
#target_service_accounts ⇒ ::Array<::String>
The target service accounts specified by the firewall rule.
-
#target_tags ⇒ ::Array<::String>
The target tags defined by the VPC firewall rule.
-
#target_type ⇒ ::Google::Cloud::NetworkManagement::V1::FirewallInfo::TargetType
Target type of the firewall rule.
-
#uri ⇒ ::String
The URI of the firewall rule.
Instance Attribute Details
#action ⇒ ::String
Returns Possible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 566 class FirewallInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The firewall rule's type. module FirewallRuleType # Unspecified type. FIREWALL_RULE_TYPE_UNSPECIFIED = 0 # Hierarchical firewall policy rule. For details, see # [Hierarchical firewall policies # overview](https://cloud.google.com/vpc/docs/firewall-policies). HIERARCHICAL_FIREWALL_POLICY_RULE = 1 # VPC firewall rule. For details, see # [VPC firewall rules # overview](https://cloud.google.com/vpc/docs/firewalls). VPC_FIREWALL_RULE = 2 # Implied VPC firewall rule. For details, see # [Implied # rules](https://cloud.google.com/vpc/docs/firewalls#default_firewall_rules). IMPLIED_VPC_FIREWALL_RULE = 3 # Implicit firewall rules that are managed by serverless VPC access to # allow ingress access. They are not visible in the Google Cloud console. # For details, see [VPC connector's implicit # rules](https://cloud.google.com/functions/docs/networking/connecting-vpc#restrict-access). SERVERLESS_VPC_ACCESS_MANAGED_FIREWALL_RULE = 4 # User-defined global network firewall policy rule. # For details, see [Network firewall # policies](https://cloud.google.com/vpc/docs/network-firewall-policies). NETWORK_FIREWALL_POLICY_RULE = 5 # User-defined regional network firewall policy rule. # For details, see [Regional network firewall # policies](https://cloud.google.com/firewall/docs/regional-firewall-policies). NETWORK_REGIONAL_FIREWALL_POLICY_RULE = 6 # System-defined global network firewall policy rule. SYSTEM_NETWORK_FIREWALL_POLICY_RULE = 7 # System-defined regional network firewall policy rule. SYSTEM_REGIONAL_NETWORK_FIREWALL_POLICY_RULE = 8 # Firewall policy rule containing attributes not yet supported in # Connectivity tests. Firewall analysis is skipped if such a rule can # potentially be matched. Please see the [list of unsupported # configurations](https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs). UNSUPPORTED_FIREWALL_POLICY_RULE = 100 # Tracking state for response traffic created when request traffic goes # through allow firewall rule. # For details, see [firewall rules # specifications](https://cloud.google.com/firewall/docs/firewalls#specifications) TRACKING_STATE = 101 # Firewall analysis was skipped due to executing Connectivity Test in the # BypassFirewallChecks mode ANALYSIS_SKIPPED = 102 end # Target type of the firewall rule. module TargetType # Target type is not specified. In this case we treat the rule as applying # to INSTANCES target type. TARGET_TYPE_UNSPECIFIED = 0 # Firewall rule applies to instances. INSTANCES = 1 # Firewall rule applies to internal managed load balancers. INTERNAL_MANAGED_LB = 2 end end |
#direction ⇒ ::String
Returns Possible values: INGRESS, EGRESS.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 566 class FirewallInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The firewall rule's type. module FirewallRuleType # Unspecified type. FIREWALL_RULE_TYPE_UNSPECIFIED = 0 # Hierarchical firewall policy rule. For details, see # [Hierarchical firewall policies # overview](https://cloud.google.com/vpc/docs/firewall-policies). HIERARCHICAL_FIREWALL_POLICY_RULE = 1 # VPC firewall rule. For details, see # [VPC firewall rules # overview](https://cloud.google.com/vpc/docs/firewalls). VPC_FIREWALL_RULE = 2 # Implied VPC firewall rule. For details, see # [Implied # rules](https://cloud.google.com/vpc/docs/firewalls#default_firewall_rules). IMPLIED_VPC_FIREWALL_RULE = 3 # Implicit firewall rules that are managed by serverless VPC access to # allow ingress access. They are not visible in the Google Cloud console. # For details, see [VPC connector's implicit # rules](https://cloud.google.com/functions/docs/networking/connecting-vpc#restrict-access). SERVERLESS_VPC_ACCESS_MANAGED_FIREWALL_RULE = 4 # User-defined global network firewall policy rule. # For details, see [Network firewall # policies](https://cloud.google.com/vpc/docs/network-firewall-policies). NETWORK_FIREWALL_POLICY_RULE = 5 # User-defined regional network firewall policy rule. # For details, see [Regional network firewall # policies](https://cloud.google.com/firewall/docs/regional-firewall-policies). NETWORK_REGIONAL_FIREWALL_POLICY_RULE = 6 # System-defined global network firewall policy rule. SYSTEM_NETWORK_FIREWALL_POLICY_RULE = 7 # System-defined regional network firewall policy rule. SYSTEM_REGIONAL_NETWORK_FIREWALL_POLICY_RULE = 8 # Firewall policy rule containing attributes not yet supported in # Connectivity tests. Firewall analysis is skipped if such a rule can # potentially be matched. Please see the [list of unsupported # configurations](https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs). UNSUPPORTED_FIREWALL_POLICY_RULE = 100 # Tracking state for response traffic created when request traffic goes # through allow firewall rule. # For details, see [firewall rules # specifications](https://cloud.google.com/firewall/docs/firewalls#specifications) TRACKING_STATE = 101 # Firewall analysis was skipped due to executing Connectivity Test in the # BypassFirewallChecks mode ANALYSIS_SKIPPED = 102 end # Target type of the firewall rule. module TargetType # Target type is not specified. In this case we treat the rule as applying # to INSTANCES target type. TARGET_TYPE_UNSPECIFIED = 0 # Firewall rule applies to instances. INSTANCES = 1 # Firewall rule applies to internal managed load balancers. INTERNAL_MANAGED_LB = 2 end end |
#display_name ⇒ ::String
Returns The display name of the firewall rule. This field might be empty for firewall policy rules.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 566 class FirewallInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The firewall rule's type. module FirewallRuleType # Unspecified type. FIREWALL_RULE_TYPE_UNSPECIFIED = 0 # Hierarchical firewall policy rule. For details, see # [Hierarchical firewall policies # overview](https://cloud.google.com/vpc/docs/firewall-policies). HIERARCHICAL_FIREWALL_POLICY_RULE = 1 # VPC firewall rule. For details, see # [VPC firewall rules # overview](https://cloud.google.com/vpc/docs/firewalls). VPC_FIREWALL_RULE = 2 # Implied VPC firewall rule. For details, see # [Implied # rules](https://cloud.google.com/vpc/docs/firewalls#default_firewall_rules). IMPLIED_VPC_FIREWALL_RULE = 3 # Implicit firewall rules that are managed by serverless VPC access to # allow ingress access. They are not visible in the Google Cloud console. # For details, see [VPC connector's implicit # rules](https://cloud.google.com/functions/docs/networking/connecting-vpc#restrict-access). SERVERLESS_VPC_ACCESS_MANAGED_FIREWALL_RULE = 4 # User-defined global network firewall policy rule. # For details, see [Network firewall # policies](https://cloud.google.com/vpc/docs/network-firewall-policies). NETWORK_FIREWALL_POLICY_RULE = 5 # User-defined regional network firewall policy rule. # For details, see [Regional network firewall # policies](https://cloud.google.com/firewall/docs/regional-firewall-policies). NETWORK_REGIONAL_FIREWALL_POLICY_RULE = 6 # System-defined global network firewall policy rule. SYSTEM_NETWORK_FIREWALL_POLICY_RULE = 7 # System-defined regional network firewall policy rule. SYSTEM_REGIONAL_NETWORK_FIREWALL_POLICY_RULE = 8 # Firewall policy rule containing attributes not yet supported in # Connectivity tests. Firewall analysis is skipped if such a rule can # potentially be matched. Please see the [list of unsupported # configurations](https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs). UNSUPPORTED_FIREWALL_POLICY_RULE = 100 # Tracking state for response traffic created when request traffic goes # through allow firewall rule. # For details, see [firewall rules # specifications](https://cloud.google.com/firewall/docs/firewalls#specifications) TRACKING_STATE = 101 # Firewall analysis was skipped due to executing Connectivity Test in the # BypassFirewallChecks mode ANALYSIS_SKIPPED = 102 end # Target type of the firewall rule. module TargetType # Target type is not specified. In this case we treat the rule as applying # to INSTANCES target type. TARGET_TYPE_UNSPECIFIED = 0 # Firewall rule applies to instances. INSTANCES = 1 # Firewall rule applies to internal managed load balancers. INTERNAL_MANAGED_LB = 2 end end |
#firewall_rule_type ⇒ ::Google::Cloud::NetworkManagement::V1::FirewallInfo::FirewallRuleType
Returns The firewall rule's type.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 566 class FirewallInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The firewall rule's type. module FirewallRuleType # Unspecified type. FIREWALL_RULE_TYPE_UNSPECIFIED = 0 # Hierarchical firewall policy rule. For details, see # [Hierarchical firewall policies # overview](https://cloud.google.com/vpc/docs/firewall-policies). HIERARCHICAL_FIREWALL_POLICY_RULE = 1 # VPC firewall rule. For details, see # [VPC firewall rules # overview](https://cloud.google.com/vpc/docs/firewalls). VPC_FIREWALL_RULE = 2 # Implied VPC firewall rule. For details, see # [Implied # rules](https://cloud.google.com/vpc/docs/firewalls#default_firewall_rules). IMPLIED_VPC_FIREWALL_RULE = 3 # Implicit firewall rules that are managed by serverless VPC access to # allow ingress access. They are not visible in the Google Cloud console. # For details, see [VPC connector's implicit # rules](https://cloud.google.com/functions/docs/networking/connecting-vpc#restrict-access). SERVERLESS_VPC_ACCESS_MANAGED_FIREWALL_RULE = 4 # User-defined global network firewall policy rule. # For details, see [Network firewall # policies](https://cloud.google.com/vpc/docs/network-firewall-policies). NETWORK_FIREWALL_POLICY_RULE = 5 # User-defined regional network firewall policy rule. # For details, see [Regional network firewall # policies](https://cloud.google.com/firewall/docs/regional-firewall-policies). NETWORK_REGIONAL_FIREWALL_POLICY_RULE = 6 # System-defined global network firewall policy rule. SYSTEM_NETWORK_FIREWALL_POLICY_RULE = 7 # System-defined regional network firewall policy rule. SYSTEM_REGIONAL_NETWORK_FIREWALL_POLICY_RULE = 8 # Firewall policy rule containing attributes not yet supported in # Connectivity tests. Firewall analysis is skipped if such a rule can # potentially be matched. Please see the [list of unsupported # configurations](https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs). UNSUPPORTED_FIREWALL_POLICY_RULE = 100 # Tracking state for response traffic created when request traffic goes # through allow firewall rule. # For details, see [firewall rules # specifications](https://cloud.google.com/firewall/docs/firewalls#specifications) TRACKING_STATE = 101 # Firewall analysis was skipped due to executing Connectivity Test in the # BypassFirewallChecks mode ANALYSIS_SKIPPED = 102 end # Target type of the firewall rule. module TargetType # Target type is not specified. In this case we treat the rule as applying # to INSTANCES target type. TARGET_TYPE_UNSPECIFIED = 0 # Firewall rule applies to instances. INSTANCES = 1 # Firewall rule applies to internal managed load balancers. INTERNAL_MANAGED_LB = 2 end end |
#network_uri ⇒ ::String
Returns The URI of the VPC network that the firewall rule is associated with. This field is not applicable to hierarchical firewall policy rules.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 566 class FirewallInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The firewall rule's type. module FirewallRuleType # Unspecified type. FIREWALL_RULE_TYPE_UNSPECIFIED = 0 # Hierarchical firewall policy rule. For details, see # [Hierarchical firewall policies # overview](https://cloud.google.com/vpc/docs/firewall-policies). HIERARCHICAL_FIREWALL_POLICY_RULE = 1 # VPC firewall rule. For details, see # [VPC firewall rules # overview](https://cloud.google.com/vpc/docs/firewalls). VPC_FIREWALL_RULE = 2 # Implied VPC firewall rule. For details, see # [Implied # rules](https://cloud.google.com/vpc/docs/firewalls#default_firewall_rules). IMPLIED_VPC_FIREWALL_RULE = 3 # Implicit firewall rules that are managed by serverless VPC access to # allow ingress access. They are not visible in the Google Cloud console. # For details, see [VPC connector's implicit # rules](https://cloud.google.com/functions/docs/networking/connecting-vpc#restrict-access). SERVERLESS_VPC_ACCESS_MANAGED_FIREWALL_RULE = 4 # User-defined global network firewall policy rule. # For details, see [Network firewall # policies](https://cloud.google.com/vpc/docs/network-firewall-policies). NETWORK_FIREWALL_POLICY_RULE = 5 # User-defined regional network firewall policy rule. # For details, see [Regional network firewall # policies](https://cloud.google.com/firewall/docs/regional-firewall-policies). NETWORK_REGIONAL_FIREWALL_POLICY_RULE = 6 # System-defined global network firewall policy rule. SYSTEM_NETWORK_FIREWALL_POLICY_RULE = 7 # System-defined regional network firewall policy rule. SYSTEM_REGIONAL_NETWORK_FIREWALL_POLICY_RULE = 8 # Firewall policy rule containing attributes not yet supported in # Connectivity tests. Firewall analysis is skipped if such a rule can # potentially be matched. Please see the [list of unsupported # configurations](https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs). UNSUPPORTED_FIREWALL_POLICY_RULE = 100 # Tracking state for response traffic created when request traffic goes # through allow firewall rule. # For details, see [firewall rules # specifications](https://cloud.google.com/firewall/docs/firewalls#specifications) TRACKING_STATE = 101 # Firewall analysis was skipped due to executing Connectivity Test in the # BypassFirewallChecks mode ANALYSIS_SKIPPED = 102 end # Target type of the firewall rule. module TargetType # Target type is not specified. In this case we treat the rule as applying # to INSTANCES target type. TARGET_TYPE_UNSPECIFIED = 0 # Firewall rule applies to instances. INSTANCES = 1 # Firewall rule applies to internal managed load balancers. INTERNAL_MANAGED_LB = 2 end end |
#policy ⇒ ::String
Returns The name of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 566 class FirewallInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The firewall rule's type. module FirewallRuleType # Unspecified type. FIREWALL_RULE_TYPE_UNSPECIFIED = 0 # Hierarchical firewall policy rule. For details, see # [Hierarchical firewall policies # overview](https://cloud.google.com/vpc/docs/firewall-policies). HIERARCHICAL_FIREWALL_POLICY_RULE = 1 # VPC firewall rule. For details, see # [VPC firewall rules # overview](https://cloud.google.com/vpc/docs/firewalls). VPC_FIREWALL_RULE = 2 # Implied VPC firewall rule. For details, see # [Implied # rules](https://cloud.google.com/vpc/docs/firewalls#default_firewall_rules). IMPLIED_VPC_FIREWALL_RULE = 3 # Implicit firewall rules that are managed by serverless VPC access to # allow ingress access. They are not visible in the Google Cloud console. # For details, see [VPC connector's implicit # rules](https://cloud.google.com/functions/docs/networking/connecting-vpc#restrict-access). SERVERLESS_VPC_ACCESS_MANAGED_FIREWALL_RULE = 4 # User-defined global network firewall policy rule. # For details, see [Network firewall # policies](https://cloud.google.com/vpc/docs/network-firewall-policies). NETWORK_FIREWALL_POLICY_RULE = 5 # User-defined regional network firewall policy rule. # For details, see [Regional network firewall # policies](https://cloud.google.com/firewall/docs/regional-firewall-policies). NETWORK_REGIONAL_FIREWALL_POLICY_RULE = 6 # System-defined global network firewall policy rule. SYSTEM_NETWORK_FIREWALL_POLICY_RULE = 7 # System-defined regional network firewall policy rule. SYSTEM_REGIONAL_NETWORK_FIREWALL_POLICY_RULE = 8 # Firewall policy rule containing attributes not yet supported in # Connectivity tests. Firewall analysis is skipped if such a rule can # potentially be matched. Please see the [list of unsupported # configurations](https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs). UNSUPPORTED_FIREWALL_POLICY_RULE = 100 # Tracking state for response traffic created when request traffic goes # through allow firewall rule. # For details, see [firewall rules # specifications](https://cloud.google.com/firewall/docs/firewalls#specifications) TRACKING_STATE = 101 # Firewall analysis was skipped due to executing Connectivity Test in the # BypassFirewallChecks mode ANALYSIS_SKIPPED = 102 end # Target type of the firewall rule. module TargetType # Target type is not specified. In this case we treat the rule as applying # to INSTANCES target type. TARGET_TYPE_UNSPECIFIED = 0 # Firewall rule applies to instances. INSTANCES = 1 # Firewall rule applies to internal managed load balancers. INTERNAL_MANAGED_LB = 2 end end |
#policy_priority ⇒ ::Integer
Returns The priority of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 566 class FirewallInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The firewall rule's type. module FirewallRuleType # Unspecified type. FIREWALL_RULE_TYPE_UNSPECIFIED = 0 # Hierarchical firewall policy rule. For details, see # [Hierarchical firewall policies # overview](https://cloud.google.com/vpc/docs/firewall-policies). HIERARCHICAL_FIREWALL_POLICY_RULE = 1 # VPC firewall rule. For details, see # [VPC firewall rules # overview](https://cloud.google.com/vpc/docs/firewalls). VPC_FIREWALL_RULE = 2 # Implied VPC firewall rule. For details, see # [Implied # rules](https://cloud.google.com/vpc/docs/firewalls#default_firewall_rules). IMPLIED_VPC_FIREWALL_RULE = 3 # Implicit firewall rules that are managed by serverless VPC access to # allow ingress access. They are not visible in the Google Cloud console. # For details, see [VPC connector's implicit # rules](https://cloud.google.com/functions/docs/networking/connecting-vpc#restrict-access). SERVERLESS_VPC_ACCESS_MANAGED_FIREWALL_RULE = 4 # User-defined global network firewall policy rule. # For details, see [Network firewall # policies](https://cloud.google.com/vpc/docs/network-firewall-policies). NETWORK_FIREWALL_POLICY_RULE = 5 # User-defined regional network firewall policy rule. # For details, see [Regional network firewall # policies](https://cloud.google.com/firewall/docs/regional-firewall-policies). NETWORK_REGIONAL_FIREWALL_POLICY_RULE = 6 # System-defined global network firewall policy rule. SYSTEM_NETWORK_FIREWALL_POLICY_RULE = 7 # System-defined regional network firewall policy rule. SYSTEM_REGIONAL_NETWORK_FIREWALL_POLICY_RULE = 8 # Firewall policy rule containing attributes not yet supported in # Connectivity tests. Firewall analysis is skipped if such a rule can # potentially be matched. Please see the [list of unsupported # configurations](https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs). UNSUPPORTED_FIREWALL_POLICY_RULE = 100 # Tracking state for response traffic created when request traffic goes # through allow firewall rule. # For details, see [firewall rules # specifications](https://cloud.google.com/firewall/docs/firewalls#specifications) TRACKING_STATE = 101 # Firewall analysis was skipped due to executing Connectivity Test in the # BypassFirewallChecks mode ANALYSIS_SKIPPED = 102 end # Target type of the firewall rule. module TargetType # Target type is not specified. In this case we treat the rule as applying # to INSTANCES target type. TARGET_TYPE_UNSPECIFIED = 0 # Firewall rule applies to instances. INSTANCES = 1 # Firewall rule applies to internal managed load balancers. INTERNAL_MANAGED_LB = 2 end end |
#policy_uri ⇒ ::String
Returns The URI of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 566 class FirewallInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The firewall rule's type. module FirewallRuleType # Unspecified type. FIREWALL_RULE_TYPE_UNSPECIFIED = 0 # Hierarchical firewall policy rule. For details, see # [Hierarchical firewall policies # overview](https://cloud.google.com/vpc/docs/firewall-policies). HIERARCHICAL_FIREWALL_POLICY_RULE = 1 # VPC firewall rule. For details, see # [VPC firewall rules # overview](https://cloud.google.com/vpc/docs/firewalls). VPC_FIREWALL_RULE = 2 # Implied VPC firewall rule. For details, see # [Implied # rules](https://cloud.google.com/vpc/docs/firewalls#default_firewall_rules). IMPLIED_VPC_FIREWALL_RULE = 3 # Implicit firewall rules that are managed by serverless VPC access to # allow ingress access. They are not visible in the Google Cloud console. # For details, see [VPC connector's implicit # rules](https://cloud.google.com/functions/docs/networking/connecting-vpc#restrict-access). SERVERLESS_VPC_ACCESS_MANAGED_FIREWALL_RULE = 4 # User-defined global network firewall policy rule. # For details, see [Network firewall # policies](https://cloud.google.com/vpc/docs/network-firewall-policies). NETWORK_FIREWALL_POLICY_RULE = 5 # User-defined regional network firewall policy rule. # For details, see [Regional network firewall # policies](https://cloud.google.com/firewall/docs/regional-firewall-policies). NETWORK_REGIONAL_FIREWALL_POLICY_RULE = 6 # System-defined global network firewall policy rule. SYSTEM_NETWORK_FIREWALL_POLICY_RULE = 7 # System-defined regional network firewall policy rule. SYSTEM_REGIONAL_NETWORK_FIREWALL_POLICY_RULE = 8 # Firewall policy rule containing attributes not yet supported in # Connectivity tests. Firewall analysis is skipped if such a rule can # potentially be matched. Please see the [list of unsupported # configurations](https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs). UNSUPPORTED_FIREWALL_POLICY_RULE = 100 # Tracking state for response traffic created when request traffic goes # through allow firewall rule. # For details, see [firewall rules # specifications](https://cloud.google.com/firewall/docs/firewalls#specifications) TRACKING_STATE = 101 # Firewall analysis was skipped due to executing Connectivity Test in the # BypassFirewallChecks mode ANALYSIS_SKIPPED = 102 end # Target type of the firewall rule. module TargetType # Target type is not specified. In this case we treat the rule as applying # to INSTANCES target type. TARGET_TYPE_UNSPECIFIED = 0 # Firewall rule applies to instances. INSTANCES = 1 # Firewall rule applies to internal managed load balancers. INTERNAL_MANAGED_LB = 2 end end |
#priority ⇒ ::Integer
Returns The priority of the firewall rule.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 566 class FirewallInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The firewall rule's type. module FirewallRuleType # Unspecified type. FIREWALL_RULE_TYPE_UNSPECIFIED = 0 # Hierarchical firewall policy rule. For details, see # [Hierarchical firewall policies # overview](https://cloud.google.com/vpc/docs/firewall-policies). HIERARCHICAL_FIREWALL_POLICY_RULE = 1 # VPC firewall rule. For details, see # [VPC firewall rules # overview](https://cloud.google.com/vpc/docs/firewalls). VPC_FIREWALL_RULE = 2 # Implied VPC firewall rule. For details, see # [Implied # rules](https://cloud.google.com/vpc/docs/firewalls#default_firewall_rules). IMPLIED_VPC_FIREWALL_RULE = 3 # Implicit firewall rules that are managed by serverless VPC access to # allow ingress access. They are not visible in the Google Cloud console. # For details, see [VPC connector's implicit # rules](https://cloud.google.com/functions/docs/networking/connecting-vpc#restrict-access). SERVERLESS_VPC_ACCESS_MANAGED_FIREWALL_RULE = 4 # User-defined global network firewall policy rule. # For details, see [Network firewall # policies](https://cloud.google.com/vpc/docs/network-firewall-policies). NETWORK_FIREWALL_POLICY_RULE = 5 # User-defined regional network firewall policy rule. # For details, see [Regional network firewall # policies](https://cloud.google.com/firewall/docs/regional-firewall-policies). NETWORK_REGIONAL_FIREWALL_POLICY_RULE = 6 # System-defined global network firewall policy rule. SYSTEM_NETWORK_FIREWALL_POLICY_RULE = 7 # System-defined regional network firewall policy rule. SYSTEM_REGIONAL_NETWORK_FIREWALL_POLICY_RULE = 8 # Firewall policy rule containing attributes not yet supported in # Connectivity tests. Firewall analysis is skipped if such a rule can # potentially be matched. Please see the [list of unsupported # configurations](https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs). UNSUPPORTED_FIREWALL_POLICY_RULE = 100 # Tracking state for response traffic created when request traffic goes # through allow firewall rule. # For details, see [firewall rules # specifications](https://cloud.google.com/firewall/docs/firewalls#specifications) TRACKING_STATE = 101 # Firewall analysis was skipped due to executing Connectivity Test in the # BypassFirewallChecks mode ANALYSIS_SKIPPED = 102 end # Target type of the firewall rule. module TargetType # Target type is not specified. In this case we treat the rule as applying # to INSTANCES target type. TARGET_TYPE_UNSPECIFIED = 0 # Firewall rule applies to instances. INSTANCES = 1 # Firewall rule applies to internal managed load balancers. INTERNAL_MANAGED_LB = 2 end end |
#target_service_accounts ⇒ ::Array<::String>
Returns The target service accounts specified by the firewall rule.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 566 class FirewallInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The firewall rule's type. module FirewallRuleType # Unspecified type. FIREWALL_RULE_TYPE_UNSPECIFIED = 0 # Hierarchical firewall policy rule. For details, see # [Hierarchical firewall policies # overview](https://cloud.google.com/vpc/docs/firewall-policies). HIERARCHICAL_FIREWALL_POLICY_RULE = 1 # VPC firewall rule. For details, see # [VPC firewall rules # overview](https://cloud.google.com/vpc/docs/firewalls). VPC_FIREWALL_RULE = 2 # Implied VPC firewall rule. For details, see # [Implied # rules](https://cloud.google.com/vpc/docs/firewalls#default_firewall_rules). IMPLIED_VPC_FIREWALL_RULE = 3 # Implicit firewall rules that are managed by serverless VPC access to # allow ingress access. They are not visible in the Google Cloud console. # For details, see [VPC connector's implicit # rules](https://cloud.google.com/functions/docs/networking/connecting-vpc#restrict-access). SERVERLESS_VPC_ACCESS_MANAGED_FIREWALL_RULE = 4 # User-defined global network firewall policy rule. # For details, see [Network firewall # policies](https://cloud.google.com/vpc/docs/network-firewall-policies). NETWORK_FIREWALL_POLICY_RULE = 5 # User-defined regional network firewall policy rule. # For details, see [Regional network firewall # policies](https://cloud.google.com/firewall/docs/regional-firewall-policies). NETWORK_REGIONAL_FIREWALL_POLICY_RULE = 6 # System-defined global network firewall policy rule. SYSTEM_NETWORK_FIREWALL_POLICY_RULE = 7 # System-defined regional network firewall policy rule. SYSTEM_REGIONAL_NETWORK_FIREWALL_POLICY_RULE = 8 # Firewall policy rule containing attributes not yet supported in # Connectivity tests. Firewall analysis is skipped if such a rule can # potentially be matched. Please see the [list of unsupported # configurations](https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs). UNSUPPORTED_FIREWALL_POLICY_RULE = 100 # Tracking state for response traffic created when request traffic goes # through allow firewall rule. # For details, see [firewall rules # specifications](https://cloud.google.com/firewall/docs/firewalls#specifications) TRACKING_STATE = 101 # Firewall analysis was skipped due to executing Connectivity Test in the # BypassFirewallChecks mode ANALYSIS_SKIPPED = 102 end # Target type of the firewall rule. module TargetType # Target type is not specified. In this case we treat the rule as applying # to INSTANCES target type. TARGET_TYPE_UNSPECIFIED = 0 # Firewall rule applies to instances. INSTANCES = 1 # Firewall rule applies to internal managed load balancers. INTERNAL_MANAGED_LB = 2 end end |
#target_tags ⇒ ::Array<::String>
Returns The target tags defined by the VPC firewall rule. This field is not applicable to firewall policy rules.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 566 class FirewallInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The firewall rule's type. module FirewallRuleType # Unspecified type. FIREWALL_RULE_TYPE_UNSPECIFIED = 0 # Hierarchical firewall policy rule. For details, see # [Hierarchical firewall policies # overview](https://cloud.google.com/vpc/docs/firewall-policies). HIERARCHICAL_FIREWALL_POLICY_RULE = 1 # VPC firewall rule. For details, see # [VPC firewall rules # overview](https://cloud.google.com/vpc/docs/firewalls). VPC_FIREWALL_RULE = 2 # Implied VPC firewall rule. For details, see # [Implied # rules](https://cloud.google.com/vpc/docs/firewalls#default_firewall_rules). IMPLIED_VPC_FIREWALL_RULE = 3 # Implicit firewall rules that are managed by serverless VPC access to # allow ingress access. They are not visible in the Google Cloud console. # For details, see [VPC connector's implicit # rules](https://cloud.google.com/functions/docs/networking/connecting-vpc#restrict-access). SERVERLESS_VPC_ACCESS_MANAGED_FIREWALL_RULE = 4 # User-defined global network firewall policy rule. # For details, see [Network firewall # policies](https://cloud.google.com/vpc/docs/network-firewall-policies). NETWORK_FIREWALL_POLICY_RULE = 5 # User-defined regional network firewall policy rule. # For details, see [Regional network firewall # policies](https://cloud.google.com/firewall/docs/regional-firewall-policies). NETWORK_REGIONAL_FIREWALL_POLICY_RULE = 6 # System-defined global network firewall policy rule. SYSTEM_NETWORK_FIREWALL_POLICY_RULE = 7 # System-defined regional network firewall policy rule. SYSTEM_REGIONAL_NETWORK_FIREWALL_POLICY_RULE = 8 # Firewall policy rule containing attributes not yet supported in # Connectivity tests. Firewall analysis is skipped if such a rule can # potentially be matched. Please see the [list of unsupported # configurations](https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs). UNSUPPORTED_FIREWALL_POLICY_RULE = 100 # Tracking state for response traffic created when request traffic goes # through allow firewall rule. # For details, see [firewall rules # specifications](https://cloud.google.com/firewall/docs/firewalls#specifications) TRACKING_STATE = 101 # Firewall analysis was skipped due to executing Connectivity Test in the # BypassFirewallChecks mode ANALYSIS_SKIPPED = 102 end # Target type of the firewall rule. module TargetType # Target type is not specified. In this case we treat the rule as applying # to INSTANCES target type. TARGET_TYPE_UNSPECIFIED = 0 # Firewall rule applies to instances. INSTANCES = 1 # Firewall rule applies to internal managed load balancers. INTERNAL_MANAGED_LB = 2 end end |
#target_type ⇒ ::Google::Cloud::NetworkManagement::V1::FirewallInfo::TargetType
Returns Target type of the firewall rule.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 566 class FirewallInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The firewall rule's type. module FirewallRuleType # Unspecified type. FIREWALL_RULE_TYPE_UNSPECIFIED = 0 # Hierarchical firewall policy rule. For details, see # [Hierarchical firewall policies # overview](https://cloud.google.com/vpc/docs/firewall-policies). HIERARCHICAL_FIREWALL_POLICY_RULE = 1 # VPC firewall rule. For details, see # [VPC firewall rules # overview](https://cloud.google.com/vpc/docs/firewalls). VPC_FIREWALL_RULE = 2 # Implied VPC firewall rule. For details, see # [Implied # rules](https://cloud.google.com/vpc/docs/firewalls#default_firewall_rules). IMPLIED_VPC_FIREWALL_RULE = 3 # Implicit firewall rules that are managed by serverless VPC access to # allow ingress access. They are not visible in the Google Cloud console. # For details, see [VPC connector's implicit # rules](https://cloud.google.com/functions/docs/networking/connecting-vpc#restrict-access). SERVERLESS_VPC_ACCESS_MANAGED_FIREWALL_RULE = 4 # User-defined global network firewall policy rule. # For details, see [Network firewall # policies](https://cloud.google.com/vpc/docs/network-firewall-policies). NETWORK_FIREWALL_POLICY_RULE = 5 # User-defined regional network firewall policy rule. # For details, see [Regional network firewall # policies](https://cloud.google.com/firewall/docs/regional-firewall-policies). NETWORK_REGIONAL_FIREWALL_POLICY_RULE = 6 # System-defined global network firewall policy rule. SYSTEM_NETWORK_FIREWALL_POLICY_RULE = 7 # System-defined regional network firewall policy rule. SYSTEM_REGIONAL_NETWORK_FIREWALL_POLICY_RULE = 8 # Firewall policy rule containing attributes not yet supported in # Connectivity tests. Firewall analysis is skipped if such a rule can # potentially be matched. Please see the [list of unsupported # configurations](https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs). UNSUPPORTED_FIREWALL_POLICY_RULE = 100 # Tracking state for response traffic created when request traffic goes # through allow firewall rule. # For details, see [firewall rules # specifications](https://cloud.google.com/firewall/docs/firewalls#specifications) TRACKING_STATE = 101 # Firewall analysis was skipped due to executing Connectivity Test in the # BypassFirewallChecks mode ANALYSIS_SKIPPED = 102 end # Target type of the firewall rule. module TargetType # Target type is not specified. In this case we treat the rule as applying # to INSTANCES target type. TARGET_TYPE_UNSPECIFIED = 0 # Firewall rule applies to instances. INSTANCES = 1 # Firewall rule applies to internal managed load balancers. INTERNAL_MANAGED_LB = 2 end end |
#uri ⇒ ::String
Returns The URI of the firewall rule. This field is not applicable to implied VPC firewall rules.
566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 566 class FirewallInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The firewall rule's type. module FirewallRuleType # Unspecified type. FIREWALL_RULE_TYPE_UNSPECIFIED = 0 # Hierarchical firewall policy rule. For details, see # [Hierarchical firewall policies # overview](https://cloud.google.com/vpc/docs/firewall-policies). HIERARCHICAL_FIREWALL_POLICY_RULE = 1 # VPC firewall rule. For details, see # [VPC firewall rules # overview](https://cloud.google.com/vpc/docs/firewalls). VPC_FIREWALL_RULE = 2 # Implied VPC firewall rule. For details, see # [Implied # rules](https://cloud.google.com/vpc/docs/firewalls#default_firewall_rules). IMPLIED_VPC_FIREWALL_RULE = 3 # Implicit firewall rules that are managed by serverless VPC access to # allow ingress access. They are not visible in the Google Cloud console. # For details, see [VPC connector's implicit # rules](https://cloud.google.com/functions/docs/networking/connecting-vpc#restrict-access). SERVERLESS_VPC_ACCESS_MANAGED_FIREWALL_RULE = 4 # User-defined global network firewall policy rule. # For details, see [Network firewall # policies](https://cloud.google.com/vpc/docs/network-firewall-policies). NETWORK_FIREWALL_POLICY_RULE = 5 # User-defined regional network firewall policy rule. # For details, see [Regional network firewall # policies](https://cloud.google.com/firewall/docs/regional-firewall-policies). NETWORK_REGIONAL_FIREWALL_POLICY_RULE = 6 # System-defined global network firewall policy rule. SYSTEM_NETWORK_FIREWALL_POLICY_RULE = 7 # System-defined regional network firewall policy rule. SYSTEM_REGIONAL_NETWORK_FIREWALL_POLICY_RULE = 8 # Firewall policy rule containing attributes not yet supported in # Connectivity tests. Firewall analysis is skipped if such a rule can # potentially be matched. Please see the [list of unsupported # configurations](https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs). UNSUPPORTED_FIREWALL_POLICY_RULE = 100 # Tracking state for response traffic created when request traffic goes # through allow firewall rule. # For details, see [firewall rules # specifications](https://cloud.google.com/firewall/docs/firewalls#specifications) TRACKING_STATE = 101 # Firewall analysis was skipped due to executing Connectivity Test in the # BypassFirewallChecks mode ANALYSIS_SKIPPED = 102 end # Target type of the firewall rule. module TargetType # Target type is not specified. In this case we treat the rule as applying # to INSTANCES target type. TARGET_TYPE_UNSPECIFIED = 0 # Firewall rule applies to instances. INSTANCES = 1 # Firewall rule applies to internal managed load balancers. INTERNAL_MANAGED_LB = 2 end end |