Class: Google::Cloud::NetworkManagement::V1::ForwardInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkmanagement/v1/trace.rb

Overview

Details of the final state "forward" and associated resource.

Defined Under Namespace

Modules: Target

Instance Attribute Summary collapse

Instance Attribute Details

#ip_address::String

Returns IP address of the target (if applicable).

Returns:

  • (::String)

    IP address of the target (if applicable).



1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1331

class ForwardInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Forward target types.
  module Target
    # Target not specified.
    TARGET_UNSPECIFIED = 0

    # Forwarded to a VPC peering network.
    PEERING_VPC = 1

    # Forwarded to a Cloud VPN gateway.
    VPN_GATEWAY = 2

    # Forwarded to a Cloud Interconnect connection.
    INTERCONNECT = 3

    # Forwarded to a Google Kubernetes Engine Container cluster master.
    GKE_MASTER = 4

    # Forwarded to the next hop of a custom route imported from a peering VPC.
    IMPORTED_CUSTOM_ROUTE_NEXT_HOP = 5

    # Forwarded to a Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 6

    # Forwarded to a VPC network in another project.
    ANOTHER_PROJECT = 7

    # Forwarded to an NCC Hub.
    NCC_HUB = 8

    # Forwarded to a router appliance.
    ROUTER_APPLIANCE = 9

    # Forwarded to a Secure Web Proxy Gateway.
    SECURE_WEB_PROXY_GATEWAY = 10
  end
end

#resource_uri::String

Returns URI of the resource that the packet is forwarded to.

Returns:

  • (::String)

    URI of the resource that the packet is forwarded to.



1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1331

class ForwardInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Forward target types.
  module Target
    # Target not specified.
    TARGET_UNSPECIFIED = 0

    # Forwarded to a VPC peering network.
    PEERING_VPC = 1

    # Forwarded to a Cloud VPN gateway.
    VPN_GATEWAY = 2

    # Forwarded to a Cloud Interconnect connection.
    INTERCONNECT = 3

    # Forwarded to a Google Kubernetes Engine Container cluster master.
    GKE_MASTER = 4

    # Forwarded to the next hop of a custom route imported from a peering VPC.
    IMPORTED_CUSTOM_ROUTE_NEXT_HOP = 5

    # Forwarded to a Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 6

    # Forwarded to a VPC network in another project.
    ANOTHER_PROJECT = 7

    # Forwarded to an NCC Hub.
    NCC_HUB = 8

    # Forwarded to a router appliance.
    ROUTER_APPLIANCE = 9

    # Forwarded to a Secure Web Proxy Gateway.
    SECURE_WEB_PROXY_GATEWAY = 10
  end
end

#target::Google::Cloud::NetworkManagement::V1::ForwardInfo::Target

Returns Target type where this packet is forwarded to.

Returns:



1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1331

class ForwardInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Forward target types.
  module Target
    # Target not specified.
    TARGET_UNSPECIFIED = 0

    # Forwarded to a VPC peering network.
    PEERING_VPC = 1

    # Forwarded to a Cloud VPN gateway.
    VPN_GATEWAY = 2

    # Forwarded to a Cloud Interconnect connection.
    INTERCONNECT = 3

    # Forwarded to a Google Kubernetes Engine Container cluster master.
    GKE_MASTER = 4

    # Forwarded to the next hop of a custom route imported from a peering VPC.
    IMPORTED_CUSTOM_ROUTE_NEXT_HOP = 5

    # Forwarded to a Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 6

    # Forwarded to a VPC network in another project.
    ANOTHER_PROJECT = 7

    # Forwarded to an NCC Hub.
    NCC_HUB = 8

    # Forwarded to a router appliance.
    ROUTER_APPLIANCE = 9

    # Forwarded to a Secure Web Proxy Gateway.
    SECURE_WEB_PROXY_GATEWAY = 10
  end
end