Class: Google::Cloud::NetworkManagement::V1::GkeNetworkPolicySkippedInfo
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::GkeNetworkPolicySkippedInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/trace.rb
Overview
For display only. Contains information about why GKE Network Policy evaluation was skipped.
Defined Under Namespace
Modules: Reason
Instance Attribute Summary collapse
-
#reason ⇒ ::Google::Cloud::NetworkManagement::V1::GkeNetworkPolicySkippedInfo::Reason
Reason why Network Policy evaluation was skipped.
Instance Attribute Details
#reason ⇒ ::Google::Cloud::NetworkManagement::V1::GkeNetworkPolicySkippedInfo::Reason
Returns Reason why Network Policy evaluation was skipped.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2163 class GkeNetworkPolicySkippedInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module Reason # Unused default value. REASON_UNSPECIFIED = 0 # Network Policy is disabled on the cluster. NETWORK_POLICY_DISABLED = 1 # Ingress traffic to a Pod from a source on the same Node is always # allowed. INGRESS_SOURCE_ON_SAME_NODE = 2 # Egress traffic from a Pod that uses the Node's network namespace is not # subject to Network Policy. EGRESS_FROM_NODE_NETWORK_NAMESPACE_POD = 3 # Network Policy is not applied to response traffic. This is because GKE # Network Policy evaluation is stateful in both GKE Dataplane V2 (eBPF) and # legacy (iptables) implementations. NETWORK_POLICY_NOT_APPLIED_TO_RESPONSE_TRAFFIC = 4 # Network Policy evaluation is currently not supported for clusters with # FQDN Network Policies enabled. NETWORK_POLICY_ANALYSIS_UNSUPPORTED = 100 end end |