Class: Google::Cloud::NetworkManagement::V1::GkeNetworkPolicySkippedInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkmanagement/v1/trace.rb

Overview

For display only. Contains information about why GKE Network Policy evaluation was skipped.

Defined Under Namespace

Modules: Reason

Instance Attribute Summary collapse

Instance Attribute Details

#reason::Google::Cloud::NetworkManagement::V1::GkeNetworkPolicySkippedInfo::Reason

Returns Reason why Network Policy evaluation was skipped.

Returns:



2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2130

class GkeNetworkPolicySkippedInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  module Reason
    # Unused default value.
    REASON_UNSPECIFIED = 0

    # Network Policy is disabled on the cluster.
    NETWORK_POLICY_DISABLED = 1

    # Ingress traffic to a Pod from a source on the same Node is always
    # allowed.
    INGRESS_SOURCE_ON_SAME_NODE = 2

    # Egress traffic from a Pod that uses the Node's network namespace is not
    # subject to Network Policy.
    EGRESS_FROM_NODE_NETWORK_NAMESPACE_POD = 3

    # Network Policy is not applied to response traffic. This is because GKE
    # Network Policy evaluation is stateful in both GKE Dataplane V2 (eBPF) and
    # legacy (iptables) implementations.
    NETWORK_POLICY_NOT_APPLIED_TO_RESPONSE_TRAFFIC = 4

    # Network Policy evaluation is currently not supported for clusters with
    # FQDN Network Policies enabled.
    NETWORK_POLICY_ANALYSIS_UNSUPPORTED = 100
  end
end