Class: Google::Cloud::NetworkManagement::V1::GoogleServiceInfo
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::GoogleServiceInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/trace.rb
Overview
For display only. Details of a Google Service sending packets to a VPC network. Although the source IP might be a publicly routable address, some Google Services use special routes within Google production infrastructure to reach Compute Engine Instances. https://cloud.google.com/vpc/docs/routes#special_return_paths
Defined Under Namespace
Modules: GoogleServiceType
Instance Attribute Summary collapse
-
#google_service_type ⇒ ::Google::Cloud::NetworkManagement::V1::GoogleServiceInfo::GoogleServiceType
Recognized type of a Google Service.
-
#source_ip ⇒ ::String
Source IP address.
Instance Attribute Details
#google_service_type ⇒ ::Google::Cloud::NetworkManagement::V1::GoogleServiceInfo::GoogleServiceType
Returns Recognized type of a Google Service.
851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 851 class GoogleServiceInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Recognized type of a Google Service. module GoogleServiceType # Unspecified Google Service. GOOGLE_SERVICE_TYPE_UNSPECIFIED = 0 # Identity aware proxy. # https://cloud.google.com/iap/docs/using-tcp-forwarding IAP = 1 # One of two services sharing IP ranges: # * Load Balancer proxy # * Centralized Health Check prober # https://cloud.google.com/load-balancing/docs/firewall-rules GFE_PROXY_OR_HEALTH_CHECK_PROBER = 2 # Connectivity from Cloud DNS to forwarding targets or alternate name # servers that use private routing. # https://cloud.google.com/dns/docs/zones/forwarding-zones#firewall-rules # https://cloud.google.com/dns/docs/policies#firewall-rules CLOUD_DNS = 3 # private.googleapis.com and restricted.googleapis.com GOOGLE_API = 4 # Google API via Private Service Connect. # https://cloud.google.com/vpc/docs/configure-private-service-connect-apis GOOGLE_API_PSC = 5 # Google API via VPC Service Controls. # https://cloud.google.com/vpc/docs/configure-private-service-connect-apis GOOGLE_API_VPC_SC = 6 # Google API via Serverless VPC Access. # https://cloud.google.com/vpc/docs/serverless-vpc-access SERVERLESS_VPC_ACCESS = 7 end end |
#source_ip ⇒ ::String
Returns Source IP address.
851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 851 class GoogleServiceInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Recognized type of a Google Service. module GoogleServiceType # Unspecified Google Service. GOOGLE_SERVICE_TYPE_UNSPECIFIED = 0 # Identity aware proxy. # https://cloud.google.com/iap/docs/using-tcp-forwarding IAP = 1 # One of two services sharing IP ranges: # * Load Balancer proxy # * Centralized Health Check prober # https://cloud.google.com/load-balancing/docs/firewall-rules GFE_PROXY_OR_HEALTH_CHECK_PROBER = 2 # Connectivity from Cloud DNS to forwarding targets or alternate name # servers that use private routing. # https://cloud.google.com/dns/docs/zones/forwarding-zones#firewall-rules # https://cloud.google.com/dns/docs/policies#firewall-rules CLOUD_DNS = 3 # private.googleapis.com and restricted.googleapis.com GOOGLE_API = 4 # Google API via Private Service Connect. # https://cloud.google.com/vpc/docs/configure-private-service-connect-apis GOOGLE_API_PSC = 5 # Google API via VPC Service Controls. # https://cloud.google.com/vpc/docs/configure-private-service-connect-apis GOOGLE_API_VPC_SC = 6 # Google API via Serverless VPC Access. # https://cloud.google.com/vpc/docs/serverless-vpc-access SERVERLESS_VPC_ACCESS = 7 end end |