Class: Google::Cloud::NetworkManagement::V1::HybridSubnetInfo
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::HybridSubnetInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/trace.rb
Overview
For display only. Metadata associated with a hybrid subnet.
Instance Attribute Summary collapse
-
#display_name ⇒ ::String
Name of a hybrid subnet.
-
#region ⇒ ::String
Name of a Google Cloud region where the hybrid subnet is configured.
-
#uri ⇒ ::String
URI of a hybrid subnet.
Instance Attribute Details
#display_name ⇒ ::String
Returns Name of a hybrid subnet.
1042 1043 1044 1045 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1042 class HybridSubnetInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#region ⇒ ::String
Returns Name of a Google Cloud region where the hybrid subnet is configured.
1042 1043 1044 1045 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1042 class HybridSubnetInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#uri ⇒ ::String
Returns URI of a hybrid subnet.
1042 1043 1044 1045 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1042 class HybridSubnetInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |