Class: Google::Cloud::NetworkManagement::V1::IpMasqueradingSkippedInfo
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::IpMasqueradingSkippedInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/trace.rb
Overview
For display only. Contains information about why IP masquerading was skipped for the packet.
Defined Under Namespace
Modules: Reason
Instance Attribute Summary collapse
-
#non_masquerade_range ⇒ ::String
The matched non-masquerade IP range.
-
#reason ⇒ ::Google::Cloud::NetworkManagement::V1::IpMasqueradingSkippedInfo::Reason
Reason why IP masquerading was not applied.
Instance Attribute Details
#non_masquerade_range ⇒ ::String
Returns The matched non-masquerade IP range. Only set if reason is DESTINATION_IP_IN_CONFIGURED_NON_MASQUERADE_RANGE or DESTINATION_IP_IN_DEFAULT_NON_MASQUERADE_RANGE.
2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2100 class IpMasqueradingSkippedInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Reason why IP masquerading was skipped. module Reason # Unused default value. REASON_UNSPECIFIED = 0 # Masquerading not applied because destination IP is in one of configured # non-masquerade ranges. DESTINATION_IP_IN_CONFIGURED_NON_MASQUERADE_RANGE = 1 # Masquerading not applied because destination IP is in one of default # non-masquerade ranges. DESTINATION_IP_IN_DEFAULT_NON_MASQUERADE_RANGE = 2 # Masquerading not applied because destination is on the same Node. DESTINATION_ON_SAME_NODE = 3 # Masquerading not applied because ip-masq-agent doesn't exist and default # SNAT is disabled. DEFAULT_SNAT_DISABLED = 4 # Masquerading not applied because the packet's IP version is IPv6. NO_MASQUERADING_FOR_IPV6 = 5 # Masquerading not applied because the source Pod uses the host Node's # network namespace, including the Node's IP address. POD_USES_NODE_NETWORK_NAMESPACE = 6 # Masquerading not applied because the packet is a return packet. NO_MASQUERADING_FOR_RETURN_PACKET = 7 end end |
#reason ⇒ ::Google::Cloud::NetworkManagement::V1::IpMasqueradingSkippedInfo::Reason
Returns Reason why IP masquerading was not applied.
2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2100 class IpMasqueradingSkippedInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Reason why IP masquerading was skipped. module Reason # Unused default value. REASON_UNSPECIFIED = 0 # Masquerading not applied because destination IP is in one of configured # non-masquerade ranges. DESTINATION_IP_IN_CONFIGURED_NON_MASQUERADE_RANGE = 1 # Masquerading not applied because destination IP is in one of default # non-masquerade ranges. DESTINATION_IP_IN_DEFAULT_NON_MASQUERADE_RANGE = 2 # Masquerading not applied because destination is on the same Node. DESTINATION_ON_SAME_NODE = 3 # Masquerading not applied because ip-masq-agent doesn't exist and default # SNAT is disabled. DEFAULT_SNAT_DISABLED = 4 # Masquerading not applied because the packet's IP version is IPv6. NO_MASQUERADING_FOR_IPV6 = 5 # Masquerading not applied because the source Pod uses the host Node's # network namespace, including the Node's IP address. POD_USES_NODE_NETWORK_NAMESPACE = 6 # Masquerading not applied because the packet is a return packet. NO_MASQUERADING_FOR_RETURN_PACKET = 7 end end |