Class: Google::Cloud::NetworkManagement::V1::IpMasqueradingSkippedInfo
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::IpMasqueradingSkippedInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/trace.rb
Overview
For display only. Contains information about why IP masquerading was skipped for the packet.
Defined Under Namespace
Modules: Reason
Instance Attribute Summary collapse
-
#non_masquerade_range ⇒ ::String
The matched non-masquerade IP range.
-
#reason ⇒ ::Google::Cloud::NetworkManagement::V1::IpMasqueradingSkippedInfo::Reason
Reason why IP masquerading was not applied.
Instance Attribute Details
#non_masquerade_range ⇒ ::String
Returns The matched non-masquerade IP range. Only set if reason is DESTINATION_IP_IN_CONFIGURED_NON_MASQUERADE_RANGE or DESTINATION_IP_IN_DEFAULT_NON_MASQUERADE_RANGE.
2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2067 class IpMasqueradingSkippedInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Reason why IP masquerading was skipped. module Reason # Unused default value. REASON_UNSPECIFIED = 0 # Masquerading not applied because destination IP is in one of configured # non-masquerade ranges. DESTINATION_IP_IN_CONFIGURED_NON_MASQUERADE_RANGE = 1 # Masquerading not applied because destination IP is in one of default # non-masquerade ranges. DESTINATION_IP_IN_DEFAULT_NON_MASQUERADE_RANGE = 2 # Masquerading not applied because destination is on the same Node. DESTINATION_ON_SAME_NODE = 3 # Masquerading not applied because ip-masq-agent doesn't exist and default # SNAT is disabled. DEFAULT_SNAT_DISABLED = 4 # Masquerading not applied because the packet's IP version is IPv6. NO_MASQUERADING_FOR_IPV6 = 5 # Masquerading not applied because the source Pod uses the host Node's # network namespace, including the Node's IP address. POD_USES_NODE_NETWORK_NAMESPACE = 6 # Masquerading not applied because the packet is a return packet. NO_MASQUERADING_FOR_RETURN_PACKET = 7 end end |
#reason ⇒ ::Google::Cloud::NetworkManagement::V1::IpMasqueradingSkippedInfo::Reason
Returns Reason why IP masquerading was not applied.
2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2067 class IpMasqueradingSkippedInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Reason why IP masquerading was skipped. module Reason # Unused default value. REASON_UNSPECIFIED = 0 # Masquerading not applied because destination IP is in one of configured # non-masquerade ranges. DESTINATION_IP_IN_CONFIGURED_NON_MASQUERADE_RANGE = 1 # Masquerading not applied because destination IP is in one of default # non-masquerade ranges. DESTINATION_IP_IN_DEFAULT_NON_MASQUERADE_RANGE = 2 # Masquerading not applied because destination is on the same Node. DESTINATION_ON_SAME_NODE = 3 # Masquerading not applied because ip-masq-agent doesn't exist and default # SNAT is disabled. DEFAULT_SNAT_DISABLED = 4 # Masquerading not applied because the packet's IP version is IPv6. NO_MASQUERADING_FOR_IPV6 = 5 # Masquerading not applied because the source Pod uses the host Node's # network namespace, including the Node's IP address. POD_USES_NODE_NETWORK_NAMESPACE = 6 # Masquerading not applied because the packet is a return packet. NO_MASQUERADING_FOR_RETURN_PACKET = 7 end end |