Module: Google::Cloud::NetworkManagement::V1::IpMasqueradingSkippedInfo::Reason
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/trace.rb
Overview
Reason why IP masquerading was skipped.
Constant Summary collapse
- REASON_UNSPECIFIED =
Unused default value.
0- DESTINATION_IP_IN_CONFIGURED_NON_MASQUERADE_RANGE =
Masquerading not applied because destination IP is in one of configured non-masquerade ranges.
1- DESTINATION_IP_IN_DEFAULT_NON_MASQUERADE_RANGE =
Masquerading not applied because destination IP is in one of default non-masquerade ranges.
2- DESTINATION_ON_SAME_NODE =
Masquerading not applied because destination is on the same Node.
3- DEFAULT_SNAT_DISABLED =
Masquerading not applied because ip-masq-agent doesn't exist and default SNAT is disabled.
4- NO_MASQUERADING_FOR_IPV6 =
Masquerading not applied because the packet's IP version is IPv6.
5- POD_USES_NODE_NETWORK_NAMESPACE =
Masquerading not applied because the source Pod uses the host Node's network namespace, including the Node's IP address.
6- NO_MASQUERADING_FOR_RETURN_PACKET =
Masquerading not applied because the packet is a return packet.
7