Class: Google::Cloud::NetworkManagement::V1::LoadBalancerBackendInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkmanagement/v1/trace.rb

Overview

For display only. Metadata associated with the load balancer backend.

Defined Under Namespace

Modules: HealthCheckFirewallsConfigState

Instance Attribute Summary collapse

Instance Attribute Details

#backend_bucket_uri::String

Returns URI of the backend bucket this backend targets (if applicable).

Returns:

  • (::String)

    URI of the backend bucket this backend targets (if applicable).



2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2510

class LoadBalancerBackendInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health check firewalls configuration state enum.
  module HealthCheckFirewallsConfigState
    # Configuration state unspecified. It usually means that the backend has
    # no health check attached, or there was an unexpected configuration error
    # preventing Connectivity tests from verifying health check configuration.
    HEALTH_CHECK_FIREWALLS_CONFIG_STATE_UNSPECIFIED = 0

    # Firewall rules (policies) allowing health check traffic from all required
    # IP ranges to the backend are configured.
    FIREWALLS_CONFIGURED = 1

    # Firewall rules (policies) allow health check traffic only from a part of
    # required IP ranges.
    FIREWALLS_PARTIALLY_CONFIGURED = 2

    # Firewall rules (policies) deny health check traffic from all required
    # IP ranges to the backend.
    FIREWALLS_NOT_CONFIGURED = 3

    # The network contains firewall rules of unsupported types, so Connectivity
    # tests were not able to verify health check configuration status. Please
    # refer to the documentation for the list of unsupported configurations:
    # https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs
    FIREWALLS_UNSUPPORTED = 4
  end
end

#backend_service_uri::String

Returns URI of the backend service this backend belongs to (if applicable).

Returns:

  • (::String)

    URI of the backend service this backend belongs to (if applicable).



2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2510

class LoadBalancerBackendInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health check firewalls configuration state enum.
  module HealthCheckFirewallsConfigState
    # Configuration state unspecified. It usually means that the backend has
    # no health check attached, or there was an unexpected configuration error
    # preventing Connectivity tests from verifying health check configuration.
    HEALTH_CHECK_FIREWALLS_CONFIG_STATE_UNSPECIFIED = 0

    # Firewall rules (policies) allowing health check traffic from all required
    # IP ranges to the backend are configured.
    FIREWALLS_CONFIGURED = 1

    # Firewall rules (policies) allow health check traffic only from a part of
    # required IP ranges.
    FIREWALLS_PARTIALLY_CONFIGURED = 2

    # Firewall rules (policies) deny health check traffic from all required
    # IP ranges to the backend.
    FIREWALLS_NOT_CONFIGURED = 3

    # The network contains firewall rules of unsupported types, so Connectivity
    # tests were not able to verify health check configuration status. Please
    # refer to the documentation for the list of unsupported configurations:
    # https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs
    FIREWALLS_UNSUPPORTED = 4
  end
end

#health_check_firewalls_config_state::Google::Cloud::NetworkManagement::V1::LoadBalancerBackendInfo::HealthCheckFirewallsConfigState (readonly)

Returns Output only. Health check firewalls configuration state for the backend. This is a result of the static firewall analysis (verifying that health check traffic from required IP ranges to the backend is allowed or not). The backend might still be unhealthy even if these firewalls are configured. Please refer to the documentation for more information: https://cloud.google.com/load-balancing/docs/firewall-rules.

Returns:



2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2510

class LoadBalancerBackendInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health check firewalls configuration state enum.
  module HealthCheckFirewallsConfigState
    # Configuration state unspecified. It usually means that the backend has
    # no health check attached, or there was an unexpected configuration error
    # preventing Connectivity tests from verifying health check configuration.
    HEALTH_CHECK_FIREWALLS_CONFIG_STATE_UNSPECIFIED = 0

    # Firewall rules (policies) allowing health check traffic from all required
    # IP ranges to the backend are configured.
    FIREWALLS_CONFIGURED = 1

    # Firewall rules (policies) allow health check traffic only from a part of
    # required IP ranges.
    FIREWALLS_PARTIALLY_CONFIGURED = 2

    # Firewall rules (policies) deny health check traffic from all required
    # IP ranges to the backend.
    FIREWALLS_NOT_CONFIGURED = 3

    # The network contains firewall rules of unsupported types, so Connectivity
    # tests were not able to verify health check configuration status. Please
    # refer to the documentation for the list of unsupported configurations:
    # https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs
    FIREWALLS_UNSUPPORTED = 4
  end
end

#health_check_uri::String

Returns URI of the health check attached to this backend (if applicable).

Returns:

  • (::String)

    URI of the health check attached to this backend (if applicable).



2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2510

class LoadBalancerBackendInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health check firewalls configuration state enum.
  module HealthCheckFirewallsConfigState
    # Configuration state unspecified. It usually means that the backend has
    # no health check attached, or there was an unexpected configuration error
    # preventing Connectivity tests from verifying health check configuration.
    HEALTH_CHECK_FIREWALLS_CONFIG_STATE_UNSPECIFIED = 0

    # Firewall rules (policies) allowing health check traffic from all required
    # IP ranges to the backend are configured.
    FIREWALLS_CONFIGURED = 1

    # Firewall rules (policies) allow health check traffic only from a part of
    # required IP ranges.
    FIREWALLS_PARTIALLY_CONFIGURED = 2

    # Firewall rules (policies) deny health check traffic from all required
    # IP ranges to the backend.
    FIREWALLS_NOT_CONFIGURED = 3

    # The network contains firewall rules of unsupported types, so Connectivity
    # tests were not able to verify health check configuration status. Please
    # refer to the documentation for the list of unsupported configurations:
    # https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs
    FIREWALLS_UNSUPPORTED = 4
  end
end

#instance_group_uri::String

Returns URI of the instance group this backend belongs to (if applicable).

Returns:

  • (::String)

    URI of the instance group this backend belongs to (if applicable).



2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2510

class LoadBalancerBackendInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health check firewalls configuration state enum.
  module HealthCheckFirewallsConfigState
    # Configuration state unspecified. It usually means that the backend has
    # no health check attached, or there was an unexpected configuration error
    # preventing Connectivity tests from verifying health check configuration.
    HEALTH_CHECK_FIREWALLS_CONFIG_STATE_UNSPECIFIED = 0

    # Firewall rules (policies) allowing health check traffic from all required
    # IP ranges to the backend are configured.
    FIREWALLS_CONFIGURED = 1

    # Firewall rules (policies) allow health check traffic only from a part of
    # required IP ranges.
    FIREWALLS_PARTIALLY_CONFIGURED = 2

    # Firewall rules (policies) deny health check traffic from all required
    # IP ranges to the backend.
    FIREWALLS_NOT_CONFIGURED = 3

    # The network contains firewall rules of unsupported types, so Connectivity
    # tests were not able to verify health check configuration status. Please
    # refer to the documentation for the list of unsupported configurations:
    # https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs
    FIREWALLS_UNSUPPORTED = 4
  end
end

#instance_uri::String

Returns URI of the backend instance (if applicable). Populated for instance group backends, and zonal NEG backends.

Returns:

  • (::String)

    URI of the backend instance (if applicable). Populated for instance group backends, and zonal NEG backends.



2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2510

class LoadBalancerBackendInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health check firewalls configuration state enum.
  module HealthCheckFirewallsConfigState
    # Configuration state unspecified. It usually means that the backend has
    # no health check attached, or there was an unexpected configuration error
    # preventing Connectivity tests from verifying health check configuration.
    HEALTH_CHECK_FIREWALLS_CONFIG_STATE_UNSPECIFIED = 0

    # Firewall rules (policies) allowing health check traffic from all required
    # IP ranges to the backend are configured.
    FIREWALLS_CONFIGURED = 1

    # Firewall rules (policies) allow health check traffic only from a part of
    # required IP ranges.
    FIREWALLS_PARTIALLY_CONFIGURED = 2

    # Firewall rules (policies) deny health check traffic from all required
    # IP ranges to the backend.
    FIREWALLS_NOT_CONFIGURED = 3

    # The network contains firewall rules of unsupported types, so Connectivity
    # tests were not able to verify health check configuration status. Please
    # refer to the documentation for the list of unsupported configurations:
    # https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs
    FIREWALLS_UNSUPPORTED = 4
  end
end

#name::String

Returns Display name of the backend. For example, it might be an instance name for the instance group backends, or an IP address and port for zonal network endpoint group backends.

Returns:

  • (::String)

    Display name of the backend. For example, it might be an instance name for the instance group backends, or an IP address and port for zonal network endpoint group backends.



2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2510

class LoadBalancerBackendInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health check firewalls configuration state enum.
  module HealthCheckFirewallsConfigState
    # Configuration state unspecified. It usually means that the backend has
    # no health check attached, or there was an unexpected configuration error
    # preventing Connectivity tests from verifying health check configuration.
    HEALTH_CHECK_FIREWALLS_CONFIG_STATE_UNSPECIFIED = 0

    # Firewall rules (policies) allowing health check traffic from all required
    # IP ranges to the backend are configured.
    FIREWALLS_CONFIGURED = 1

    # Firewall rules (policies) allow health check traffic only from a part of
    # required IP ranges.
    FIREWALLS_PARTIALLY_CONFIGURED = 2

    # Firewall rules (policies) deny health check traffic from all required
    # IP ranges to the backend.
    FIREWALLS_NOT_CONFIGURED = 3

    # The network contains firewall rules of unsupported types, so Connectivity
    # tests were not able to verify health check configuration status. Please
    # refer to the documentation for the list of unsupported configurations:
    # https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs
    FIREWALLS_UNSUPPORTED = 4
  end
end

#network_endpoint_group_uri::String

Returns URI of the network endpoint group this backend belongs to (if applicable).

Returns:

  • (::String)

    URI of the network endpoint group this backend belongs to (if applicable).



2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2510

class LoadBalancerBackendInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health check firewalls configuration state enum.
  module HealthCheckFirewallsConfigState
    # Configuration state unspecified. It usually means that the backend has
    # no health check attached, or there was an unexpected configuration error
    # preventing Connectivity tests from verifying health check configuration.
    HEALTH_CHECK_FIREWALLS_CONFIG_STATE_UNSPECIFIED = 0

    # Firewall rules (policies) allowing health check traffic from all required
    # IP ranges to the backend are configured.
    FIREWALLS_CONFIGURED = 1

    # Firewall rules (policies) allow health check traffic only from a part of
    # required IP ranges.
    FIREWALLS_PARTIALLY_CONFIGURED = 2

    # Firewall rules (policies) deny health check traffic from all required
    # IP ranges to the backend.
    FIREWALLS_NOT_CONFIGURED = 3

    # The network contains firewall rules of unsupported types, so Connectivity
    # tests were not able to verify health check configuration status. Please
    # refer to the documentation for the list of unsupported configurations:
    # https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs
    FIREWALLS_UNSUPPORTED = 4
  end
end

#psc_google_api_target::String

Returns PSC Google API target this PSC NEG backend targets (if applicable).

Returns:

  • (::String)

    PSC Google API target this PSC NEG backend targets (if applicable).



2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2510

class LoadBalancerBackendInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health check firewalls configuration state enum.
  module HealthCheckFirewallsConfigState
    # Configuration state unspecified. It usually means that the backend has
    # no health check attached, or there was an unexpected configuration error
    # preventing Connectivity tests from verifying health check configuration.
    HEALTH_CHECK_FIREWALLS_CONFIG_STATE_UNSPECIFIED = 0

    # Firewall rules (policies) allowing health check traffic from all required
    # IP ranges to the backend are configured.
    FIREWALLS_CONFIGURED = 1

    # Firewall rules (policies) allow health check traffic only from a part of
    # required IP ranges.
    FIREWALLS_PARTIALLY_CONFIGURED = 2

    # Firewall rules (policies) deny health check traffic from all required
    # IP ranges to the backend.
    FIREWALLS_NOT_CONFIGURED = 3

    # The network contains firewall rules of unsupported types, so Connectivity
    # tests were not able to verify health check configuration status. Please
    # refer to the documentation for the list of unsupported configurations:
    # https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs
    FIREWALLS_UNSUPPORTED = 4
  end
end

#psc_service_attachment_uri::String

Returns URI of the PSC service attachment this PSC NEG backend targets (if applicable).

Returns:

  • (::String)

    URI of the PSC service attachment this PSC NEG backend targets (if applicable).



2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2510

class LoadBalancerBackendInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health check firewalls configuration state enum.
  module HealthCheckFirewallsConfigState
    # Configuration state unspecified. It usually means that the backend has
    # no health check attached, or there was an unexpected configuration error
    # preventing Connectivity tests from verifying health check configuration.
    HEALTH_CHECK_FIREWALLS_CONFIG_STATE_UNSPECIFIED = 0

    # Firewall rules (policies) allowing health check traffic from all required
    # IP ranges to the backend are configured.
    FIREWALLS_CONFIGURED = 1

    # Firewall rules (policies) allow health check traffic only from a part of
    # required IP ranges.
    FIREWALLS_PARTIALLY_CONFIGURED = 2

    # Firewall rules (policies) deny health check traffic from all required
    # IP ranges to the backend.
    FIREWALLS_NOT_CONFIGURED = 3

    # The network contains firewall rules of unsupported types, so Connectivity
    # tests were not able to verify health check configuration status. Please
    # refer to the documentation for the list of unsupported configurations:
    # https://cloud.google.com/network-intelligence-center/docs/connectivity-tests/concepts/overview#unsupported-configs
    FIREWALLS_UNSUPPORTED = 4
  end
end