Class: Google::Cloud::NetworkManagement::V1::LoadBalancerInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/networkmanagement/v1/trace.rb

Overview

For display only. Metadata associated with a load balancer.

Defined Under Namespace

Modules: BackendType, LoadBalancerType

Instance Attribute Summary collapse

Instance Attribute Details

#backend_type::Google::Cloud::NetworkManagement::V1::LoadBalancerInfo::BackendType

Returns Type of load balancer's backend configuration.

Returns:



953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 953

class LoadBalancerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type definition for a load balancer:
  module LoadBalancerType
    # Type is unspecified.
    LOAD_BALANCER_TYPE_UNSPECIFIED = 0

    # Internal TCP/UDP load balancer.
    INTERNAL_TCP_UDP = 1

    # Network TCP/UDP load balancer.
    NETWORK_TCP_UDP = 2

    # HTTP(S) proxy load balancer.
    HTTP_PROXY = 3

    # TCP proxy load balancer.
    TCP_PROXY = 4

    # SSL proxy load balancer.
    SSL_PROXY = 5
  end

  # The type definition for a load balancer backend configuration:
  module BackendType
    # Type is unspecified.
    BACKEND_TYPE_UNSPECIFIED = 0

    # Backend Service as the load balancer's backend.
    BACKEND_SERVICE = 1

    # Target Pool as the load balancer's backend.
    TARGET_POOL = 2

    # Target Instance as the load balancer's backend.
    TARGET_INSTANCE = 3
  end
end

#backend_uri::String

Returns Backend configuration URI.

Returns:

  • (::String)

    Backend configuration URI.



953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 953

class LoadBalancerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type definition for a load balancer:
  module LoadBalancerType
    # Type is unspecified.
    LOAD_BALANCER_TYPE_UNSPECIFIED = 0

    # Internal TCP/UDP load balancer.
    INTERNAL_TCP_UDP = 1

    # Network TCP/UDP load balancer.
    NETWORK_TCP_UDP = 2

    # HTTP(S) proxy load balancer.
    HTTP_PROXY = 3

    # TCP proxy load balancer.
    TCP_PROXY = 4

    # SSL proxy load balancer.
    SSL_PROXY = 5
  end

  # The type definition for a load balancer backend configuration:
  module BackendType
    # Type is unspecified.
    BACKEND_TYPE_UNSPECIFIED = 0

    # Backend Service as the load balancer's backend.
    BACKEND_SERVICE = 1

    # Target Pool as the load balancer's backend.
    TARGET_POOL = 2

    # Target Instance as the load balancer's backend.
    TARGET_INSTANCE = 3
  end
end

#backends::Array<::Google::Cloud::NetworkManagement::V1::LoadBalancerBackend>

Returns Information for the loadbalancer backends.

Returns:



953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 953

class LoadBalancerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type definition for a load balancer:
  module LoadBalancerType
    # Type is unspecified.
    LOAD_BALANCER_TYPE_UNSPECIFIED = 0

    # Internal TCP/UDP load balancer.
    INTERNAL_TCP_UDP = 1

    # Network TCP/UDP load balancer.
    NETWORK_TCP_UDP = 2

    # HTTP(S) proxy load balancer.
    HTTP_PROXY = 3

    # TCP proxy load balancer.
    TCP_PROXY = 4

    # SSL proxy load balancer.
    SSL_PROXY = 5
  end

  # The type definition for a load balancer backend configuration:
  module BackendType
    # Type is unspecified.
    BACKEND_TYPE_UNSPECIFIED = 0

    # Backend Service as the load balancer's backend.
    BACKEND_SERVICE = 1

    # Target Pool as the load balancer's backend.
    TARGET_POOL = 2

    # Target Instance as the load balancer's backend.
    TARGET_INSTANCE = 3
  end
end

#health_check_uri::String

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns URI of the health check for the load balancer. Deprecated and no longer populated as different load balancer backends might have different health checks.

Returns:

  • (::String)

    URI of the health check for the load balancer. Deprecated and no longer populated as different load balancer backends might have different health checks.



953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 953

class LoadBalancerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type definition for a load balancer:
  module LoadBalancerType
    # Type is unspecified.
    LOAD_BALANCER_TYPE_UNSPECIFIED = 0

    # Internal TCP/UDP load balancer.
    INTERNAL_TCP_UDP = 1

    # Network TCP/UDP load balancer.
    NETWORK_TCP_UDP = 2

    # HTTP(S) proxy load balancer.
    HTTP_PROXY = 3

    # TCP proxy load balancer.
    TCP_PROXY = 4

    # SSL proxy load balancer.
    SSL_PROXY = 5
  end

  # The type definition for a load balancer backend configuration:
  module BackendType
    # Type is unspecified.
    BACKEND_TYPE_UNSPECIFIED = 0

    # Backend Service as the load balancer's backend.
    BACKEND_SERVICE = 1

    # Target Pool as the load balancer's backend.
    TARGET_POOL = 2

    # Target Instance as the load balancer's backend.
    TARGET_INSTANCE = 3
  end
end

#load_balancer_type::Google::Cloud::NetworkManagement::V1::LoadBalancerInfo::LoadBalancerType

Returns Type of the load balancer.



953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 953

class LoadBalancerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type definition for a load balancer:
  module LoadBalancerType
    # Type is unspecified.
    LOAD_BALANCER_TYPE_UNSPECIFIED = 0

    # Internal TCP/UDP load balancer.
    INTERNAL_TCP_UDP = 1

    # Network TCP/UDP load balancer.
    NETWORK_TCP_UDP = 2

    # HTTP(S) proxy load balancer.
    HTTP_PROXY = 3

    # TCP proxy load balancer.
    TCP_PROXY = 4

    # SSL proxy load balancer.
    SSL_PROXY = 5
  end

  # The type definition for a load balancer backend configuration:
  module BackendType
    # Type is unspecified.
    BACKEND_TYPE_UNSPECIFIED = 0

    # Backend Service as the load balancer's backend.
    BACKEND_SERVICE = 1

    # Target Pool as the load balancer's backend.
    TARGET_POOL = 2

    # Target Instance as the load balancer's backend.
    TARGET_INSTANCE = 3
  end
end