Class: Google::Cloud::NetworkManagement::V1::NgfwPacketInspectionInfo
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::NgfwPacketInspectionInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/trace.rb
Overview
For display only. Metadata associated with a layer 7 packet inspection by the firewall.
Instance Attribute Summary collapse
-
#security_profile_group_uri ⇒ ::String
URI of the security profile group associated with this firewall packet inspection.
Instance Attribute Details
#security_profile_group_uri ⇒ ::String
Returns URI of the security profile group associated with this firewall packet inspection.
2566 2567 2568 2569 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 2566 class NgfwPacketInspectionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |