Class: Google::Cloud::NetworkManagement::V1::ProbingDetails
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::ProbingDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb
Overview
Results of active probing from the last run of the test.
Defined Under Namespace
Modules: ProbingAbortCause, ProbingResult Classes: EdgeLocation, SingleEdgeResponse
Instance Attribute Summary collapse
-
#abort_cause ⇒ ::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingAbortCause
The reason probing was aborted.
-
#destination_egress_location ⇒ ::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation
The EdgeLocation from which a packet, destined to the internet, will egress the Google network.
-
#edge_responses ⇒ ::Array<::Google::Cloud::NetworkManagement::V1::ProbingDetails::SingleEdgeResponse>
Probing results for all edge devices.
-
#endpoint_info ⇒ ::Google::Cloud::NetworkManagement::V1::EndpointInfo
The source and destination endpoints derived from the test input and used for active probing.
-
#error ⇒ ::Google::Rpc::Status
Details about an internal failure or the cancellation of active probing.
-
#probed_all_devices ⇒ ::Boolean
Whether all relevant edge devices were probed.
-
#probing_latency ⇒ ::Google::Cloud::NetworkManagement::V1::LatencyDistribution
Latency as measured by active probing in one direction: from the source to the destination endpoint.
-
#result ⇒ ::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult
The overall result of active probing.
-
#sent_probe_count ⇒ ::Integer
Number of probes sent.
-
#successful_probe_count ⇒ ::Integer
Number of probes that reached the destination.
-
#verify_time ⇒ ::Google::Protobuf::Timestamp
The time that reachability was assessed through active probing.
Instance Attribute Details
#abort_cause ⇒ ::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingAbortCause
Returns The reason probing was aborted.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 407 class ProbingDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Representation of a network edge location as per # https://cloud.google.com/vpc/docs/edge-locations. # @!attribute [rw] metropolitan_area # @return [::String] # Name of the metropolitan area. class EdgeLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Probing results for a single edge device. # @!attribute [rw] result # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult] # The overall result of active probing for this egress device. # @!attribute [rw] sent_probe_count # @return [::Integer] # Number of probes sent. # @!attribute [rw] successful_probe_count # @return [::Integer] # Number of probes that reached the destination. # @!attribute [rw] probing_latency # @return [::Google::Cloud::NetworkManagement::V1::LatencyDistribution] # Latency as measured by active probing in one direction: from the source # to the destination endpoint. # @!attribute [rw] destination_egress_location # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation] # The EdgeLocation from which a packet, destined to the internet, will # egress the Google network. # This will only be populated for a connectivity test which has an internet # destination address. # The absence of this field *must not* be used as an indication that the # destination is part of the Google network. # @!attribute [rw] destination_router # @return [::String] # Router name in the format '\\{router}.\\{metroshard}'. For example: # pf01.aaa01, pr02.aaa01. class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Overall probing result of the test. module ProbingResult # No result was specified. PROBING_RESULT_UNSPECIFIED = 0 # At least 95% of packets reached the destination. REACHABLE = 1 # No packets reached the destination. UNREACHABLE = 2 # Less than 95% of packets reached the destination. REACHABILITY_INCONSISTENT = 3 # Reachability could not be determined. Possible reasons are: # * The user lacks permission to access some of the network resources # required to run the test. # * No valid source endpoint could be derived from the request. # * An internal error occurred. UNDETERMINED = 4 end # Abort cause types. module ProbingAbortCause # No reason was specified. PROBING_ABORT_CAUSE_UNSPECIFIED = 0 # The user lacks permission to access some of the # network resources required to run the test. PERMISSION_DENIED = 1 # No valid source endpoint could be derived from the request. NO_SOURCE_LOCATION = 2 end end |
#destination_egress_location ⇒ ::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation
Returns The EdgeLocation from which a packet, destined to the internet, will egress the Google network. This will only be populated for a connectivity test which has an internet destination address. The absence of this field must not be used as an indication that the destination is part of the Google network.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 407 class ProbingDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Representation of a network edge location as per # https://cloud.google.com/vpc/docs/edge-locations. # @!attribute [rw] metropolitan_area # @return [::String] # Name of the metropolitan area. class EdgeLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Probing results for a single edge device. # @!attribute [rw] result # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult] # The overall result of active probing for this egress device. # @!attribute [rw] sent_probe_count # @return [::Integer] # Number of probes sent. # @!attribute [rw] successful_probe_count # @return [::Integer] # Number of probes that reached the destination. # @!attribute [rw] probing_latency # @return [::Google::Cloud::NetworkManagement::V1::LatencyDistribution] # Latency as measured by active probing in one direction: from the source # to the destination endpoint. # @!attribute [rw] destination_egress_location # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation] # The EdgeLocation from which a packet, destined to the internet, will # egress the Google network. # This will only be populated for a connectivity test which has an internet # destination address. # The absence of this field *must not* be used as an indication that the # destination is part of the Google network. # @!attribute [rw] destination_router # @return [::String] # Router name in the format '\\{router}.\\{metroshard}'. For example: # pf01.aaa01, pr02.aaa01. class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Overall probing result of the test. module ProbingResult # No result was specified. PROBING_RESULT_UNSPECIFIED = 0 # At least 95% of packets reached the destination. REACHABLE = 1 # No packets reached the destination. UNREACHABLE = 2 # Less than 95% of packets reached the destination. REACHABILITY_INCONSISTENT = 3 # Reachability could not be determined. Possible reasons are: # * The user lacks permission to access some of the network resources # required to run the test. # * No valid source endpoint could be derived from the request. # * An internal error occurred. UNDETERMINED = 4 end # Abort cause types. module ProbingAbortCause # No reason was specified. PROBING_ABORT_CAUSE_UNSPECIFIED = 0 # The user lacks permission to access some of the # network resources required to run the test. PERMISSION_DENIED = 1 # No valid source endpoint could be derived from the request. NO_SOURCE_LOCATION = 2 end end |
#edge_responses ⇒ ::Array<::Google::Cloud::NetworkManagement::V1::ProbingDetails::SingleEdgeResponse>
Returns Probing results for all edge devices.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 407 class ProbingDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Representation of a network edge location as per # https://cloud.google.com/vpc/docs/edge-locations. # @!attribute [rw] metropolitan_area # @return [::String] # Name of the metropolitan area. class EdgeLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Probing results for a single edge device. # @!attribute [rw] result # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult] # The overall result of active probing for this egress device. # @!attribute [rw] sent_probe_count # @return [::Integer] # Number of probes sent. # @!attribute [rw] successful_probe_count # @return [::Integer] # Number of probes that reached the destination. # @!attribute [rw] probing_latency # @return [::Google::Cloud::NetworkManagement::V1::LatencyDistribution] # Latency as measured by active probing in one direction: from the source # to the destination endpoint. # @!attribute [rw] destination_egress_location # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation] # The EdgeLocation from which a packet, destined to the internet, will # egress the Google network. # This will only be populated for a connectivity test which has an internet # destination address. # The absence of this field *must not* be used as an indication that the # destination is part of the Google network. # @!attribute [rw] destination_router # @return [::String] # Router name in the format '\\{router}.\\{metroshard}'. For example: # pf01.aaa01, pr02.aaa01. class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Overall probing result of the test. module ProbingResult # No result was specified. PROBING_RESULT_UNSPECIFIED = 0 # At least 95% of packets reached the destination. REACHABLE = 1 # No packets reached the destination. UNREACHABLE = 2 # Less than 95% of packets reached the destination. REACHABILITY_INCONSISTENT = 3 # Reachability could not be determined. Possible reasons are: # * The user lacks permission to access some of the network resources # required to run the test. # * No valid source endpoint could be derived from the request. # * An internal error occurred. UNDETERMINED = 4 end # Abort cause types. module ProbingAbortCause # No reason was specified. PROBING_ABORT_CAUSE_UNSPECIFIED = 0 # The user lacks permission to access some of the # network resources required to run the test. PERMISSION_DENIED = 1 # No valid source endpoint could be derived from the request. NO_SOURCE_LOCATION = 2 end end |
#endpoint_info ⇒ ::Google::Cloud::NetworkManagement::V1::EndpointInfo
Returns The source and destination endpoints derived from the test input and used for active probing.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 407 class ProbingDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Representation of a network edge location as per # https://cloud.google.com/vpc/docs/edge-locations. # @!attribute [rw] metropolitan_area # @return [::String] # Name of the metropolitan area. class EdgeLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Probing results for a single edge device. # @!attribute [rw] result # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult] # The overall result of active probing for this egress device. # @!attribute [rw] sent_probe_count # @return [::Integer] # Number of probes sent. # @!attribute [rw] successful_probe_count # @return [::Integer] # Number of probes that reached the destination. # @!attribute [rw] probing_latency # @return [::Google::Cloud::NetworkManagement::V1::LatencyDistribution] # Latency as measured by active probing in one direction: from the source # to the destination endpoint. # @!attribute [rw] destination_egress_location # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation] # The EdgeLocation from which a packet, destined to the internet, will # egress the Google network. # This will only be populated for a connectivity test which has an internet # destination address. # The absence of this field *must not* be used as an indication that the # destination is part of the Google network. # @!attribute [rw] destination_router # @return [::String] # Router name in the format '\\{router}.\\{metroshard}'. For example: # pf01.aaa01, pr02.aaa01. class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Overall probing result of the test. module ProbingResult # No result was specified. PROBING_RESULT_UNSPECIFIED = 0 # At least 95% of packets reached the destination. REACHABLE = 1 # No packets reached the destination. UNREACHABLE = 2 # Less than 95% of packets reached the destination. REACHABILITY_INCONSISTENT = 3 # Reachability could not be determined. Possible reasons are: # * The user lacks permission to access some of the network resources # required to run the test. # * No valid source endpoint could be derived from the request. # * An internal error occurred. UNDETERMINED = 4 end # Abort cause types. module ProbingAbortCause # No reason was specified. PROBING_ABORT_CAUSE_UNSPECIFIED = 0 # The user lacks permission to access some of the # network resources required to run the test. PERMISSION_DENIED = 1 # No valid source endpoint could be derived from the request. NO_SOURCE_LOCATION = 2 end end |
#error ⇒ ::Google::Rpc::Status
Returns Details about an internal failure or the cancellation of active probing.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 407 class ProbingDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Representation of a network edge location as per # https://cloud.google.com/vpc/docs/edge-locations. # @!attribute [rw] metropolitan_area # @return [::String] # Name of the metropolitan area. class EdgeLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Probing results for a single edge device. # @!attribute [rw] result # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult] # The overall result of active probing for this egress device. # @!attribute [rw] sent_probe_count # @return [::Integer] # Number of probes sent. # @!attribute [rw] successful_probe_count # @return [::Integer] # Number of probes that reached the destination. # @!attribute [rw] probing_latency # @return [::Google::Cloud::NetworkManagement::V1::LatencyDistribution] # Latency as measured by active probing in one direction: from the source # to the destination endpoint. # @!attribute [rw] destination_egress_location # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation] # The EdgeLocation from which a packet, destined to the internet, will # egress the Google network. # This will only be populated for a connectivity test which has an internet # destination address. # The absence of this field *must not* be used as an indication that the # destination is part of the Google network. # @!attribute [rw] destination_router # @return [::String] # Router name in the format '\\{router}.\\{metroshard}'. For example: # pf01.aaa01, pr02.aaa01. class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Overall probing result of the test. module ProbingResult # No result was specified. PROBING_RESULT_UNSPECIFIED = 0 # At least 95% of packets reached the destination. REACHABLE = 1 # No packets reached the destination. UNREACHABLE = 2 # Less than 95% of packets reached the destination. REACHABILITY_INCONSISTENT = 3 # Reachability could not be determined. Possible reasons are: # * The user lacks permission to access some of the network resources # required to run the test. # * No valid source endpoint could be derived from the request. # * An internal error occurred. UNDETERMINED = 4 end # Abort cause types. module ProbingAbortCause # No reason was specified. PROBING_ABORT_CAUSE_UNSPECIFIED = 0 # The user lacks permission to access some of the # network resources required to run the test. PERMISSION_DENIED = 1 # No valid source endpoint could be derived from the request. NO_SOURCE_LOCATION = 2 end end |
#probed_all_devices ⇒ ::Boolean
Returns Whether all relevant edge devices were probed.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 407 class ProbingDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Representation of a network edge location as per # https://cloud.google.com/vpc/docs/edge-locations. # @!attribute [rw] metropolitan_area # @return [::String] # Name of the metropolitan area. class EdgeLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Probing results for a single edge device. # @!attribute [rw] result # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult] # The overall result of active probing for this egress device. # @!attribute [rw] sent_probe_count # @return [::Integer] # Number of probes sent. # @!attribute [rw] successful_probe_count # @return [::Integer] # Number of probes that reached the destination. # @!attribute [rw] probing_latency # @return [::Google::Cloud::NetworkManagement::V1::LatencyDistribution] # Latency as measured by active probing in one direction: from the source # to the destination endpoint. # @!attribute [rw] destination_egress_location # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation] # The EdgeLocation from which a packet, destined to the internet, will # egress the Google network. # This will only be populated for a connectivity test which has an internet # destination address. # The absence of this field *must not* be used as an indication that the # destination is part of the Google network. # @!attribute [rw] destination_router # @return [::String] # Router name in the format '\\{router}.\\{metroshard}'. For example: # pf01.aaa01, pr02.aaa01. class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Overall probing result of the test. module ProbingResult # No result was specified. PROBING_RESULT_UNSPECIFIED = 0 # At least 95% of packets reached the destination. REACHABLE = 1 # No packets reached the destination. UNREACHABLE = 2 # Less than 95% of packets reached the destination. REACHABILITY_INCONSISTENT = 3 # Reachability could not be determined. Possible reasons are: # * The user lacks permission to access some of the network resources # required to run the test. # * No valid source endpoint could be derived from the request. # * An internal error occurred. UNDETERMINED = 4 end # Abort cause types. module ProbingAbortCause # No reason was specified. PROBING_ABORT_CAUSE_UNSPECIFIED = 0 # The user lacks permission to access some of the # network resources required to run the test. PERMISSION_DENIED = 1 # No valid source endpoint could be derived from the request. NO_SOURCE_LOCATION = 2 end end |
#probing_latency ⇒ ::Google::Cloud::NetworkManagement::V1::LatencyDistribution
Returns Latency as measured by active probing in one direction: from the source to the destination endpoint.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 407 class ProbingDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Representation of a network edge location as per # https://cloud.google.com/vpc/docs/edge-locations. # @!attribute [rw] metropolitan_area # @return [::String] # Name of the metropolitan area. class EdgeLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Probing results for a single edge device. # @!attribute [rw] result # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult] # The overall result of active probing for this egress device. # @!attribute [rw] sent_probe_count # @return [::Integer] # Number of probes sent. # @!attribute [rw] successful_probe_count # @return [::Integer] # Number of probes that reached the destination. # @!attribute [rw] probing_latency # @return [::Google::Cloud::NetworkManagement::V1::LatencyDistribution] # Latency as measured by active probing in one direction: from the source # to the destination endpoint. # @!attribute [rw] destination_egress_location # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation] # The EdgeLocation from which a packet, destined to the internet, will # egress the Google network. # This will only be populated for a connectivity test which has an internet # destination address. # The absence of this field *must not* be used as an indication that the # destination is part of the Google network. # @!attribute [rw] destination_router # @return [::String] # Router name in the format '\\{router}.\\{metroshard}'. For example: # pf01.aaa01, pr02.aaa01. class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Overall probing result of the test. module ProbingResult # No result was specified. PROBING_RESULT_UNSPECIFIED = 0 # At least 95% of packets reached the destination. REACHABLE = 1 # No packets reached the destination. UNREACHABLE = 2 # Less than 95% of packets reached the destination. REACHABILITY_INCONSISTENT = 3 # Reachability could not be determined. Possible reasons are: # * The user lacks permission to access some of the network resources # required to run the test. # * No valid source endpoint could be derived from the request. # * An internal error occurred. UNDETERMINED = 4 end # Abort cause types. module ProbingAbortCause # No reason was specified. PROBING_ABORT_CAUSE_UNSPECIFIED = 0 # The user lacks permission to access some of the # network resources required to run the test. PERMISSION_DENIED = 1 # No valid source endpoint could be derived from the request. NO_SOURCE_LOCATION = 2 end end |
#result ⇒ ::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult
Returns The overall result of active probing.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 407 class ProbingDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Representation of a network edge location as per # https://cloud.google.com/vpc/docs/edge-locations. # @!attribute [rw] metropolitan_area # @return [::String] # Name of the metropolitan area. class EdgeLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Probing results for a single edge device. # @!attribute [rw] result # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult] # The overall result of active probing for this egress device. # @!attribute [rw] sent_probe_count # @return [::Integer] # Number of probes sent. # @!attribute [rw] successful_probe_count # @return [::Integer] # Number of probes that reached the destination. # @!attribute [rw] probing_latency # @return [::Google::Cloud::NetworkManagement::V1::LatencyDistribution] # Latency as measured by active probing in one direction: from the source # to the destination endpoint. # @!attribute [rw] destination_egress_location # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation] # The EdgeLocation from which a packet, destined to the internet, will # egress the Google network. # This will only be populated for a connectivity test which has an internet # destination address. # The absence of this field *must not* be used as an indication that the # destination is part of the Google network. # @!attribute [rw] destination_router # @return [::String] # Router name in the format '\\{router}.\\{metroshard}'. For example: # pf01.aaa01, pr02.aaa01. class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Overall probing result of the test. module ProbingResult # No result was specified. PROBING_RESULT_UNSPECIFIED = 0 # At least 95% of packets reached the destination. REACHABLE = 1 # No packets reached the destination. UNREACHABLE = 2 # Less than 95% of packets reached the destination. REACHABILITY_INCONSISTENT = 3 # Reachability could not be determined. Possible reasons are: # * The user lacks permission to access some of the network resources # required to run the test. # * No valid source endpoint could be derived from the request. # * An internal error occurred. UNDETERMINED = 4 end # Abort cause types. module ProbingAbortCause # No reason was specified. PROBING_ABORT_CAUSE_UNSPECIFIED = 0 # The user lacks permission to access some of the # network resources required to run the test. PERMISSION_DENIED = 1 # No valid source endpoint could be derived from the request. NO_SOURCE_LOCATION = 2 end end |
#sent_probe_count ⇒ ::Integer
Returns Number of probes sent.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 407 class ProbingDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Representation of a network edge location as per # https://cloud.google.com/vpc/docs/edge-locations. # @!attribute [rw] metropolitan_area # @return [::String] # Name of the metropolitan area. class EdgeLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Probing results for a single edge device. # @!attribute [rw] result # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult] # The overall result of active probing for this egress device. # @!attribute [rw] sent_probe_count # @return [::Integer] # Number of probes sent. # @!attribute [rw] successful_probe_count # @return [::Integer] # Number of probes that reached the destination. # @!attribute [rw] probing_latency # @return [::Google::Cloud::NetworkManagement::V1::LatencyDistribution] # Latency as measured by active probing in one direction: from the source # to the destination endpoint. # @!attribute [rw] destination_egress_location # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation] # The EdgeLocation from which a packet, destined to the internet, will # egress the Google network. # This will only be populated for a connectivity test which has an internet # destination address. # The absence of this field *must not* be used as an indication that the # destination is part of the Google network. # @!attribute [rw] destination_router # @return [::String] # Router name in the format '\\{router}.\\{metroshard}'. For example: # pf01.aaa01, pr02.aaa01. class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Overall probing result of the test. module ProbingResult # No result was specified. PROBING_RESULT_UNSPECIFIED = 0 # At least 95% of packets reached the destination. REACHABLE = 1 # No packets reached the destination. UNREACHABLE = 2 # Less than 95% of packets reached the destination. REACHABILITY_INCONSISTENT = 3 # Reachability could not be determined. Possible reasons are: # * The user lacks permission to access some of the network resources # required to run the test. # * No valid source endpoint could be derived from the request. # * An internal error occurred. UNDETERMINED = 4 end # Abort cause types. module ProbingAbortCause # No reason was specified. PROBING_ABORT_CAUSE_UNSPECIFIED = 0 # The user lacks permission to access some of the # network resources required to run the test. PERMISSION_DENIED = 1 # No valid source endpoint could be derived from the request. NO_SOURCE_LOCATION = 2 end end |
#successful_probe_count ⇒ ::Integer
Returns Number of probes that reached the destination.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 407 class ProbingDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Representation of a network edge location as per # https://cloud.google.com/vpc/docs/edge-locations. # @!attribute [rw] metropolitan_area # @return [::String] # Name of the metropolitan area. class EdgeLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Probing results for a single edge device. # @!attribute [rw] result # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult] # The overall result of active probing for this egress device. # @!attribute [rw] sent_probe_count # @return [::Integer] # Number of probes sent. # @!attribute [rw] successful_probe_count # @return [::Integer] # Number of probes that reached the destination. # @!attribute [rw] probing_latency # @return [::Google::Cloud::NetworkManagement::V1::LatencyDistribution] # Latency as measured by active probing in one direction: from the source # to the destination endpoint. # @!attribute [rw] destination_egress_location # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation] # The EdgeLocation from which a packet, destined to the internet, will # egress the Google network. # This will only be populated for a connectivity test which has an internet # destination address. # The absence of this field *must not* be used as an indication that the # destination is part of the Google network. # @!attribute [rw] destination_router # @return [::String] # Router name in the format '\\{router}.\\{metroshard}'. For example: # pf01.aaa01, pr02.aaa01. class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Overall probing result of the test. module ProbingResult # No result was specified. PROBING_RESULT_UNSPECIFIED = 0 # At least 95% of packets reached the destination. REACHABLE = 1 # No packets reached the destination. UNREACHABLE = 2 # Less than 95% of packets reached the destination. REACHABILITY_INCONSISTENT = 3 # Reachability could not be determined. Possible reasons are: # * The user lacks permission to access some of the network resources # required to run the test. # * No valid source endpoint could be derived from the request. # * An internal error occurred. UNDETERMINED = 4 end # Abort cause types. module ProbingAbortCause # No reason was specified. PROBING_ABORT_CAUSE_UNSPECIFIED = 0 # The user lacks permission to access some of the # network resources required to run the test. PERMISSION_DENIED = 1 # No valid source endpoint could be derived from the request. NO_SOURCE_LOCATION = 2 end end |
#verify_time ⇒ ::Google::Protobuf::Timestamp
Returns The time that reachability was assessed through active probing.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 407 class ProbingDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Representation of a network edge location as per # https://cloud.google.com/vpc/docs/edge-locations. # @!attribute [rw] metropolitan_area # @return [::String] # Name of the metropolitan area. class EdgeLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Probing results for a single edge device. # @!attribute [rw] result # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult] # The overall result of active probing for this egress device. # @!attribute [rw] sent_probe_count # @return [::Integer] # Number of probes sent. # @!attribute [rw] successful_probe_count # @return [::Integer] # Number of probes that reached the destination. # @!attribute [rw] probing_latency # @return [::Google::Cloud::NetworkManagement::V1::LatencyDistribution] # Latency as measured by active probing in one direction: from the source # to the destination endpoint. # @!attribute [rw] destination_egress_location # @return [::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation] # The EdgeLocation from which a packet, destined to the internet, will # egress the Google network. # This will only be populated for a connectivity test which has an internet # destination address. # The absence of this field *must not* be used as an indication that the # destination is part of the Google network. # @!attribute [rw] destination_router # @return [::String] # Router name in the format '\\{router}.\\{metroshard}'. For example: # pf01.aaa01, pr02.aaa01. class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Overall probing result of the test. module ProbingResult # No result was specified. PROBING_RESULT_UNSPECIFIED = 0 # At least 95% of packets reached the destination. REACHABLE = 1 # No packets reached the destination. UNREACHABLE = 2 # Less than 95% of packets reached the destination. REACHABILITY_INCONSISTENT = 3 # Reachability could not be determined. Possible reasons are: # * The user lacks permission to access some of the network resources # required to run the test. # * No valid source endpoint could be derived from the request. # * An internal error occurred. UNDETERMINED = 4 end # Abort cause types. module ProbingAbortCause # No reason was specified. PROBING_ABORT_CAUSE_UNSPECIFIED = 0 # The user lacks permission to access some of the # network resources required to run the test. PERMISSION_DENIED = 1 # No valid source endpoint could be derived from the request. NO_SOURCE_LOCATION = 2 end end |