Class: Google::Cloud::NetworkManagement::V1::ProbingDetails::SingleEdgeResponse
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::ProbingDetails::SingleEdgeResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb
Overview
Probing results for a single edge device.
Instance Attribute Summary collapse
-
#destination_egress_location ⇒ ::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation
The EdgeLocation from which a packet, destined to the internet, will egress the Google network.
-
#destination_router ⇒ ::String
Router name in the format '{router}.{metroshard}'.
-
#probing_latency ⇒ ::Google::Cloud::NetworkManagement::V1::LatencyDistribution
Latency as measured by active probing in one direction: from the source to the destination endpoint.
-
#result ⇒ ::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult
The overall result of active probing for this egress device.
-
#sent_probe_count ⇒ ::Integer
Number of probes sent.
-
#successful_probe_count ⇒ ::Integer
Number of probes that reached the destination.
Instance Attribute Details
#destination_egress_location ⇒ ::Google::Cloud::NetworkManagement::V1::ProbingDetails::EdgeLocation
Returns The EdgeLocation from which a packet, destined to the internet, will egress the Google network. This will only be populated for a connectivity test which has an internet destination address. The absence of this field must not be used as an indication that the destination is part of the Google network.
447 448 449 450 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 447 class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destination_router ⇒ ::String
Returns Router name in the format '{router}.{metroshard}'. For example: pf01.aaa01, pr02.aaa01.
447 448 449 450 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 447 class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#probing_latency ⇒ ::Google::Cloud::NetworkManagement::V1::LatencyDistribution
Returns Latency as measured by active probing in one direction: from the source to the destination endpoint.
447 448 449 450 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 447 class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#result ⇒ ::Google::Cloud::NetworkManagement::V1::ProbingDetails::ProbingResult
Returns The overall result of active probing for this egress device.
447 448 449 450 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 447 class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sent_probe_count ⇒ ::Integer
Returns Number of probes sent.
447 448 449 450 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 447 class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#successful_probe_count ⇒ ::Integer
Returns Number of probes that reached the destination.
447 448 449 450 |
# File 'proto_docs/google/cloud/networkmanagement/v1/connectivity_test.rb', line 447 class SingleEdgeResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |