Class: Google::Cloud::NetworkManagement::V1::ShowEffectiveFlowLogsConfigsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::ShowEffectiveFlowLogsConfigsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb
Overview
Request for the ShowEffectiveFlowLogsConfigs method.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
-
#resource ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Lists the EffectiveVpcFlowLogsConfigs that match the filter
expression. A filter expression must use the supported CEL logic
operators.
202 203 204 205 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 202 class ShowEffectiveFlowLogsConfigsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Number of EffectiveVpcFlowLogsConfigs to return. Default is 30.
202 203 204 205 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 202 class ShowEffectiveFlowLogsConfigsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. Page token from an earlier query, as returned in
next_page_token.
202 203 204 205 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 202 class ShowEffectiveFlowLogsConfigsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource of the VpcFlowLogsConfig, specified in
the following format: projects/{project_id}/locations/global.
202 203 204 205 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 202 class ShowEffectiveFlowLogsConfigsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource ⇒ ::String
Returns Required. The resource to get the effective VPC Flow Logs configuration for. The resource must belong to the same project as the parent. The resource must be a network, subnetwork, interconnect attachment, VPN tunnel, or a project.
202 203 204 205 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs.rb', line 202 class ShowEffectiveFlowLogsConfigsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |