Class: Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb
Overview
A configuration to generate VPC Flow Logs.
Defined Under Namespace
Modules: AggregationInterval, CrossProjectMetadata, Metadata, State, TargetResourceState Classes: LabelsEntry
Instance Attribute Summary collapse
-
#aggregation_interval ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::AggregationInterval
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#cross_project_metadata ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::CrossProjectMetadata
Optional.
-
#description ⇒ ::String
Optional.
-
#filter_expr ⇒ ::String
Optional.
-
#flow_sampling ⇒ ::Float
Optional.
-
#interconnect_attachment ⇒ ::String
Traffic will be logged from the Interconnect Attachment.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#metadata ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::Metadata
Optional.
-
#metadata_fields ⇒ ::Array<::String>
Optional.
-
#name ⇒ ::String
Identifier.
-
#network ⇒ ::String
Traffic will be logged from VMs, VPN tunnels and Interconnect Attachments within the network.
-
#state ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::State
Optional.
-
#subnet ⇒ ::String
Traffic will be logged from VMs within the subnetwork.
-
#target_resource_state ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::TargetResourceState
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#vpn_tunnel ⇒ ::String
Traffic will be logged from the VPN Tunnel.
Instance Attribute Details
#aggregation_interval ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::AggregationInterval
Returns Optional. The aggregation interval for the logs. Default value is INTERVAL_5_SEC.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the config was created.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#cross_project_metadata ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::CrossProjectMetadata
Returns Optional. Determines whether to include cross project annotations in the logs. This field is available only for organization configurations. If not specified in org configs will be set to CROSS_PROJECT_METADATA_ENABLED.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#description ⇒ ::String
Returns Optional. The user-supplied description of the VPC Flow Logs configuration. Maximum of 512 characters.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#filter_expr ⇒ ::String
Returns Optional. Export filter used to define which VPC Flow Logs should be logged.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#flow_sampling ⇒ ::Float
Returns Optional. The value of the field must be in (0, 1]. The sampling rate of VPC Flow Logs where 1.0 means all collected logs are reported. Setting the sampling rate to 0.0 is not allowed. If you want to disable VPC Flow Logs, use the state field instead. Default value is 1.0.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#interconnect_attachment ⇒ ::String
Returns Traffic will be logged from the Interconnect Attachment. Format: projects/{project_id}/regions/{region}/interconnectAttachments/{name}
Note: The following fields are mutually exclusive: interconnect_attachment, network, subnet, vpn_tunnel. If a field in that set is populated, all other fields in the set will automatically be cleared.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Resource labels to represent user-provided metadata.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#metadata ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::Metadata
Returns Optional. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default value is INCLUDE_ALL_METADATA.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#metadata_fields ⇒ ::Array<::String>
Returns Optional. Custom metadata fields to include in the reported VPC flow logs. Can only be specified if "metadata" was set to CUSTOM_METADATA.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#name ⇒ ::String
Returns Identifier. Unique name of the configuration. The name can have one of the following forms:
For project-level configurations:
projects/{project_id}/locations/global/vpcFlowLogsConfigs/{vpc_flow_logs_config_id}For organization-level configurations:
organizations/{organization_id}/locations/global/vpcFlowLogsConfigs/{vpc_flow_logs_config_id}.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#network ⇒ ::String
Returns Traffic will be logged from VMs, VPN tunnels and Interconnect Attachments within the network. Format: projects/{project_id}/global/networks/{name}
Note: The following fields are mutually exclusive: network, subnet, interconnect_attachment, vpn_tunnel. If a field in that set is populated, all other fields in the set will automatically be cleared.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#state ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::State
Returns Optional. The state of the VPC Flow Log configuration. Default value is ENABLED. When creating a new configuration, it must be enabled. Setting state=DISABLED will pause the log generation for this config.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#subnet ⇒ ::String
Returns Traffic will be logged from VMs within the subnetwork. Format: projects/{project_id}/regions/{region}/subnetworks/{name}
Note: The following fields are mutually exclusive: subnet, network, interconnect_attachment, vpn_tunnel. If a field in that set is populated, all other fields in the set will automatically be cleared.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#target_resource_state ⇒ ::Google::Cloud::NetworkManagement::V1::VpcFlowLogsConfig::TargetResourceState (readonly)
Returns Output only. Describes the state of the configured target resource for diagnostic purposes.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the config was updated.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |
#vpn_tunnel ⇒ ::String
Returns Traffic will be logged from the VPN Tunnel. Format: projects/{project_id}/regions/{region}/vpnTunnels/{name}
Note: The following fields are mutually exclusive: vpn_tunnel, network, subnet, interconnect_attachment. If a field in that set is populated, all other fields in the set will automatically be cleared.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'proto_docs/google/cloud/networkmanagement/v1/vpc_flow_logs_config.rb', line 111 class VpcFlowLogsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Determines whether this configuration will be generating logs. module State # If not specified, will default to ENABLED. STATE_UNSPECIFIED = 0 # When ENABLED, this configuration will generate logs. ENABLED = 1 # When DISABLED, this configuration will not generate logs. DISABLED = 2 end # Toggles the aggregation interval for collecting flow logs by 5-tuple. module AggregationInterval # If not specified, will default to INTERVAL_5_SEC. AGGREGATION_INTERVAL_UNSPECIFIED = 0 # Aggregate logs in 5s intervals. INTERVAL_5_SEC = 1 # Aggregate logs in 30s intervals. INTERVAL_30_SEC = 2 # Aggregate logs in 1m intervals. INTERVAL_1_MIN = 3 # Aggregate logs in 5m intervals. INTERVAL_5_MIN = 4 # Aggregate logs in 10m intervals. INTERVAL_10_MIN = 5 # Aggregate logs in 15m intervals. INTERVAL_15_MIN = 6 end # Configures which log fields would be included. module Metadata # If not specified, will default to INCLUDE_ALL_METADATA. METADATA_UNSPECIFIED = 0 # Include all metadata fields. INCLUDE_ALL_METADATA = 1 # Exclude all metadata fields. EXCLUDE_ALL_METADATA = 2 # Include only custom fields (specified in metadata_fields). CUSTOM_METADATA = 3 end # Determines whether to include cross project annotations in the logs. # Project configurations will always have CROSS_PROJECT_METADATA_DISABLED. module CrossProjectMetadata # If not specified, the default is CROSS_PROJECT_METADATA_ENABLED. CROSS_PROJECT_METADATA_UNSPECIFIED = 0 # When CROSS_PROJECT_METADATA_ENABLED, metadata from other projects will be # included in the logs. CROSS_PROJECT_METADATA_ENABLED = 1 # When CROSS_PROJECT_METADATA_DISABLED, metadata from other projects will # not be included in the logs. CROSS_PROJECT_METADATA_DISABLED = 2 end # Output only. Indicates whether the target resource exists, for diagnostic # purposes. module TargetResourceState # Unspecified target resource state. TARGET_RESOURCE_STATE_UNSPECIFIED = 0 # Indicates that the target resource exists. TARGET_RESOURCE_EXISTS = 1 # Indicates that the target resource does not exist. TARGET_RESOURCE_DOES_NOT_EXIST = 2 end end |