Class: Google::Cloud::NetworkManagement::V1::VpnTunnelInfo
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkManagement::V1::VpnTunnelInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkmanagement/v1/trace.rb
Overview
For display only. Metadata associated with a Compute Engine VPN tunnel.
Defined Under Namespace
Modules: RoutingType
Instance Attribute Summary collapse
-
#display_name ⇒ ::String
Name of a VPN tunnel.
-
#network_uri ⇒ ::String
URI of a Compute Engine network where the VPN tunnel is configured.
-
#region ⇒ ::String
Name of a Google Cloud region where this VPN tunnel is configured.
-
#remote_gateway ⇒ ::String
URI of a VPN gateway at remote end of the tunnel.
-
#remote_gateway_ip ⇒ ::String
Remote VPN gateway's IP address.
-
#routing_type ⇒ ::Google::Cloud::NetworkManagement::V1::VpnTunnelInfo::RoutingType
Type of the routing policy.
-
#source_gateway ⇒ ::String
URI of the VPN gateway at local end of the tunnel.
-
#source_gateway_ip ⇒ ::String
Local VPN gateway's IP address.
-
#uri ⇒ ::String
URI of a VPN tunnel.
Instance Attribute Details
#display_name ⇒ ::String
Returns Name of a VPN tunnel.
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1101 class VpnTunnelInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of VPN routing policy. For details, refer to [Networks and Tunnel # routing](https://cloud.google.com/network-connectivity/docs/vpn/concepts/choosing-networks-routing/). module RoutingType # Unspecified type. Default value. ROUTING_TYPE_UNSPECIFIED = 0 # Route based VPN. ROUTE_BASED = 1 # Policy based routing. POLICY_BASED = 2 # Dynamic (BGP) routing. DYNAMIC = 3 end end |
#network_uri ⇒ ::String
Returns URI of a Compute Engine network where the VPN tunnel is configured.
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1101 class VpnTunnelInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of VPN routing policy. For details, refer to [Networks and Tunnel # routing](https://cloud.google.com/network-connectivity/docs/vpn/concepts/choosing-networks-routing/). module RoutingType # Unspecified type. Default value. ROUTING_TYPE_UNSPECIFIED = 0 # Route based VPN. ROUTE_BASED = 1 # Policy based routing. POLICY_BASED = 2 # Dynamic (BGP) routing. DYNAMIC = 3 end end |
#region ⇒ ::String
Returns Name of a Google Cloud region where this VPN tunnel is configured.
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1101 class VpnTunnelInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of VPN routing policy. For details, refer to [Networks and Tunnel # routing](https://cloud.google.com/network-connectivity/docs/vpn/concepts/choosing-networks-routing/). module RoutingType # Unspecified type. Default value. ROUTING_TYPE_UNSPECIFIED = 0 # Route based VPN. ROUTE_BASED = 1 # Policy based routing. POLICY_BASED = 2 # Dynamic (BGP) routing. DYNAMIC = 3 end end |
#remote_gateway ⇒ ::String
Returns URI of a VPN gateway at remote end of the tunnel.
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1101 class VpnTunnelInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of VPN routing policy. For details, refer to [Networks and Tunnel # routing](https://cloud.google.com/network-connectivity/docs/vpn/concepts/choosing-networks-routing/). module RoutingType # Unspecified type. Default value. ROUTING_TYPE_UNSPECIFIED = 0 # Route based VPN. ROUTE_BASED = 1 # Policy based routing. POLICY_BASED = 2 # Dynamic (BGP) routing. DYNAMIC = 3 end end |
#remote_gateway_ip ⇒ ::String
Returns Remote VPN gateway's IP address.
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1101 class VpnTunnelInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of VPN routing policy. For details, refer to [Networks and Tunnel # routing](https://cloud.google.com/network-connectivity/docs/vpn/concepts/choosing-networks-routing/). module RoutingType # Unspecified type. Default value. ROUTING_TYPE_UNSPECIFIED = 0 # Route based VPN. ROUTE_BASED = 1 # Policy based routing. POLICY_BASED = 2 # Dynamic (BGP) routing. DYNAMIC = 3 end end |
#routing_type ⇒ ::Google::Cloud::NetworkManagement::V1::VpnTunnelInfo::RoutingType
Returns Type of the routing policy.
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1101 class VpnTunnelInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of VPN routing policy. For details, refer to [Networks and Tunnel # routing](https://cloud.google.com/network-connectivity/docs/vpn/concepts/choosing-networks-routing/). module RoutingType # Unspecified type. Default value. ROUTING_TYPE_UNSPECIFIED = 0 # Route based VPN. ROUTE_BASED = 1 # Policy based routing. POLICY_BASED = 2 # Dynamic (BGP) routing. DYNAMIC = 3 end end |
#source_gateway ⇒ ::String
Returns URI of the VPN gateway at local end of the tunnel.
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1101 class VpnTunnelInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of VPN routing policy. For details, refer to [Networks and Tunnel # routing](https://cloud.google.com/network-connectivity/docs/vpn/concepts/choosing-networks-routing/). module RoutingType # Unspecified type. Default value. ROUTING_TYPE_UNSPECIFIED = 0 # Route based VPN. ROUTE_BASED = 1 # Policy based routing. POLICY_BASED = 2 # Dynamic (BGP) routing. DYNAMIC = 3 end end |
#source_gateway_ip ⇒ ::String
Returns Local VPN gateway's IP address.
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1101 class VpnTunnelInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of VPN routing policy. For details, refer to [Networks and Tunnel # routing](https://cloud.google.com/network-connectivity/docs/vpn/concepts/choosing-networks-routing/). module RoutingType # Unspecified type. Default value. ROUTING_TYPE_UNSPECIFIED = 0 # Route based VPN. ROUTE_BASED = 1 # Policy based routing. POLICY_BASED = 2 # Dynamic (BGP) routing. DYNAMIC = 3 end end |
#uri ⇒ ::String
Returns URI of a VPN tunnel.
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'proto_docs/google/cloud/networkmanagement/v1/trace.rb', line 1101 class VpnTunnelInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of VPN routing policy. For details, refer to [Networks and Tunnel # routing](https://cloud.google.com/network-connectivity/docs/vpn/concepts/choosing-networks-routing/). module RoutingType # Unspecified type. Default value. ROUTING_TYPE_UNSPECIFIED = 0 # Route based VPN. ROUTE_BASED = 1 # Policy based routing. POLICY_BASED = 2 # Dynamic (BGP) routing. DYNAMIC = 3 end end |